/*   
    Copyright (C) 2014 Mario Krumnow, Dresden University of Technology

    This file is part of TraaS.

    TraaS is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License.

    TraaS is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with TraaS.  If not, see <http://www.gnu.org/licenses/>.
*/

package de.tudresden.ws;

/**
 * 
 * @author Mario Krumnow
 *
 */

public interface Service {
        
        public String start(String user);
        
        public String stop(String user);
        
        public void addOption(String name, String value);
        
        public void doTimestep();
        
        public void setConfig(String filename);
        
        public void setSumoBinary(String filename);
        
        
        public String get_Status(String user);
       
        public String LastActionTime();

        public String version();
               
        public String TXT_output(boolean input);
           
}