classdef Message
%Message A container for outgoing TraCI messages.

%   Copyright 2013 Universidad Nacional de Colombia,
%   Politecnico Jaime Isaza Cadavid.
%   Authors: Andres Acosta, Jairo Espinosa, Jorge Espinosa.
%   $Id: Message.m 2 2013-12-21 21:39:57Z aacosta $

	properties
		string
		queue
	end
end
