function laneID = getLaneID(vehID)
%getLaneID
%   laneID = getLaneID(VEHID) Returns the id of the lane the named vehicle 
%   was at within the last step.

%   Copyright 2013 Universidad Nacional de Colombia,
%   Politecnico Jaime Isaza Cadavid.
%   Authors: Andres Acosta, Jairo Espinosa, Jorge Espinosa.
%   $Id: getLaneID.m 2 2013-12-21 21:39:57Z aacosta $

import traci.constants


import traci.constants
laneID = traci.vehicle.getUniversal(constants.VAR_LANE_ID, vehID);