function length = getLength(typeID)
%getLength
%   length = getLength(TYPEID) Returns the length in m of the vehicles of 
%   this type.

%   Copyright 2013 Universidad Nacional de Colombia,
%   Politecnico Jaime Isaza Cadavid.
%   Authors: Andres Acosta, Jairo Espinosa, Jorge Espinosa.
%   $Id: getLength.m 2 2013-12-21 21:39:57Z aacosta $

import traci.constants
length = traci.vehicletype.getUniversal(constants.VAR_LENGTH, typeID);