
package de.tudresden.ws;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the de.tudresden.ws package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _VehicleSetSpeed_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setSpeed");
    private final static QName _SimulationGetParkingStartingVehiclesNumberResponse_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getParkingStartingVehiclesNumberResponse");
    private final static QName _GUIGetBoundaryResponse_QNAME = new QName("http://ws.tudresden.de/", "GUI_getBoundaryResponse");
    private final static QName _VehicleGetSpeedWithoutTraCIResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getSpeedWithoutTraCIResponse");
    private final static QName _VehicleChangeLane_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_changeLane");
    private final static QName _PoiGetPositionResponse_QNAME = new QName("http://ws.tudresden.de/", "Poi_getPositionResponse");
    private final static QName _RouteGetIDListResponse_QNAME = new QName("http://ws.tudresden.de/", "Route_getIDListResponse");
    private final static QName _EdgeGetAdaptedTraveltimeResponse_QNAME = new QName("http://ws.tudresden.de/", "Edge_getAdaptedTraveltimeResponse");
    private final static QName _TrafficlightsSetCompleteRedYellowGreenDefinitionResponse_QNAME = new QName("http://ws.tudresden.de/", "Trafficlights_setCompleteRedYellowGreenDefinitionResponse");
    private final static QName _JunctionGetShape_QNAME = new QName("http://ws.tudresden.de/", "Junction_getShape");
    private final static QName _VehicleIsRouteValid_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_isRouteValid");
    private final static QName _Start_QNAME = new QName("http://ws.tudresden.de/", "start");
    private final static QName _LaneGetNOxEmissionResponse_QNAME = new QName("http://ws.tudresden.de/", "Lane_getNOxEmissionResponse");
    private final static QName _GUIGetIDListResponse_QNAME = new QName("http://ws.tudresden.de/", "GUI_getIDListResponse");
    private final static QName _InductionloopGetIDCountResponse_QNAME = new QName("http://ws.tudresden.de/", "Inductionloop_getIDCountResponse");
    private final static QName _VehicleGetNOxEmissionResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getNOxEmissionResponse");
    private final static QName _SimulationConvertRoadResponse_QNAME = new QName("http://ws.tudresden.de/", "Simulation_convertRoadResponse");
    private final static QName _VehicleGetMinGapResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getMinGapResponse");
    private final static QName _PolygonGetIDCountResponse_QNAME = new QName("http://ws.tudresden.de/", "Polygon_getIDCountResponse");
    private final static QName _VehicleIsRouteValidResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_isRouteValidResponse");
    private final static QName _VehicletypeGetColor_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_getColor");
    private final static QName _VehicleSetSpeedFactorResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setSpeedFactorResponse");
    private final static QName _PoiGetIDCountResponse_QNAME = new QName("http://ws.tudresden.de/", "Poi_getIDCountResponse");
    private final static QName _SimulationGetDistanceRoad_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getDistanceRoad");
    private final static QName _TrafficlightsSetCompleteRedYellowGreenDefinition_QNAME = new QName("http://ws.tudresden.de/", "Trafficlights_setCompleteRedYellowGreenDefinition");
    private final static QName _LaneGetWidthResponse_QNAME = new QName("http://ws.tudresden.de/", "Lane_getWidthResponse");
    private final static QName _InductionloopGetLastStepOccupancyResponse_QNAME = new QName("http://ws.tudresden.de/", "Inductionloop_getLastStepOccupancyResponse");
    private final static QName _VehicleGetColorResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getColorResponse");
    private final static QName _VehicletypeSetEmissionClassResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_setEmissionClassResponse");
    private final static QName _LaneGetCOEmission_QNAME = new QName("http://ws.tudresden.de/", "Lane_getCOEmission");
    private final static QName _PoiGetColor_QNAME = new QName("http://ws.tudresden.de/", "Poi_getColor");
    private final static QName _MultientryexitGetIDCountResponse_QNAME = new QName("http://ws.tudresden.de/", "Multientryexit_getIDCountResponse");
    private final static QName _EdgeGetHCEmissionResponse_QNAME = new QName("http://ws.tudresden.de/", "Edge_getHCEmissionResponse");
    private final static QName _VehicletypeSetMinGap_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_setMinGap");
    private final static QName _VehicleSetTypeResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setTypeResponse");
    private final static QName _SimulationGetParkingEndingVehiclesNumber_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getParkingEndingVehiclesNumber");
    private final static QName _PoiGetTypeResponse_QNAME = new QName("http://ws.tudresden.de/", "Poi_getTypeResponse");
    private final static QName _TrafficlightsGetProgramResponse_QNAME = new QName("http://ws.tudresden.de/", "Trafficlights_getProgramResponse");
    private final static QName _TrafficlightsGetControlledLanesResponse_QNAME = new QName("http://ws.tudresden.de/", "Trafficlights_getControlledLanesResponse");
    private final static QName _InductionloopGetVehicleDataResponse_QNAME = new QName("http://ws.tudresden.de/", "Inductionloop_getVehicleDataResponse");
    private final static QName _PolygonGetShapeResponse_QNAME = new QName("http://ws.tudresden.de/", "Polygon_getShapeResponse");
    private final static QName _VehicleSetAccel_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setAccel");
    private final static QName _VehicleGetLanePosition_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getLanePosition");
    private final static QName _VehicleSetVehicleClass_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setVehicleClass");
    private final static QName _VehicleGetCOEmissionResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getCOEmissionResponse");
    private final static QName _SimulationGetEndingTeleportNumberResponse_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getEndingTeleportNumberResponse");
    private final static QName _EdgeGetLastStepVehicleNumberResponse_QNAME = new QName("http://ws.tudresden.de/", "Edge_getLastStepVehicleNumberResponse");
    private final static QName _VehicleSetWidthResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setWidthResponse");
    private final static QName _VehicleGetRoute_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getRoute");
    private final static QName _LaneGetLastStepVehicleIDsResponse_QNAME = new QName("http://ws.tudresden.de/", "Lane_getLastStepVehicleIDsResponse");
    private final static QName _VehicleGetTauResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getTauResponse");
    private final static QName _TrafficlightsGetPhase_QNAME = new QName("http://ws.tudresden.de/", "Trafficlights_getPhase");
    private final static QName _VehicleSetSignals_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setSignals");
    private final static QName _PolygonAdd_QNAME = new QName("http://ws.tudresden.de/", "Polygon_add");
    private final static QName _LaneGetDisallowedResponse_QNAME = new QName("http://ws.tudresden.de/", "Lane_getDisallowedResponse");
    private final static QName _SimulationGetLoadedIDList_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getLoadedIDList");
    private final static QName _VehicletypeSetMinGapResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_setMinGapResponse");
    private final static QName _VehicleGetDistance_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getDistance");
    private final static QName _GUIGetSchema_QNAME = new QName("http://ws.tudresden.de/", "GUI_getSchema");
    private final static QName _PolygonGetIDCount_QNAME = new QName("http://ws.tudresden.de/", "Polygon_getIDCount");
    private final static QName _TrafficlightsGetControlledLinks_QNAME = new QName("http://ws.tudresden.de/", "Trafficlights_getControlledLinks");
    private final static QName _GUIGetBoundary_QNAME = new QName("http://ws.tudresden.de/", "GUI_getBoundary");
    private final static QName _VehicleRerouteTraveltime_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_rerouteTraveltime");
    private final static QName _Version_QNAME = new QName("http://ws.tudresden.de/", "version");
    private final static QName _LastActionTimeResponse_QNAME = new QName("http://ws.tudresden.de/", "LastActionTimeResponse");
    private final static QName _LaneGetLinkNumberResponse_QNAME = new QName("http://ws.tudresden.de/", "Lane_getLinkNumberResponse");
    private final static QName _VehicleGetLengthResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getLengthResponse");
    private final static QName _VehicletypeSetShapeClass_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_setShapeClass");
    private final static QName _LaneGetLastStepMeanSpeed_QNAME = new QName("http://ws.tudresden.de/", "Lane_getLastStepMeanSpeed");
    private final static QName _VehicleGetLaneIndexResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getLaneIndexResponse");
    private final static QName _EdgeGetLastStepOccupancyResponse_QNAME = new QName("http://ws.tudresden.de/", "Edge_getLastStepOccupancyResponse");
    private final static QName _SimulationGetMinExpectedNumber_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getMinExpectedNumber");
    private final static QName _VehicleGetEffort_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getEffort");
    private final static QName _JunctionGetIDListResponse_QNAME = new QName("http://ws.tudresden.de/", "Junction_getIDListResponse");
    private final static QName _VehicleGetSpeedFactor_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getSpeedFactor");
    private final static QName _SimulationGetLoadedNumber_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getLoadedNumber");
    private final static QName _VehicleAdd_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_add");
    private final static QName _SimulationGetEndingTeleportIDList_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getEndingTeleportIDList");
    private final static QName _VehicleGetAdaptedTraveltime_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getAdaptedTraveltime");
    private final static QName _EdgeGetAdaptedTraveltime_QNAME = new QName("http://ws.tudresden.de/", "Edge_getAdaptedTraveltime");
    private final static QName _VehicleRemove_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_remove");
    private final static QName _VehicleSetRouteIDResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setRouteIDResponse");
    private final static QName _EdgeGetTraveltimeResponse_QNAME = new QName("http://ws.tudresden.de/", "Edge_getTraveltimeResponse");
    private final static QName _LaneGetLinkNumber_QNAME = new QName("http://ws.tudresden.de/", "Lane_getLinkNumber");
    private final static QName _LaneGetMaxSpeed_QNAME = new QName("http://ws.tudresden.de/", "Lane_getMaxSpeed");
    private final static QName _VehicletypeSetLength_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_setLength");
    private final static QName _RouteAdd_QNAME = new QName("http://ws.tudresden.de/", "Route_add");
    private final static QName _VehicleSetColor_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setColor");
    private final static QName _VehicleSetLaneChangeModeResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setLaneChangeModeResponse");
    private final static QName _VehicleGetNoiseEmission_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getNoiseEmission");
    private final static QName _VehicleSetSignalsResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setSignalsResponse");
    private final static QName _ArealDetectorGetJamLengthVehicle_QNAME = new QName("http://ws.tudresden.de/", "ArealDetector_getJamLengthVehicle");
    private final static QName _VehicleSetMinGap_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setMinGap");
    private final static QName _SimulationGetParkingEndingVehiclesNumberResponse_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getParkingEndingVehiclesNumberResponse");
    private final static QName _EdgeGetFuelConsumption_QNAME = new QName("http://ws.tudresden.de/", "Edge_getFuelConsumption");
    private final static QName _SimulationGetNetBoundary_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getNetBoundary");
    private final static QName _SimulationGetArrivedIDList_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getArrivedIDList");
    private final static QName _VehicleGetSpeedFactorResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getSpeedFactorResponse");
    private final static QName _VehicleGetRoadIDResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getRoadIDResponse");
    private final static QName _VehicleGetDrivingDistance2D_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getDrivingDistance2D");
    private final static QName _SetConfig_QNAME = new QName("http://ws.tudresden.de/", "setConfig");
    private final static QName _SimulationConvertRoad_QNAME = new QName("http://ws.tudresden.de/", "Simulation_convertRoad");
    private final static QName _VehicleGetImperfectionResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getImperfectionResponse");
    private final static QName _DoTimestepResponse_QNAME = new QName("http://ws.tudresden.de/", "doTimestepResponse");
    private final static QName _VehicleSetRoute_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setRoute");
    private final static QName _EdgeGetLastStepLength_QNAME = new QName("http://ws.tudresden.de/", "Edge_getLastStepLength");
    private final static QName _PoiGetIDListResponse_QNAME = new QName("http://ws.tudresden.de/", "Poi_getIDListResponse");
    private final static QName _PoiRemoveResponse_QNAME = new QName("http://ws.tudresden.de/", "Poi_removeResponse");
    private final static QName _LaneGetIDCount_QNAME = new QName("http://ws.tudresden.de/", "Lane_getIDCount");
    private final static QName _VehicleGetIDList_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getIDList");
    private final static QName _SimulationGetDepartedNumberResponse_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getDepartedNumberResponse");
    private final static QName _VehicleSetSpeedDeviation_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setSpeedDeviation");
    private final static QName _VehicleSetEmissionClassResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setEmissionClassResponse");
    private final static QName _EdgeGetEffort_QNAME = new QName("http://ws.tudresden.de/", "Edge_getEffort");
    private final static QName _VehicleGetSpeedDeviationResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getSpeedDeviationResponse");
    private final static QName _VehicletypeSetImperfection_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_setImperfection");
    private final static QName _LaneSetMaxSpeedResponse_QNAME = new QName("http://ws.tudresden.de/", "Lane_setMaxSpeedResponse");
    private final static QName _Stop_QNAME = new QName("http://ws.tudresden.de/", "stop");
    private final static QName _TrafficlightsGetIDListResponse_QNAME = new QName("http://ws.tudresden.de/", "Trafficlights_getIDListResponse");
    private final static QName _GUIGetOffsetResponse_QNAME = new QName("http://ws.tudresden.de/", "GUI_getOffsetResponse");
    private final static QName _AddOptionResponse_QNAME = new QName("http://ws.tudresden.de/", "addOptionResponse");
    private final static QName _TXTOutput_QNAME = new QName("http://ws.tudresden.de/", "TXT_output");
    private final static QName _SimulationGetStartingTeleportNumberResponse_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getStartingTeleportNumberResponse");
    private final static QName _GUIGetIDList_QNAME = new QName("http://ws.tudresden.de/", "GUI_getIDList");
    private final static QName _VehicleGetRouteResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getRouteResponse");
    private final static QName _SimulationConvertGeo_QNAME = new QName("http://ws.tudresden.de/", "Simulation_convertGeo");
    private final static QName _PolygonSetShape_QNAME = new QName("http://ws.tudresden.de/", "Polygon_setShape");
    private final static QName _SimulationGetEndingTeleportNumber_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getEndingTeleportNumber");
    private final static QName _VehicleGetAllowedSpeed_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getAllowedSpeed");
    private final static QName _VehicleMoveToVTDResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_moveToVTDResponse");
    private final static QName _LaneGetEdgeID_QNAME = new QName("http://ws.tudresden.de/", "Lane_getEdgeID");
    private final static QName _LaneGetPMxEmission_QNAME = new QName("http://ws.tudresden.de/", "Lane_getPMxEmission");
    private final static QName _LaneGetEdgeIDResponse_QNAME = new QName("http://ws.tudresden.de/", "Lane_getEdgeIDResponse");
    private final static QName _LaneSetDisallowed_QNAME = new QName("http://ws.tudresden.de/", "Lane_setDisallowed");
    private final static QName _RouteGetIDCountResponse_QNAME = new QName("http://ws.tudresden.de/", "Route_getIDCountResponse");
    private final static QName _EdgeGetCOEmissionResponse_QNAME = new QName("http://ws.tudresden.de/", "Edge_getCOEmissionResponse");
    private final static QName _LaneGetWidth_QNAME = new QName("http://ws.tudresden.de/", "Lane_getWidth");
    private final static QName _GetStatus_QNAME = new QName("http://ws.tudresden.de/", "get_Status");
    private final static QName _SimulationConvertGeoResponse_QNAME = new QName("http://ws.tudresden.de/", "Simulation_convertGeoResponse");
    private final static QName _VehicleGetIDCount_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getIDCount");
    private final static QName _EdgeAdaptTraveltime_QNAME = new QName("http://ws.tudresden.de/", "Edge_adaptTraveltime");
    private final static QName _VehicletypeSetLengthResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_setLengthResponse");
    private final static QName _LaneGetCOEmissionResponse_QNAME = new QName("http://ws.tudresden.de/", "Lane_getCOEmissionResponse");
    private final static QName _VehicletypeSetShapeClassResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_setShapeClassResponse");
    private final static QName _EdgeGetNOxEmissionResponse_QNAME = new QName("http://ws.tudresden.de/", "Edge_getNOxEmissionResponse");
    private final static QName _LaneGetNoiseEmission_QNAME = new QName("http://ws.tudresden.de/", "Lane_getNoiseEmission");
    private final static QName _VehicletypeGetIDList_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_getIDList");
    private final static QName _LaneGetIDListResponse_QNAME = new QName("http://ws.tudresden.de/", "Lane_getIDListResponse");
    private final static QName _VehicletypeGetIDListResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_getIDListResponse");
    private final static QName _VehicletypeGetSpeedFactorResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_getSpeedFactorResponse");
    private final static QName _SimulationGetParkingEndingVehiclesIDListResponse_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getParkingEndingVehiclesIDListResponse");
    private final static QName _VehicleGetPosition_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getPosition");
    private final static QName _PolygonGetIDListResponse_QNAME = new QName("http://ws.tudresden.de/", "Polygon_getIDListResponse");
    private final static QName _VehicleGetIDListResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getIDListResponse");
    private final static QName _LaneGetLastStepHaltingNumber_QNAME = new QName("http://ws.tudresden.de/", "Lane_getLastStepHaltingNumber");
    private final static QName _VehicleSetLengthResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setLengthResponse");
    private final static QName _LaneGetLastStepVehicleNumber_QNAME = new QName("http://ws.tudresden.de/", "Lane_getLastStepVehicleNumber");
    private final static QName _VehicleGetRoadID_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getRoadID");
    private final static QName _LaneGetAllowed_QNAME = new QName("http://ws.tudresden.de/", "Lane_getAllowed");
    private final static QName _EdgeGetTraveltime_QNAME = new QName("http://ws.tudresden.de/", "Edge_getTraveltime");
    private final static QName _VehicleSetShapeClassResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setShapeClassResponse");
    private final static QName _VehicletypeSetWidthResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_setWidthResponse");
    private final static QName _GUISetSchemaResponse_QNAME = new QName("http://ws.tudresden.de/", "GUI_setSchemaResponse");
    private final static QName _VehicletypeSetSpeedDeviationResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_setSpeedDeviationResponse");
    private final static QName _VehicleSetAdaptedTraveltime_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setAdaptedTraveltime");
    private final static QName _LaneGetLastStepHaltingNumberResponse_QNAME = new QName("http://ws.tudresden.de/", "Lane_getLastStepHaltingNumberResponse");
    private final static QName _LaneGetFuelConsumption_QNAME = new QName("http://ws.tudresden.de/", "Lane_getFuelConsumption");
    private final static QName _SimulationConvert2D_QNAME = new QName("http://ws.tudresden.de/", "Simulation_convert2D");
    private final static QName _SimulationGetDistance2D_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getDistance2D");
    private final static QName _VehicleGetVehicleClass_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getVehicleClass");
    private final static QName _SimulationGetDistanceRoadResponse_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getDistanceRoadResponse");
    private final static QName _InductionloopGetLastStepMeanSpeed_QNAME = new QName("http://ws.tudresden.de/", "Inductionloop_getLastStepMeanSpeed");
    private final static QName _VehicletypeGetImperfectionResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_getImperfectionResponse");
    private final static QName _InductionloopGetLastStepMeanLength_QNAME = new QName("http://ws.tudresden.de/", "Inductionloop_getLastStepMeanLength");
    private final static QName _PoiSetPositionResponse_QNAME = new QName("http://ws.tudresden.de/", "Poi_setPositionResponse");
    private final static QName _LaneGetLinksResponse_QNAME = new QName("http://ws.tudresden.de/", "Lane_getLinksResponse");
    private final static QName _PolygonAddResponse_QNAME = new QName("http://ws.tudresden.de/", "Polygon_addResponse");
    private final static QName _VehicletypeSetSpeedDeviation_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_setSpeedDeviation");
    private final static QName _AddOption_QNAME = new QName("http://ws.tudresden.de/", "addOption");
    private final static QName _VehicletypeGetTau_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_getTau");
    private final static QName _VehicleGetMaxSpeedResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getMaxSpeedResponse");
    private final static QName _VehicletypeGetMinGapResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_getMinGapResponse");
    private final static QName _PolygonGetColorResponse_QNAME = new QName("http://ws.tudresden.de/", "Polygon_getColorResponse");
    private final static QName _VehicletypeGetShapeClassResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_getShapeClassResponse");
    private final static QName _VehicleSetType_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setType");
    private final static QName _GetStatusResponse_QNAME = new QName("http://ws.tudresden.de/", "get_StatusResponse");
    private final static QName _VehicleGetNOxEmission_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getNOxEmission");
    private final static QName _LaneGetTraveltime_QNAME = new QName("http://ws.tudresden.de/", "Lane_getTraveltime");
    private final static QName _EdgeGetLastStepVehicleIDs_QNAME = new QName("http://ws.tudresden.de/", "Edge_getLastStepVehicleIDs");
    private final static QName _PolygonSetColorResponse_QNAME = new QName("http://ws.tudresden.de/", "Polygon_setColorResponse");
    private final static QName _DoTimestep_QNAME = new QName("http://ws.tudresden.de/", "doTimestep");
    private final static QName _LaneGetIDList_QNAME = new QName("http://ws.tudresden.de/", "Lane_getIDList");
    private final static QName _InductionloopGetLastStepVehicleNumberResponse_QNAME = new QName("http://ws.tudresden.de/", "Inductionloop_getLastStepVehicleNumberResponse");
    private final static QName _TrafficlightsGetRedYellowGreenState_QNAME = new QName("http://ws.tudresden.de/", "Trafficlights_getRedYellowGreenState");
    private final static QName _VehicleGetAngle_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getAngle");
    private final static QName _PolygonSetType_QNAME = new QName("http://ws.tudresden.de/", "Polygon_setType");
    private final static QName _SimulationGetBusStopWaitingResponse_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getBusStopWaitingResponse");
    private final static QName _VehicleGetPositionResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getPositionResponse");
    private final static QName _SimulationGetLoadedNumberResponse_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getLoadedNumberResponse");
    private final static QName _VehicleGetHCEmissionResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getHCEmissionResponse");
    private final static QName _EdgeGetWaitingTimeResponse_QNAME = new QName("http://ws.tudresden.de/", "Edge_getWaitingTimeResponse");
    private final static QName _VersionResponse_QNAME = new QName("http://ws.tudresden.de/", "versionResponse");
    private final static QName _LaneGetCO2Emission_QNAME = new QName("http://ws.tudresden.de/", "Lane_getCO2Emission");
    private final static QName _EdgeGetLastStepMeanSpeedResponse_QNAME = new QName("http://ws.tudresden.de/", "Edge_getLastStepMeanSpeedResponse");
    private final static QName _StartResponse_QNAME = new QName("http://ws.tudresden.de/", "startResponse");
    private final static QName _TrafficlightsGetPhaseDuration_QNAME = new QName("http://ws.tudresden.de/", "Trafficlights_getPhaseDuration");
    private final static QName _VehicleSetAccelResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setAccelResponse");
    private final static QName _EdgeSetEffortResponse_QNAME = new QName("http://ws.tudresden.de/", "Edge_setEffortResponse");
    private final static QName _InductionloopGetLastStepVehicleIDsResponse_QNAME = new QName("http://ws.tudresden.de/", "Inductionloop_getLastStepVehicleIDsResponse");
    private final static QName _JunctionGetPosition_QNAME = new QName("http://ws.tudresden.de/", "Junction_getPosition");
    private final static QName _TrafficlightsSetRedYellowGreenState_QNAME = new QName("http://ws.tudresden.de/", "Trafficlights_setRedYellowGreenState");
    private final static QName _PolygonSetTypeResponse_QNAME = new QName("http://ws.tudresden.de/", "Polygon_setTypeResponse");
    private final static QName _EdgeGetCOEmission_QNAME = new QName("http://ws.tudresden.de/", "Edge_getCOEmission");
    private final static QName _EdgeGetNoiseEmissionResponse_QNAME = new QName("http://ws.tudresden.de/", "Edge_getNoiseEmissionResponse");
    private final static QName _VehicleSetStopResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setStopResponse");
    private final static QName _VehicleGetMaxSpeed_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getMaxSpeed");
    private final static QName _VehicleGetFuelConsumption_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getFuelConsumption");
    private final static QName _TrafficlightsGetIDCount_QNAME = new QName("http://ws.tudresden.de/", "Trafficlights_getIDCount");
    private final static QName _VehicleSetTau_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setTau");
    private final static QName _ArealDetectorGetJamLengthVehicleResponse_QNAME = new QName("http://ws.tudresden.de/", "ArealDetector_getJamLengthVehicleResponse");
    private final static QName _MultientryexitGetLastStepMeanSpeedResponse_QNAME = new QName("http://ws.tudresden.de/", "Multientryexit_getLastStepMeanSpeedResponse");
    private final static QName _EdgeGetNOxEmission_QNAME = new QName("http://ws.tudresden.de/", "Edge_getNOxEmission");
    private final static QName _VehicleSetRouteResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setRouteResponse");
    private final static QName _PolygonGetShape_QNAME = new QName("http://ws.tudresden.de/", "Polygon_getShape");
    private final static QName _EdgeGetCO2EmissionResponse_QNAME = new QName("http://ws.tudresden.de/", "Edge_getCO2EmissionResponse");
    private final static QName _PolygonGetIDList_QNAME = new QName("http://ws.tudresden.de/", "Polygon_getIDList");
    private final static QName _PoiRemove_QNAME = new QName("http://ws.tudresden.de/", "Poi_remove");
    private final static QName _VehicleSetEmissionClass_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setEmissionClass");
    private final static QName _LaneGetLastStepVehicleNumberResponse_QNAME = new QName("http://ws.tudresden.de/", "Lane_getLastStepVehicleNumberResponse");
    private final static QName _VehicletypeGetEmissionClassResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_getEmissionClassResponse");
    private final static QName _VehicleSetAdaptedTraveltimeResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setAdaptedTraveltimeResponse");
    private final static QName _TrafficlightsGetNextSwitchResponse_QNAME = new QName("http://ws.tudresden.de/", "Trafficlights_getNextSwitchResponse");
    private final static QName _VehicletypeGetSpeedDeviationResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_getSpeedDeviationResponse");
    private final static QName _VehicleGetLaneID_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getLaneID");
    private final static QName _VehicletypeGetDecel_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_getDecel");
    private final static QName _VehicleSetRouteID_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setRouteID");
    private final static QName _VehicleGetAllowedSpeedResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getAllowedSpeedResponse");
    private final static QName _TrafficlightsGetRedYellowGreenStateResponse_QNAME = new QName("http://ws.tudresden.de/", "Trafficlights_getRedYellowGreenStateResponse");
    private final static QName _GUISetOffsetResponse_QNAME = new QName("http://ws.tudresden.de/", "GUI_setOffsetResponse");
    private final static QName _VehicleGetAccelResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getAccelResponse");
    private final static QName _VehicleGetBestLanesResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getBestLanesResponse");
    private final static QName _VehicleGetLaneIDResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getLaneIDResponse");
    private final static QName _VehicleGetPersonNumberResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getPersonNumberResponse");
    private final static QName _VehicleGetPMxEmissionResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getPMxEmissionResponse");
    private final static QName _VehicletypeSetWidth_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_setWidth");
    private final static QName _PolygonSetShapeResponse_QNAME = new QName("http://ws.tudresden.de/", "Polygon_setShapeResponse");
    private final static QName _PolygonGetTypeResponse_QNAME = new QName("http://ws.tudresden.de/", "Polygon_getTypeResponse");
    private final static QName _LaneGetIDCountResponse_QNAME = new QName("http://ws.tudresden.de/", "Lane_getIDCountResponse");
    private final static QName _SimulationGetParkingStartingVehiclesIDListResponse_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getParkingStartingVehiclesIDListResponse");
    private final static QName _PoiGetIDCount_QNAME = new QName("http://ws.tudresden.de/", "Poi_getIDCount");
    private final static QName _PolygonGetColor_QNAME = new QName("http://ws.tudresden.de/", "Polygon_getColor");
    private final static QName _PoiSetColorResponse_QNAME = new QName("http://ws.tudresden.de/", "Poi_setColorResponse");
    private final static QName _LaneSetLengthResponse_QNAME = new QName("http://ws.tudresden.de/", "Lane_setLengthResponse");
    private final static QName _LaneGetMaxSpeedResponse_QNAME = new QName("http://ws.tudresden.de/", "Lane_getMaxSpeedResponse");
    private final static QName _VehicleGetEmissionClass_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getEmissionClass");
    private final static QName _VehicleGetTypeIDResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getTypeIDResponse");
    private final static QName _TrafficlightsGetPhaseResponse_QNAME = new QName("http://ws.tudresden.de/", "Trafficlights_getPhaseResponse");
    private final static QName _VehicleGetImperfection_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getImperfection");
    private final static QName _EdgeGetLastStepOccupancy_QNAME = new QName("http://ws.tudresden.de/", "Edge_getLastStepOccupancy");
    private final static QName _VehicletypeGetTauResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_getTauResponse");
    private final static QName _EdgeGetLastStepVehicleIDsResponse_QNAME = new QName("http://ws.tudresden.de/", "Edge_getLastStepVehicleIDsResponse");
    private final static QName _VehicletypeSetVehicleClass_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_setVehicleClass");
    private final static QName _VehicleGetSpeedWithoutTraCI_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getSpeedWithoutTraCI");
    private final static QName _JunctionGetIDList_QNAME = new QName("http://ws.tudresden.de/", "Junction_getIDList");
    private final static QName _VehicletypeGetVehicleClassResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_getVehicleClassResponse");
    private final static QName _LaneGetLinks_QNAME = new QName("http://ws.tudresden.de/", "Lane_getLinks");
    private final static QName _SimulationGetArrivedIDListResponse_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getArrivedIDListResponse");
    private final static QName _EdgeGetIDListResponse_QNAME = new QName("http://ws.tudresden.de/", "Edge_getIDListResponse");
    private final static QName _ArealDetectorGetJamLengthMeters_QNAME = new QName("http://ws.tudresden.de/", "ArealDetector_getJamLengthMeters");
    private final static QName _ArealDetectorGetIDList_QNAME = new QName("http://ws.tudresden.de/", "ArealDetector_getIDList");
    private final static QName _LaneGetLastStepMeanSpeedResponse_QNAME = new QName("http://ws.tudresden.de/", "Lane_getLastStepMeanSpeedResponse");
    private final static QName _TrafficlightsGetCompleteRedYellowGreenDefinitionResponse_QNAME = new QName("http://ws.tudresden.de/", "Trafficlights_getCompleteRedYellowGreenDefinitionResponse");
    private final static QName _TrafficlightsGetControlledLanes_QNAME = new QName("http://ws.tudresden.de/", "Trafficlights_getControlledLanes");
    private final static QName _MultientryexitGetIDList_QNAME = new QName("http://ws.tudresden.de/", "Multientryexit_getIDList");
    private final static QName _LaneGetShapeResponse_QNAME = new QName("http://ws.tudresden.de/", "Lane_getShapeResponse");
    private final static QName _JunctionGetIDCount_QNAME = new QName("http://ws.tudresden.de/", "Junction_getIDCount");
    private final static QName _VehicleGetSpeedDeviation_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getSpeedDeviation");
    private final static QName _VehicleGetVehicleClassResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getVehicleClassResponse");
    private final static QName _VehicleGetCO2Emission_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getCO2Emission");
    private final static QName _VehicletypeGetIDCountResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_getIDCountResponse");
    private final static QName _VehicleGetLaneIndex_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getLaneIndex");
    private final static QName _LaneGetLength_QNAME = new QName("http://ws.tudresden.de/", "Lane_getLength");
    private final static QName _SimulationGetParkingStartingVehiclesNumber_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getParkingStartingVehiclesNumber");
    private final static QName _SimulationConvert2DResponse_QNAME = new QName("http://ws.tudresden.de/", "Simulation_convert2DResponse");
    private final static QName _PoiAddResponse_QNAME = new QName("http://ws.tudresden.de/", "Poi_addResponse");
    private final static QName _ArealDetectorGetJamLengthMetersResponse_QNAME = new QName("http://ws.tudresden.de/", "ArealDetector_getJamLengthMetersResponse");
    private final static QName _VehicleGetDistanceResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getDistanceResponse");
    private final static QName _EdgeSetMaxSpeed_QNAME = new QName("http://ws.tudresden.de/", "Edge_setMaxSpeed");
    private final static QName _VehicletypeSetAccel_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_setAccel");
    private final static QName _VehicleGetDrivingDistance2DResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getDrivingDistance2DResponse");
    private final static QName _LaneGetLastStepVehicleIDs_QNAME = new QName("http://ws.tudresden.de/", "Lane_getLastStepVehicleIDs");
    private final static QName _RouteGetEdges_QNAME = new QName("http://ws.tudresden.de/", "Route_getEdges");
    private final static QName _InductionloopGetLastStepMeanSpeedResponse_QNAME = new QName("http://ws.tudresden.de/", "Inductionloop_getLastStepMeanSpeedResponse");
    private final static QName _EdgeGetLastStepVehicleNumber_QNAME = new QName("http://ws.tudresden.de/", "Edge_getLastStepVehicleNumber");
    private final static QName _GUISetZoomResponse_QNAME = new QName("http://ws.tudresden.de/", "GUI_setZoomResponse");
    private final static QName _LaneSetAllowedResponse_QNAME = new QName("http://ws.tudresden.de/", "Lane_setAllowedResponse");
    private final static QName _JunctionGetIDCountResponse_QNAME = new QName("http://ws.tudresden.de/", "Junction_getIDCountResponse");
    private final static QName _TrafficlightsSetProgramResponse_QNAME = new QName("http://ws.tudresden.de/", "Trafficlights_setProgramResponse");
    private final static QName _VehicleGetCOEmission_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getCOEmission");
    private final static QName _InductionloopGetIDCount_QNAME = new QName("http://ws.tudresden.de/", "Inductionloop_getIDCount");
    private final static QName _VehicleGetSpeedResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getSpeedResponse");
    private final static QName _SimulationGetDepartedIDList_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getDepartedIDList");
    private final static QName _GUIGetZoomResponse_QNAME = new QName("http://ws.tudresden.de/", "GUI_getZoomResponse");
    private final static QName _VehicleSetWidth_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setWidth");
    private final static QName _GUITrackVehicleResponse_QNAME = new QName("http://ws.tudresden.de/", "GUI_trackVehicleResponse");
    private final static QName _VehicleGetNoiseEmissionResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getNoiseEmissionResponse");
    private final static QName _VehicleSetMaxSpeedResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setMaxSpeedResponse");
    private final static QName _VehicletypeGetSpeedFactor_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_getSpeedFactor");
    private final static QName _LaneGetNoiseEmissionResponse_QNAME = new QName("http://ws.tudresden.de/", "Lane_getNoiseEmissionResponse");
    private final static QName _VehicleSetSpeedResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setSpeedResponse");
    private final static QName _VehicleChangeLaneResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_changeLaneResponse");
    private final static QName _GUISetZoom_QNAME = new QName("http://ws.tudresden.de/", "GUI_setZoom");
    private final static QName _PoiGetType_QNAME = new QName("http://ws.tudresden.de/", "Poi_getType");
    private final static QName _VehicleRemoveResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_removeResponse");
    private final static QName _EdgeGetLastStepHaltingNumber_QNAME = new QName("http://ws.tudresden.de/", "Edge_getLastStepHaltingNumber");
    private final static QName _VehicleGetSignals_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getSignals");
    private final static QName _LaneGetLengthResponse_QNAME = new QName("http://ws.tudresden.de/", "Lane_getLengthResponse");
    private final static QName _EdgeGetCO2Emission_QNAME = new QName("http://ws.tudresden.de/", "Edge_getCO2Emission");
    private final static QName _VehicletypeSetDecelResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_setDecelResponse");
    private final static QName _VehicleSetDecel_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setDecel");
    private final static QName _LaneGetLastStepLength_QNAME = new QName("http://ws.tudresden.de/", "Lane_getLastStepLength");
    private final static QName _SimulationGetStartingTeleportIDList_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getStartingTeleportIDList");
    private final static QName _VehicletypeSetMaxSpeed_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_setMaxSpeed");
    private final static QName _GUIGetZoom_QNAME = new QName("http://ws.tudresden.de/", "GUI_getZoom");
    private final static QName _VehicleGetIDCountResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getIDCountResponse");
    private final static QName _PoiSetColor_QNAME = new QName("http://ws.tudresden.de/", "Poi_setColor");
    private final static QName _VehicletypeGetSpeedDeviation_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_getSpeedDeviation");
    private final static QName _VehicletypeSetTauResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_setTauResponse");
    private final static QName _SimulationGetStopEndingVehiclesIDListResponse_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getStopEndingVehiclesIDListResponse");
    private final static QName _RouteAddResponse_QNAME = new QName("http://ws.tudresden.de/", "Route_addResponse");
    private final static QName _SetSumoBinary_QNAME = new QName("http://ws.tudresden.de/", "setSumoBinary");
    private final static QName _EdgeGetHCEmission_QNAME = new QName("http://ws.tudresden.de/", "Edge_getHCEmission");
    private final static QName _VehicleSetLaneChangeMode_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setLaneChangeMode");
    private final static QName _EdgeGetLastStepHaltingNumberResponse_QNAME = new QName("http://ws.tudresden.de/", "Edge_getLastStepHaltingNumberResponse");
    private final static QName _VehicleSlowDown_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_slowDown");
    private final static QName _VehicleGetDecel_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getDecel");
    private final static QName _EdgeGetPMxEmissionResponse_QNAME = new QName("http://ws.tudresden.de/", "Edge_getPMxEmissionResponse");
    private final static QName _GUIScreenshot_QNAME = new QName("http://ws.tudresden.de/", "GUI_screenshot");
    private final static QName _LaneGetFuelConsumptionResponse_QNAME = new QName("http://ws.tudresden.de/", "Lane_getFuelConsumptionResponse");
    private final static QName _MultientryexitGetLastStepVehicleIDsResponse_QNAME = new QName("http://ws.tudresden.de/", "Multientryexit_getLastStepVehicleIDsResponse");
    private final static QName _VehicleSetImperfection_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setImperfection");
    private final static QName _VehicletypeSetSpeedFactor_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_setSpeedFactor");
    private final static QName _VehicletypeSetSpeedFactorResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_setSpeedFactorResponse");
    private final static QName _VehicletypeSetAccelResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_setAccelResponse");
    private final static QName _EdgeGetEffortResponse_QNAME = new QName("http://ws.tudresden.de/", "Edge_getEffortResponse");
    private final static QName _ArealDetectorGetIDListResponse_QNAME = new QName("http://ws.tudresden.de/", "ArealDetector_getIDListResponse");
    private final static QName _VehicletypeSetColorResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_setColorResponse");
    private final static QName _SimulationGetArrivedNumberResponse_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getArrivedNumberResponse");
    private final static QName _LaneGetDisallowed_QNAME = new QName("http://ws.tudresden.de/", "Lane_getDisallowed");
    private final static QName _SimulationGetStartingTeleportNumber_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getStartingTeleportNumber");
    private final static QName _LaneGetAllowedResponse_QNAME = new QName("http://ws.tudresden.de/", "Lane_getAllowedResponse");
    private final static QName _VehicleMoveTo_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_moveTo");
    private final static QName _VehicleGetWidthResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getWidthResponse");
    private final static QName _EdgeAdaptTraveltimeResponse_QNAME = new QName("http://ws.tudresden.de/", "Edge_adaptTraveltimeResponse");
    private final static QName _VehicletypeGetShapeClass_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_getShapeClass");
    private final static QName _InductionloopGetLastStepOccupancy_QNAME = new QName("http://ws.tudresden.de/", "Inductionloop_getLastStepOccupancy");
    private final static QName _VehicleRerouteEffortResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_rerouteEffortResponse");
    private final static QName _VehicleGetDrivingDistance_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getDrivingDistance");
    private final static QName _InductionloopGetIDList_QNAME = new QName("http://ws.tudresden.de/", "Inductionloop_getIDList");
    private final static QName _VehicletypeSetDecel_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_setDecel");
    private final static QName _VehicleGetWaitingTimeResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getWaitingTimeResponse");
    private final static QName _VehicleGetShapeClassResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getShapeClassResponse");
    private final static QName _LaneGetHCEmissionResponse_QNAME = new QName("http://ws.tudresden.de/", "Lane_getHCEmissionResponse");
    private final static QName _VehicletypeSetColor_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_setColor");
    private final static QName _VehicleSlowDownResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_slowDownResponse");
    private final static QName _ArealDetectorGetIDCount_QNAME = new QName("http://ws.tudresden.de/", "ArealDetector_getIDCount");
    private final static QName _InductionloopGetPosition_QNAME = new QName("http://ws.tudresden.de/", "Inductionloop_getPosition");
    private final static QName _VehicleGetDrivingDistanceResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getDrivingDistanceResponse");
    private final static QName _SimulationGetMinExpectedNumberResponse_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getMinExpectedNumberResponse");
    private final static QName _VehicleGetAngleResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getAngleResponse");
    private final static QName _VehicletypeGetMaxSpeedResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_getMaxSpeedResponse");
    private final static QName _VehicleGetShapeClass_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getShapeClass");
    private final static QName _VehicleGetEffortResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getEffortResponse");
    private final static QName _VehicleGetFuelConsumptionResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getFuelConsumptionResponse");
    private final static QName _GUISetSchema_QNAME = new QName("http://ws.tudresden.de/", "GUI_setSchema");
    private final static QName _InductionloopGetIDListResponse_QNAME = new QName("http://ws.tudresden.de/", "Inductionloop_getIDListResponse");
    private final static QName _VehicletypeGetIDCount_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_getIDCount");
    private final static QName _SimulationGetStopStartingVehiclesNumber_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getStopStartingVehiclesNumber");
    private final static QName _VehicletypeSetMaxSpeedResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_setMaxSpeedResponse");
    private final static QName _SimulationGetArrivedNumber_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getArrivedNumber");
    private final static QName _TrafficlightsGetControlledLinksResponse_QNAME = new QName("http://ws.tudresden.de/", "Trafficlights_getControlledLinksResponse");
    private final static QName _VehicleSetMinGapResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setMinGapResponse");
    private final static QName _GUITrackVehicle_QNAME = new QName("http://ws.tudresden.de/", "GUI_trackVehicle");
    private final static QName _VehicleGetLength_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getLength");
    private final static QName _VehicleGetWidth_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getWidth");
    private final static QName _SimulationGetDistance2DResponse_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getDistance2DResponse");
    private final static QName _LaneGetWaitingTimeResponse_QNAME = new QName("http://ws.tudresden.de/", "Lane_getWaitingTimeResponse");
    private final static QName _PoiSetType_QNAME = new QName("http://ws.tudresden.de/", "Poi_setType");
    private final static QName _TrafficlightsGetPhaseDurationResponse_QNAME = new QName("http://ws.tudresden.de/", "Trafficlights_getPhaseDurationResponse");
    private final static QName _VehicleSetVehicleClassResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setVehicleClassResponse");
    private final static QName _VehicleSetEffort_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setEffort");
    private final static QName _TrafficlightsSetPhase_QNAME = new QName("http://ws.tudresden.de/", "Trafficlights_setPhase");
    private final static QName _VehicletypeGetWidth_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_getWidth");
    private final static QName _VehicleRerouteTraveltimeResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_rerouteTraveltimeResponse");
    private final static QName _InductionloopGetVehicleData_QNAME = new QName("http://ws.tudresden.de/", "Inductionloop_getVehicleData");
    private final static QName _VehicletypeGetAccel_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_getAccel");
    private final static QName _InductionloopGetPositionResponse_QNAME = new QName("http://ws.tudresden.de/", "Inductionloop_getPositionResponse");
    private final static QName _TrafficlightsGetCompleteRedYellowGreenDefinition_QNAME = new QName("http://ws.tudresden.de/", "Trafficlights_getCompleteRedYellowGreenDefinition");
    private final static QName _VehicleSetStop_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setStop");
    private final static QName _TXTOutputResponse_QNAME = new QName("http://ws.tudresden.de/", "TXT_outputResponse");
    private final static QName _LaneGetWaitingTime_QNAME = new QName("http://ws.tudresden.de/", "Lane_getWaitingTime");
    private final static QName _VehicleGetSignalsResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getSignalsResponse");
    private final static QName _InductionloopGetLastStepVehicleIDs_QNAME = new QName("http://ws.tudresden.de/", "Inductionloop_getLastStepVehicleIDs");
    private final static QName _MultientryexitGetLastStepHaltingNumber_QNAME = new QName("http://ws.tudresden.de/", "Multientryexit_getLastStepHaltingNumber");
    private final static QName _SimulationGetDeltaTResponse_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getDeltaTResponse");
    private final static QName _PolygonSetColor_QNAME = new QName("http://ws.tudresden.de/", "Polygon_setColor");
    private final static QName _LastActionTime_QNAME = new QName("http://ws.tudresden.de/", "LastActionTime");
    private final static QName _EdgeGetIDCountResponse_QNAME = new QName("http://ws.tudresden.de/", "Edge_getIDCountResponse");
    private final static QName _VehicleGetAdaptedTraveltimeResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getAdaptedTraveltimeResponse");
    private final static QName _TrafficlightsSetProgram_QNAME = new QName("http://ws.tudresden.de/", "Trafficlights_setProgram");
    private final static QName _VehicleGetPMxEmission_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getPMxEmission");
    private final static QName _TrafficlightsGetIDCountResponse_QNAME = new QName("http://ws.tudresden.de/", "Trafficlights_getIDCountResponse");
    private final static QName _StopResponse_QNAME = new QName("http://ws.tudresden.de/", "stopResponse");
    private final static QName _SetConfigResponse_QNAME = new QName("http://ws.tudresden.de/", "setConfigResponse");
    private final static QName _VehicleSetImperfectionResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setImperfectionResponse");
    private final static QName _VehicleChangeTarget_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_changeTarget");
    private final static QName _VehicleGetMinGap_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getMinGap");
    private final static QName _VehicletypeGetEmissionClass_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_getEmissionClass");
    private final static QName _EdgeGetLastStepMeanSpeed_QNAME = new QName("http://ws.tudresden.de/", "Edge_getLastStepMeanSpeed");
    private final static QName _MultientryexitGetLastStepVehicleIDs_QNAME = new QName("http://ws.tudresden.de/", "Multientryexit_getLastStepVehicleIDs");
    private final static QName _LaneSetLength_QNAME = new QName("http://ws.tudresden.de/", "Lane_setLength");
    private final static QName _VehicleGetSpeed_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getSpeed");
    private final static QName _VehicletypeGetColorResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_getColorResponse");
    private final static QName _RouteGetIDList_QNAME = new QName("http://ws.tudresden.de/", "Route_getIDList");
    private final static QName _EdgeGetPMxEmission_QNAME = new QName("http://ws.tudresden.de/", "Edge_getPMxEmission");
    private final static QName _VehicleMoveToVTD_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_moveToVTD");
    private final static QName _SimulationGetStopEndingVehiclesIDList_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getStopEndingVehiclesIDList");
    private final static QName _VehicleGetDecelResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getDecelResponse");
    private final static QName _VehicleGetLanePositionResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getLanePositionResponse");
    private final static QName _VehicleGetTau_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getTau");
    private final static QName _LaneGetCO2EmissionResponse_QNAME = new QName("http://ws.tudresden.de/", "Lane_getCO2EmissionResponse");
    private final static QName _VehicleMoveToResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_moveToResponse");
    private final static QName _MultientryexitGetLastStepHaltingNumberResponse_QNAME = new QName("http://ws.tudresden.de/", "Multientryexit_getLastStepHaltingNumberResponse");
    private final static QName _VehicletypeGetImperfection_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_getImperfection");
    private final static QName _SimulationGetStartingTeleportIDListResponse_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getStartingTeleportIDListResponse");
    private final static QName _VehicleSetShapeClass_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setShapeClass");
    private final static QName _EdgeGetIDCount_QNAME = new QName("http://ws.tudresden.de/", "Edge_getIDCount");
    private final static QName _VehicletypeGetDecelResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_getDecelResponse");
    private final static QName _VehicletypeGetWidthResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_getWidthResponse");
    private final static QName _LaneSetDisallowedResponse_QNAME = new QName("http://ws.tudresden.de/", "Lane_setDisallowedResponse");
    private final static QName _VehicleSetSpeedFactor_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setSpeedFactor");
    private final static QName _VehicleGetHCEmission_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getHCEmission");
    private final static QName _VehicleGetPersonNumber_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getPersonNumber");
    private final static QName _PoiAdd_QNAME = new QName("http://ws.tudresden.de/", "Poi_add");
    private final static QName _VehicleSetEffortResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setEffortResponse");
    private final static QName _SimulationGetStopStartingVehiclesNumberResponse_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getStopStartingVehiclesNumberResponse");
    private final static QName _VehicleGetCO2EmissionResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getCO2EmissionResponse");
    private final static QName _LaneGetNOxEmission_QNAME = new QName("http://ws.tudresden.de/", "Lane_getNOxEmission");
    private final static QName _VehicletypeSetVehicleClassResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_setVehicleClassResponse");
    private final static QName _RouteGetEdgesResponse_QNAME = new QName("http://ws.tudresden.de/", "Route_getEdgesResponse");
    private final static QName _VehicleGetEmissionClassResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getEmissionClassResponse");
    private final static QName _InductionloopGetLaneIDResponse_QNAME = new QName("http://ws.tudresden.de/", "Inductionloop_getLaneIDResponse");
    private final static QName _LaneSetMaxSpeed_QNAME = new QName("http://ws.tudresden.de/", "Lane_setMaxSpeed");
    private final static QName _GUIGetSchemaResponse_QNAME = new QName("http://ws.tudresden.de/", "GUI_getSchemaResponse");
    private final static QName _PoiGetIDList_QNAME = new QName("http://ws.tudresden.de/", "Poi_getIDList");
    private final static QName _TrafficlightsGetIDList_QNAME = new QName("http://ws.tudresden.de/", "Trafficlights_getIDList");
    private final static QName _SimulationGetStopEndingVehiclesNumber_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getStopEndingVehiclesNumber");
    private final static QName _EdgeGetIDList_QNAME = new QName("http://ws.tudresden.de/", "Edge_getIDList");
    private final static QName _PolygonRemoveResponse_QNAME = new QName("http://ws.tudresden.de/", "Polygon_removeResponse");
    private final static QName _InductionloopGetLastStepVehicleNumber_QNAME = new QName("http://ws.tudresden.de/", "Inductionloop_getLastStepVehicleNumber");
    private final static QName _VehicleSetColorResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setColorResponse");
    private final static QName _VehicleGetColor_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getColor");
    private final static QName _VehicleChangeTargetResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_changeTargetResponse");
    private final static QName _VehicleAddResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_addResponse");
    private final static QName _SimulationGetDepartedIDListResponse_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getDepartedIDListResponse");
    private final static QName _EdgeGetLastStepLengthResponse_QNAME = new QName("http://ws.tudresden.de/", "Edge_getLastStepLengthResponse");
    private final static QName _SimulationGetCurrentTimeResponse_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getCurrentTimeResponse");
    private final static QName _EdgeGetFuelConsumptionResponse_QNAME = new QName("http://ws.tudresden.de/", "Edge_getFuelConsumptionResponse");
    private final static QName _LaneGetLastStepLengthResponse_QNAME = new QName("http://ws.tudresden.de/", "Lane_getLastStepLengthResponse");
    private final static QName _PoiGetPosition_QNAME = new QName("http://ws.tudresden.de/", "Poi_getPosition");
    private final static QName _PoiSetPosition_QNAME = new QName("http://ws.tudresden.de/", "Poi_setPosition");
    private final static QName _SimulationGetLoadedIDListResponse_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getLoadedIDListResponse");
    private final static QName _VehicleGetWaitingTime_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getWaitingTime");
    private final static QName _MultientryexitGetLastStepVehicleNumber_QNAME = new QName("http://ws.tudresden.de/", "Multientryexit_getLastStepVehicleNumber");
    private final static QName _VehicleSetMaxSpeed_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setMaxSpeed");
    private final static QName _LaneGetPMxEmissionResponse_QNAME = new QName("http://ws.tudresden.de/", "Lane_getPMxEmissionResponse");
    private final static QName _SimulationGetStopStartingVehiclesIDList_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getStopStartingVehiclesIDList");
    private final static QName _VehicleSetSpeedDeviationResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setSpeedDeviationResponse");
    private final static QName _SimulationGetStopStartingVehiclesIDListResponse_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getStopStartingVehiclesIDListResponse");
    private final static QName _VehicleGetRouteID_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getRouteID");
    private final static QName _GUISetBoundary_QNAME = new QName("http://ws.tudresden.de/", "GUI_setBoundary");
    private final static QName _InductionloopGetTimeSinceDetection_QNAME = new QName("http://ws.tudresden.de/", "Inductionloop_getTimeSinceDetection");
    private final static QName _SetSumoBinaryResponse_QNAME = new QName("http://ws.tudresden.de/", "setSumoBinaryResponse");
    private final static QName _EdgeSetMaxSpeedResponse_QNAME = new QName("http://ws.tudresden.de/", "Edge_setMaxSpeedResponse");
    private final static QName _InductionloopGetLaneID_QNAME = new QName("http://ws.tudresden.de/", "Inductionloop_getLaneID");
    private final static QName _TrafficlightsSetRedYellowGreenStateResponse_QNAME = new QName("http://ws.tudresden.de/", "Trafficlights_setRedYellowGreenStateResponse");
    private final static QName _GUIScreenshotResponse_QNAME = new QName("http://ws.tudresden.de/", "GUI_screenshotResponse");
    private final static QName _VehicletypeSetImperfectionResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_setImperfectionResponse");
    private final static QName _VehicletypeGetAccelResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_getAccelResponse");
    private final static QName _VehicletypeGetMaxSpeed_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_getMaxSpeed");
    private final static QName _PoiSetTypeResponse_QNAME = new QName("http://ws.tudresden.de/", "Poi_setTypeResponse");
    private final static QName _VehicleGetTypeID_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getTypeID");
    private final static QName _JunctionGetPositionResponse_QNAME = new QName("http://ws.tudresden.de/", "Junction_getPositionResponse");
    private final static QName _MultientryexitGetLastStepMeanSpeed_QNAME = new QName("http://ws.tudresden.de/", "Multientryexit_getLastStepMeanSpeed");
    private final static QName _SimulationGetDepartedNumber_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getDepartedNumber");
    private final static QName _SimulationGetParkingStartingVehiclesIDList_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getParkingStartingVehiclesIDList");
    private final static QName _LaneGetTraveltimeResponse_QNAME = new QName("http://ws.tudresden.de/", "Lane_getTraveltimeResponse");
    private final static QName _PolygonGetType_QNAME = new QName("http://ws.tudresden.de/", "Polygon_getType");
    private final static QName _VehicletypeSetTau_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_setTau");
    private final static QName _ArealDetectorGetIDCountResponse_QNAME = new QName("http://ws.tudresden.de/", "ArealDetector_getIDCountResponse");
    private final static QName _GUISetBoundaryResponse_QNAME = new QName("http://ws.tudresden.de/", "GUI_setBoundaryResponse");
    private final static QName _VehicleGetRouteIDResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getRouteIDResponse");
    private final static QName _LaneGetLastStepOccupancy_QNAME = new QName("http://ws.tudresden.de/", "Lane_getLastStepOccupancy");
    private final static QName _VehicletypeGetLength_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_getLength");
    private final static QName _InductionloopGetLastStepMeanLengthResponse_QNAME = new QName("http://ws.tudresden.de/", "Inductionloop_getLastStepMeanLengthResponse");
    private final static QName _VehicletypeGetLengthResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_getLengthResponse");
    private final static QName _LaneGetHCEmission_QNAME = new QName("http://ws.tudresden.de/", "Lane_getHCEmission");
    private final static QName _EdgeGetWaitingTime_QNAME = new QName("http://ws.tudresden.de/", "Edge_getWaitingTime");
    private final static QName _MultientryexitGetLastStepVehicleNumberResponse_QNAME = new QName("http://ws.tudresden.de/", "Multientryexit_getLastStepVehicleNumberResponse");
    private final static QName _JunctionGetShapeResponse_QNAME = new QName("http://ws.tudresden.de/", "Junction_getShapeResponse");
    private final static QName _LaneGetShape_QNAME = new QName("http://ws.tudresden.de/", "Lane_getShape");
    private final static QName _RouteGetIDCount_QNAME = new QName("http://ws.tudresden.de/", "Route_getIDCount");
    private final static QName _VehicletypeSetEmissionClass_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_setEmissionClass");
    private final static QName _TrafficlightsSetPhaseDuration_QNAME = new QName("http://ws.tudresden.de/", "Trafficlights_setPhaseDuration");
    private final static QName _TrafficlightsGetNextSwitch_QNAME = new QName("http://ws.tudresden.de/", "Trafficlights_getNextSwitch");
    private final static QName _SimulationGetEndingTeleportIDListResponse_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getEndingTeleportIDListResponse");
    private final static QName _SimulationGetStopEndingVehiclesNumberResponse_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getStopEndingVehiclesNumberResponse");
    private final static QName _SimulationGetBusStopWaiting_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getBusStopWaiting");
    private final static QName _TrafficlightsSetPhaseResponse_QNAME = new QName("http://ws.tudresden.de/", "Trafficlights_setPhaseResponse");
    private final static QName _EdgeSetEffort_QNAME = new QName("http://ws.tudresden.de/", "Edge_setEffort");
    private final static QName _VehicleSetLength_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setLength");
    private final static QName _VehicleGetAccel_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getAccel");
    private final static QName _GUISetOffset_QNAME = new QName("http://ws.tudresden.de/", "GUI_setOffset");
    private final static QName _TrafficlightsSetPhaseDurationResponse_QNAME = new QName("http://ws.tudresden.de/", "Trafficlights_setPhaseDurationResponse");
    private final static QName _SimulationGetDeltaT_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getDeltaT");
    private final static QName _TrafficlightsGetProgram_QNAME = new QName("http://ws.tudresden.de/", "Trafficlights_getProgram");
    private final static QName _VehicleRerouteEffort_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_rerouteEffort");
    private final static QName _VehicletypeGetMinGap_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_getMinGap");
    private final static QName _VehicleGetBestLanes_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_getBestLanes");
    private final static QName _SimulationGetCurrentTime_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getCurrentTime");
    private final static QName _VehicleSetDecelResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setDecelResponse");
    private final static QName _GUIGetOffset_QNAME = new QName("http://ws.tudresden.de/", "GUI_getOffset");
    private final static QName _LaneGetLastStepOccupancyResponse_QNAME = new QName("http://ws.tudresden.de/", "Lane_getLastStepOccupancyResponse");
    private final static QName _InductionloopGetTimeSinceDetectionResponse_QNAME = new QName("http://ws.tudresden.de/", "Inductionloop_getTimeSinceDetectionResponse");
    private final static QName _VehicleSetTauResponse_QNAME = new QName("http://ws.tudresden.de/", "Vehicle_setTauResponse");
    private final static QName _EdgeGetNoiseEmission_QNAME = new QName("http://ws.tudresden.de/", "Edge_getNoiseEmission");
    private final static QName _PoiGetColorResponse_QNAME = new QName("http://ws.tudresden.de/", "Poi_getColorResponse");
    private final static QName _MultientryexitGetIDListResponse_QNAME = new QName("http://ws.tudresden.de/", "Multientryexit_getIDListResponse");
    private final static QName _SimulationGetParkingEndingVehiclesIDList_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getParkingEndingVehiclesIDList");
    private final static QName _MultientryexitGetIDCount_QNAME = new QName("http://ws.tudresden.de/", "Multientryexit_getIDCount");
    private final static QName _VehicletypeGetVehicleClass_QNAME = new QName("http://ws.tudresden.de/", "Vehicletype_getVehicleClass");
    private final static QName _SimulationGetNetBoundaryResponse_QNAME = new QName("http://ws.tudresden.de/", "Simulation_getNetBoundaryResponse");
    private final static QName _PolygonRemove_QNAME = new QName("http://ws.tudresden.de/", "Polygon_remove");
    private final static QName _LaneSetAllowed_QNAME = new QName("http://ws.tudresden.de/", "Lane_setAllowed");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: de.tudresden.ws
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link LaneGetCO2EmissionResponse }
     * 
     */
    public LaneGetCO2EmissionResponse createLaneGetCO2EmissionResponse() {
        return new LaneGetCO2EmissionResponse();
    }

    /**
     * Create an instance of {@link VehicleGetLanePositionResponse }
     * 
     */
    public VehicleGetLanePositionResponse createVehicleGetLanePositionResponse() {
        return new VehicleGetLanePositionResponse();
    }

    /**
     * Create an instance of {@link VehicleGetTau }
     * 
     */
    public VehicleGetTau createVehicleGetTau() {
        return new VehicleGetTau();
    }

    /**
     * Create an instance of {@link SimulationGetStartingTeleportIDListResponse }
     * 
     */
    public SimulationGetStartingTeleportIDListResponse createSimulationGetStartingTeleportIDListResponse() {
        return new SimulationGetStartingTeleportIDListResponse();
    }

    /**
     * Create an instance of {@link VehicleMoveToResponse }
     * 
     */
    public VehicleMoveToResponse createVehicleMoveToResponse() {
        return new VehicleMoveToResponse();
    }

    /**
     * Create an instance of {@link VehicletypeGetImperfection }
     * 
     */
    public VehicletypeGetImperfection createVehicletypeGetImperfection() {
        return new VehicletypeGetImperfection();
    }

    /**
     * Create an instance of {@link MultientryexitGetLastStepHaltingNumberResponse }
     * 
     */
    public MultientryexitGetLastStepHaltingNumberResponse createMultientryexitGetLastStepHaltingNumberResponse() {
        return new MultientryexitGetLastStepHaltingNumberResponse();
    }

    /**
     * Create an instance of {@link EdgeGetIDCount }
     * 
     */
    public EdgeGetIDCount createEdgeGetIDCount() {
        return new EdgeGetIDCount();
    }

    /**
     * Create an instance of {@link VehicletypeGetDecelResponse }
     * 
     */
    public VehicletypeGetDecelResponse createVehicletypeGetDecelResponse() {
        return new VehicletypeGetDecelResponse();
    }

    /**
     * Create an instance of {@link VehicleSetShapeClass }
     * 
     */
    public VehicleSetShapeClass createVehicleSetShapeClass() {
        return new VehicleSetShapeClass();
    }

    /**
     * Create an instance of {@link VehicletypeGetWidthResponse }
     * 
     */
    public VehicletypeGetWidthResponse createVehicletypeGetWidthResponse() {
        return new VehicletypeGetWidthResponse();
    }

    /**
     * Create an instance of {@link LaneSetDisallowedResponse }
     * 
     */
    public LaneSetDisallowedResponse createLaneSetDisallowedResponse() {
        return new LaneSetDisallowedResponse();
    }

    /**
     * Create an instance of {@link StopResponse }
     * 
     */
    public StopResponse createStopResponse() {
        return new StopResponse();
    }

    /**
     * Create an instance of {@link SetConfigResponse }
     * 
     */
    public SetConfigResponse createSetConfigResponse() {
        return new SetConfigResponse();
    }

    /**
     * Create an instance of {@link VehicleSetImperfectionResponse }
     * 
     */
    public VehicleSetImperfectionResponse createVehicleSetImperfectionResponse() {
        return new VehicleSetImperfectionResponse();
    }

    /**
     * Create an instance of {@link VehicleChangeTarget }
     * 
     */
    public VehicleChangeTarget createVehicleChangeTarget() {
        return new VehicleChangeTarget();
    }

    /**
     * Create an instance of {@link VehicleGetMinGap }
     * 
     */
    public VehicleGetMinGap createVehicleGetMinGap() {
        return new VehicleGetMinGap();
    }

    /**
     * Create an instance of {@link TrafficlightsSetProgram }
     * 
     */
    public TrafficlightsSetProgram createTrafficlightsSetProgram() {
        return new TrafficlightsSetProgram();
    }

    /**
     * Create an instance of {@link VehicleGetPMxEmission }
     * 
     */
    public VehicleGetPMxEmission createVehicleGetPMxEmission() {
        return new VehicleGetPMxEmission();
    }

    /**
     * Create an instance of {@link TrafficlightsGetIDCountResponse }
     * 
     */
    public TrafficlightsGetIDCountResponse createTrafficlightsGetIDCountResponse() {
        return new TrafficlightsGetIDCountResponse();
    }

    /**
     * Create an instance of {@link MultientryexitGetLastStepVehicleIDs }
     * 
     */
    public MultientryexitGetLastStepVehicleIDs createMultientryexitGetLastStepVehicleIDs() {
        return new MultientryexitGetLastStepVehicleIDs();
    }

    /**
     * Create an instance of {@link VehicletypeGetEmissionClass }
     * 
     */
    public VehicletypeGetEmissionClass createVehicletypeGetEmissionClass() {
        return new VehicletypeGetEmissionClass();
    }

    /**
     * Create an instance of {@link EdgeGetLastStepMeanSpeed }
     * 
     */
    public EdgeGetLastStepMeanSpeed createEdgeGetLastStepMeanSpeed() {
        return new EdgeGetLastStepMeanSpeed();
    }

    /**
     * Create an instance of {@link VehicletypeGetColorResponse }
     * 
     */
    public VehicletypeGetColorResponse createVehicletypeGetColorResponse() {
        return new VehicletypeGetColorResponse();
    }

    /**
     * Create an instance of {@link VehicleGetSpeed }
     * 
     */
    public VehicleGetSpeed createVehicleGetSpeed() {
        return new VehicleGetSpeed();
    }

    /**
     * Create an instance of {@link LaneSetLength }
     * 
     */
    public LaneSetLength createLaneSetLength() {
        return new LaneSetLength();
    }

    /**
     * Create an instance of {@link EdgeGetPMxEmission }
     * 
     */
    public EdgeGetPMxEmission createEdgeGetPMxEmission() {
        return new EdgeGetPMxEmission();
    }

    /**
     * Create an instance of {@link RouteGetIDList }
     * 
     */
    public RouteGetIDList createRouteGetIDList() {
        return new RouteGetIDList();
    }

    /**
     * Create an instance of {@link VehicleGetDecelResponse }
     * 
     */
    public VehicleGetDecelResponse createVehicleGetDecelResponse() {
        return new VehicleGetDecelResponse();
    }

    /**
     * Create an instance of {@link VehicleMoveToVTD }
     * 
     */
    public VehicleMoveToVTD createVehicleMoveToVTD() {
        return new VehicleMoveToVTD();
    }

    /**
     * Create an instance of {@link SimulationGetStopEndingVehiclesIDList }
     * 
     */
    public SimulationGetStopEndingVehiclesIDList createSimulationGetStopEndingVehiclesIDList() {
        return new SimulationGetStopEndingVehiclesIDList();
    }

    /**
     * Create an instance of {@link VehicleChangeTargetResponse }
     * 
     */
    public VehicleChangeTargetResponse createVehicleChangeTargetResponse() {
        return new VehicleChangeTargetResponse();
    }

    /**
     * Create an instance of {@link EdgeGetLastStepLengthResponse }
     * 
     */
    public EdgeGetLastStepLengthResponse createEdgeGetLastStepLengthResponse() {
        return new EdgeGetLastStepLengthResponse();
    }

    /**
     * Create an instance of {@link SimulationGetDepartedIDListResponse }
     * 
     */
    public SimulationGetDepartedIDListResponse createSimulationGetDepartedIDListResponse() {
        return new SimulationGetDepartedIDListResponse();
    }

    /**
     * Create an instance of {@link VehicleAddResponse }
     * 
     */
    public VehicleAddResponse createVehicleAddResponse() {
        return new VehicleAddResponse();
    }

    /**
     * Create an instance of {@link InductionloopGetLastStepVehicleNumber }
     * 
     */
    public InductionloopGetLastStepVehicleNumber createInductionloopGetLastStepVehicleNumber() {
        return new InductionloopGetLastStepVehicleNumber();
    }

    /**
     * Create an instance of {@link VehicleSetColorResponse }
     * 
     */
    public VehicleSetColorResponse createVehicleSetColorResponse() {
        return new VehicleSetColorResponse();
    }

    /**
     * Create an instance of {@link VehicleGetColor }
     * 
     */
    public VehicleGetColor createVehicleGetColor() {
        return new VehicleGetColor();
    }

    /**
     * Create an instance of {@link LaneGetLastStepLengthResponse }
     * 
     */
    public LaneGetLastStepLengthResponse createLaneGetLastStepLengthResponse() {
        return new LaneGetLastStepLengthResponse();
    }

    /**
     * Create an instance of {@link SimulationGetCurrentTimeResponse }
     * 
     */
    public SimulationGetCurrentTimeResponse createSimulationGetCurrentTimeResponse() {
        return new SimulationGetCurrentTimeResponse();
    }

    /**
     * Create an instance of {@link EdgeGetFuelConsumptionResponse }
     * 
     */
    public EdgeGetFuelConsumptionResponse createEdgeGetFuelConsumptionResponse() {
        return new EdgeGetFuelConsumptionResponse();
    }

    /**
     * Create an instance of {@link SimulationGetLoadedIDListResponse }
     * 
     */
    public SimulationGetLoadedIDListResponse createSimulationGetLoadedIDListResponse() {
        return new SimulationGetLoadedIDListResponse();
    }

    /**
     * Create an instance of {@link PoiGetPosition }
     * 
     */
    public PoiGetPosition createPoiGetPosition() {
        return new PoiGetPosition();
    }

    /**
     * Create an instance of {@link PoiSetPosition }
     * 
     */
    public PoiSetPosition createPoiSetPosition() {
        return new PoiSetPosition();
    }

    /**
     * Create an instance of {@link VehicleGetWaitingTime }
     * 
     */
    public VehicleGetWaitingTime createVehicleGetWaitingTime() {
        return new VehicleGetWaitingTime();
    }

    /**
     * Create an instance of {@link MultientryexitGetLastStepVehicleNumber }
     * 
     */
    public MultientryexitGetLastStepVehicleNumber createMultientryexitGetLastStepVehicleNumber() {
        return new MultientryexitGetLastStepVehicleNumber();
    }

    /**
     * Create an instance of {@link PoiAdd }
     * 
     */
    public PoiAdd createPoiAdd() {
        return new PoiAdd();
    }

    /**
     * Create an instance of {@link VehicleSetSpeedFactor }
     * 
     */
    public VehicleSetSpeedFactor createVehicleSetSpeedFactor() {
        return new VehicleSetSpeedFactor();
    }

    /**
     * Create an instance of {@link VehicleGetHCEmission }
     * 
     */
    public VehicleGetHCEmission createVehicleGetHCEmission() {
        return new VehicleGetHCEmission();
    }

    /**
     * Create an instance of {@link VehicleGetPersonNumber }
     * 
     */
    public VehicleGetPersonNumber createVehicleGetPersonNumber() {
        return new VehicleGetPersonNumber();
    }

    /**
     * Create an instance of {@link SimulationGetStopStartingVehiclesNumberResponse }
     * 
     */
    public SimulationGetStopStartingVehiclesNumberResponse createSimulationGetStopStartingVehiclesNumberResponse() {
        return new SimulationGetStopStartingVehiclesNumberResponse();
    }

    /**
     * Create an instance of {@link VehicleGetCO2EmissionResponse }
     * 
     */
    public VehicleGetCO2EmissionResponse createVehicleGetCO2EmissionResponse() {
        return new VehicleGetCO2EmissionResponse();
    }

    /**
     * Create an instance of {@link LaneGetNOxEmission }
     * 
     */
    public LaneGetNOxEmission createLaneGetNOxEmission() {
        return new LaneGetNOxEmission();
    }

    /**
     * Create an instance of {@link VehicleSetEffortResponse }
     * 
     */
    public VehicleSetEffortResponse createVehicleSetEffortResponse() {
        return new VehicleSetEffortResponse();
    }

    /**
     * Create an instance of {@link VehicleGetEmissionClassResponse }
     * 
     */
    public VehicleGetEmissionClassResponse createVehicleGetEmissionClassResponse() {
        return new VehicleGetEmissionClassResponse();
    }

    /**
     * Create an instance of {@link InductionloopGetLaneIDResponse }
     * 
     */
    public InductionloopGetLaneIDResponse createInductionloopGetLaneIDResponse() {
        return new InductionloopGetLaneIDResponse();
    }

    /**
     * Create an instance of {@link VehicletypeSetVehicleClassResponse }
     * 
     */
    public VehicletypeSetVehicleClassResponse createVehicletypeSetVehicleClassResponse() {
        return new VehicletypeSetVehicleClassResponse();
    }

    /**
     * Create an instance of {@link RouteGetEdgesResponse }
     * 
     */
    public RouteGetEdgesResponse createRouteGetEdgesResponse() {
        return new RouteGetEdgesResponse();
    }

    /**
     * Create an instance of {@link SimulationGetStopEndingVehiclesNumber }
     * 
     */
    public SimulationGetStopEndingVehiclesNumber createSimulationGetStopEndingVehiclesNumber() {
        return new SimulationGetStopEndingVehiclesNumber();
    }

    /**
     * Create an instance of {@link EdgeGetIDList }
     * 
     */
    public EdgeGetIDList createEdgeGetIDList() {
        return new EdgeGetIDList();
    }

    /**
     * Create an instance of {@link PolygonRemoveResponse }
     * 
     */
    public PolygonRemoveResponse createPolygonRemoveResponse() {
        return new PolygonRemoveResponse();
    }

    /**
     * Create an instance of {@link LaneSetMaxSpeed }
     * 
     */
    public LaneSetMaxSpeed createLaneSetMaxSpeed() {
        return new LaneSetMaxSpeed();
    }

    /**
     * Create an instance of {@link GUIGetSchemaResponse }
     * 
     */
    public GUIGetSchemaResponse createGUIGetSchemaResponse() {
        return new GUIGetSchemaResponse();
    }

    /**
     * Create an instance of {@link PoiGetIDList }
     * 
     */
    public PoiGetIDList createPoiGetIDList() {
        return new PoiGetIDList();
    }

    /**
     * Create an instance of {@link TrafficlightsGetIDList }
     * 
     */
    public TrafficlightsGetIDList createTrafficlightsGetIDList() {
        return new TrafficlightsGetIDList();
    }

    /**
     * Create an instance of {@link MultientryexitGetLastStepMeanSpeed }
     * 
     */
    public MultientryexitGetLastStepMeanSpeed createMultientryexitGetLastStepMeanSpeed() {
        return new MultientryexitGetLastStepMeanSpeed();
    }

    /**
     * Create an instance of {@link SimulationGetDepartedNumber }
     * 
     */
    public SimulationGetDepartedNumber createSimulationGetDepartedNumber() {
        return new SimulationGetDepartedNumber();
    }

    /**
     * Create an instance of {@link SimulationGetParkingStartingVehiclesIDList }
     * 
     */
    public SimulationGetParkingStartingVehiclesIDList createSimulationGetParkingStartingVehiclesIDList() {
        return new SimulationGetParkingStartingVehiclesIDList();
    }

    /**
     * Create an instance of {@link LaneGetTraveltimeResponse }
     * 
     */
    public LaneGetTraveltimeResponse createLaneGetTraveltimeResponse() {
        return new LaneGetTraveltimeResponse();
    }

    /**
     * Create an instance of {@link PoiSetTypeResponse }
     * 
     */
    public PoiSetTypeResponse createPoiSetTypeResponse() {
        return new PoiSetTypeResponse();
    }

    /**
     * Create an instance of {@link VehicleGetTypeID }
     * 
     */
    public VehicleGetTypeID createVehicleGetTypeID() {
        return new VehicleGetTypeID();
    }

    /**
     * Create an instance of {@link JunctionGetPositionResponse }
     * 
     */
    public JunctionGetPositionResponse createJunctionGetPositionResponse() {
        return new JunctionGetPositionResponse();
    }

    /**
     * Create an instance of {@link ArealDetectorGetIDCountResponse }
     * 
     */
    public ArealDetectorGetIDCountResponse createArealDetectorGetIDCountResponse() {
        return new ArealDetectorGetIDCountResponse();
    }

    /**
     * Create an instance of {@link GUISetBoundaryResponse }
     * 
     */
    public GUISetBoundaryResponse createGUISetBoundaryResponse() {
        return new GUISetBoundaryResponse();
    }

    /**
     * Create an instance of {@link PolygonGetType }
     * 
     */
    public PolygonGetType createPolygonGetType() {
        return new PolygonGetType();
    }

    /**
     * Create an instance of {@link VehicletypeSetTau }
     * 
     */
    public VehicletypeSetTau createVehicletypeSetTau() {
        return new VehicletypeSetTau();
    }

    /**
     * Create an instance of {@link VehicletypeGetLength }
     * 
     */
    public VehicletypeGetLength createVehicletypeGetLength() {
        return new VehicletypeGetLength();
    }

    /**
     * Create an instance of {@link VehicleGetRouteIDResponse }
     * 
     */
    public VehicleGetRouteIDResponse createVehicleGetRouteIDResponse() {
        return new VehicleGetRouteIDResponse();
    }

    /**
     * Create an instance of {@link LaneGetLastStepOccupancy }
     * 
     */
    public LaneGetLastStepOccupancy createLaneGetLastStepOccupancy() {
        return new LaneGetLastStepOccupancy();
    }

    /**
     * Create an instance of {@link MultientryexitGetLastStepVehicleNumberResponse }
     * 
     */
    public MultientryexitGetLastStepVehicleNumberResponse createMultientryexitGetLastStepVehicleNumberResponse() {
        return new MultientryexitGetLastStepVehicleNumberResponse();
    }

    /**
     * Create an instance of {@link JunctionGetShapeResponse }
     * 
     */
    public JunctionGetShapeResponse createJunctionGetShapeResponse() {
        return new JunctionGetShapeResponse();
    }

    /**
     * Create an instance of {@link LaneGetShape }
     * 
     */
    public LaneGetShape createLaneGetShape() {
        return new LaneGetShape();
    }

    /**
     * Create an instance of {@link InductionloopGetLastStepMeanLengthResponse }
     * 
     */
    public InductionloopGetLastStepMeanLengthResponse createInductionloopGetLastStepMeanLengthResponse() {
        return new InductionloopGetLastStepMeanLengthResponse();
    }

    /**
     * Create an instance of {@link VehicletypeGetLengthResponse }
     * 
     */
    public VehicletypeGetLengthResponse createVehicletypeGetLengthResponse() {
        return new VehicletypeGetLengthResponse();
    }

    /**
     * Create an instance of {@link LaneGetHCEmission }
     * 
     */
    public LaneGetHCEmission createLaneGetHCEmission() {
        return new LaneGetHCEmission();
    }

    /**
     * Create an instance of {@link EdgeGetWaitingTime }
     * 
     */
    public EdgeGetWaitingTime createEdgeGetWaitingTime() {
        return new EdgeGetWaitingTime();
    }

    /**
     * Create an instance of {@link LaneGetPMxEmissionResponse }
     * 
     */
    public LaneGetPMxEmissionResponse createLaneGetPMxEmissionResponse() {
        return new LaneGetPMxEmissionResponse();
    }

    /**
     * Create an instance of {@link VehicleSetMaxSpeed }
     * 
     */
    public VehicleSetMaxSpeed createVehicleSetMaxSpeed() {
        return new VehicleSetMaxSpeed();
    }

    /**
     * Create an instance of {@link VehicleGetRouteID }
     * 
     */
    public VehicleGetRouteID createVehicleGetRouteID() {
        return new VehicleGetRouteID();
    }

    /**
     * Create an instance of {@link SimulationGetStopStartingVehiclesIDList }
     * 
     */
    public SimulationGetStopStartingVehiclesIDList createSimulationGetStopStartingVehiclesIDList() {
        return new SimulationGetStopStartingVehiclesIDList();
    }

    /**
     * Create an instance of {@link VehicleSetSpeedDeviationResponse }
     * 
     */
    public VehicleSetSpeedDeviationResponse createVehicleSetSpeedDeviationResponse() {
        return new VehicleSetSpeedDeviationResponse();
    }

    /**
     * Create an instance of {@link SimulationGetStopStartingVehiclesIDListResponse }
     * 
     */
    public SimulationGetStopStartingVehiclesIDListResponse createSimulationGetStopStartingVehiclesIDListResponse() {
        return new SimulationGetStopStartingVehiclesIDListResponse();
    }

    /**
     * Create an instance of {@link GUISetBoundary }
     * 
     */
    public GUISetBoundary createGUISetBoundary() {
        return new GUISetBoundary();
    }

    /**
     * Create an instance of {@link InductionloopGetTimeSinceDetection }
     * 
     */
    public InductionloopGetTimeSinceDetection createInductionloopGetTimeSinceDetection() {
        return new InductionloopGetTimeSinceDetection();
    }

    /**
     * Create an instance of {@link InductionloopGetLaneID }
     * 
     */
    public InductionloopGetLaneID createInductionloopGetLaneID() {
        return new InductionloopGetLaneID();
    }

    /**
     * Create an instance of {@link VehicletypeSetImperfectionResponse }
     * 
     */
    public VehicletypeSetImperfectionResponse createVehicletypeSetImperfectionResponse() {
        return new VehicletypeSetImperfectionResponse();
    }

    /**
     * Create an instance of {@link GUIScreenshotResponse }
     * 
     */
    public GUIScreenshotResponse createGUIScreenshotResponse() {
        return new GUIScreenshotResponse();
    }

    /**
     * Create an instance of {@link TrafficlightsSetRedYellowGreenStateResponse }
     * 
     */
    public TrafficlightsSetRedYellowGreenStateResponse createTrafficlightsSetRedYellowGreenStateResponse() {
        return new TrafficlightsSetRedYellowGreenStateResponse();
    }

    /**
     * Create an instance of {@link VehicletypeGetMaxSpeed }
     * 
     */
    public VehicletypeGetMaxSpeed createVehicletypeGetMaxSpeed() {
        return new VehicletypeGetMaxSpeed();
    }

    /**
     * Create an instance of {@link VehicletypeGetAccelResponse }
     * 
     */
    public VehicletypeGetAccelResponse createVehicletypeGetAccelResponse() {
        return new VehicletypeGetAccelResponse();
    }

    /**
     * Create an instance of {@link SetSumoBinaryResponse }
     * 
     */
    public SetSumoBinaryResponse createSetSumoBinaryResponse() {
        return new SetSumoBinaryResponse();
    }

    /**
     * Create an instance of {@link EdgeSetMaxSpeedResponse }
     * 
     */
    public EdgeSetMaxSpeedResponse createEdgeSetMaxSpeedResponse() {
        return new EdgeSetMaxSpeedResponse();
    }

    /**
     * Create an instance of {@link VehicletypeGetMinGap }
     * 
     */
    public VehicletypeGetMinGap createVehicletypeGetMinGap() {
        return new VehicletypeGetMinGap();
    }

    /**
     * Create an instance of {@link VehicleGetBestLanes }
     * 
     */
    public VehicleGetBestLanes createVehicleGetBestLanes() {
        return new VehicleGetBestLanes();
    }

    /**
     * Create an instance of {@link VehicleSetDecelResponse }
     * 
     */
    public VehicleSetDecelResponse createVehicleSetDecelResponse() {
        return new VehicleSetDecelResponse();
    }

    /**
     * Create an instance of {@link SimulationGetCurrentTime }
     * 
     */
    public SimulationGetCurrentTime createSimulationGetCurrentTime() {
        return new SimulationGetCurrentTime();
    }

    /**
     * Create an instance of {@link TrafficlightsGetProgram }
     * 
     */
    public TrafficlightsGetProgram createTrafficlightsGetProgram() {
        return new TrafficlightsGetProgram();
    }

    /**
     * Create an instance of {@link VehicleRerouteEffort }
     * 
     */
    public VehicleRerouteEffort createVehicleRerouteEffort() {
        return new VehicleRerouteEffort();
    }

    /**
     * Create an instance of {@link InductionloopGetTimeSinceDetectionResponse }
     * 
     */
    public InductionloopGetTimeSinceDetectionResponse createInductionloopGetTimeSinceDetectionResponse() {
        return new InductionloopGetTimeSinceDetectionResponse();
    }

    /**
     * Create an instance of {@link VehicleSetTauResponse }
     * 
     */
    public VehicleSetTauResponse createVehicleSetTauResponse() {
        return new VehicleSetTauResponse();
    }

    /**
     * Create an instance of {@link LaneGetLastStepOccupancyResponse }
     * 
     */
    public LaneGetLastStepOccupancyResponse createLaneGetLastStepOccupancyResponse() {
        return new LaneGetLastStepOccupancyResponse();
    }

    /**
     * Create an instance of {@link GUIGetOffset }
     * 
     */
    public GUIGetOffset createGUIGetOffset() {
        return new GUIGetOffset();
    }

    /**
     * Create an instance of {@link PoiGetColorResponse }
     * 
     */
    public PoiGetColorResponse createPoiGetColorResponse() {
        return new PoiGetColorResponse();
    }

    /**
     * Create an instance of {@link MultientryexitGetIDListResponse }
     * 
     */
    public MultientryexitGetIDListResponse createMultientryexitGetIDListResponse() {
        return new MultientryexitGetIDListResponse();
    }

    /**
     * Create an instance of {@link SimulationGetParkingEndingVehiclesIDList }
     * 
     */
    public SimulationGetParkingEndingVehiclesIDList createSimulationGetParkingEndingVehiclesIDList() {
        return new SimulationGetParkingEndingVehiclesIDList();
    }

    /**
     * Create an instance of {@link EdgeGetNoiseEmission }
     * 
     */
    public EdgeGetNoiseEmission createEdgeGetNoiseEmission() {
        return new EdgeGetNoiseEmission();
    }

    /**
     * Create an instance of {@link LaneSetAllowed }
     * 
     */
    public LaneSetAllowed createLaneSetAllowed() {
        return new LaneSetAllowed();
    }

    /**
     * Create an instance of {@link VehicletypeGetVehicleClass }
     * 
     */
    public VehicletypeGetVehicleClass createVehicletypeGetVehicleClass() {
        return new VehicletypeGetVehicleClass();
    }

    /**
     * Create an instance of {@link MultientryexitGetIDCount }
     * 
     */
    public MultientryexitGetIDCount createMultientryexitGetIDCount() {
        return new MultientryexitGetIDCount();
    }

    /**
     * Create an instance of {@link PolygonRemove }
     * 
     */
    public PolygonRemove createPolygonRemove() {
        return new PolygonRemove();
    }

    /**
     * Create an instance of {@link SimulationGetNetBoundaryResponse }
     * 
     */
    public SimulationGetNetBoundaryResponse createSimulationGetNetBoundaryResponse() {
        return new SimulationGetNetBoundaryResponse();
    }

    /**
     * Create an instance of {@link TrafficlightsGetNextSwitch }
     * 
     */
    public TrafficlightsGetNextSwitch createTrafficlightsGetNextSwitch() {
        return new TrafficlightsGetNextSwitch();
    }

    /**
     * Create an instance of {@link RouteGetIDCount }
     * 
     */
    public RouteGetIDCount createRouteGetIDCount() {
        return new RouteGetIDCount();
    }

    /**
     * Create an instance of {@link VehicletypeSetEmissionClass }
     * 
     */
    public VehicletypeSetEmissionClass createVehicletypeSetEmissionClass() {
        return new VehicletypeSetEmissionClass();
    }

    /**
     * Create an instance of {@link TrafficlightsSetPhaseDuration }
     * 
     */
    public TrafficlightsSetPhaseDuration createTrafficlightsSetPhaseDuration() {
        return new TrafficlightsSetPhaseDuration();
    }

    /**
     * Create an instance of {@link SimulationGetStopEndingVehiclesNumberResponse }
     * 
     */
    public SimulationGetStopEndingVehiclesNumberResponse createSimulationGetStopEndingVehiclesNumberResponse() {
        return new SimulationGetStopEndingVehiclesNumberResponse();
    }

    /**
     * Create an instance of {@link SimulationGetBusStopWaiting }
     * 
     */
    public SimulationGetBusStopWaiting createSimulationGetBusStopWaiting() {
        return new SimulationGetBusStopWaiting();
    }

    /**
     * Create an instance of {@link SimulationGetEndingTeleportIDListResponse }
     * 
     */
    public SimulationGetEndingTeleportIDListResponse createSimulationGetEndingTeleportIDListResponse() {
        return new SimulationGetEndingTeleportIDListResponse();
    }

    /**
     * Create an instance of {@link EdgeSetEffort }
     * 
     */
    public EdgeSetEffort createEdgeSetEffort() {
        return new EdgeSetEffort();
    }

    /**
     * Create an instance of {@link VehicleSetLength }
     * 
     */
    public VehicleSetLength createVehicleSetLength() {
        return new VehicleSetLength();
    }

    /**
     * Create an instance of {@link TrafficlightsSetPhaseResponse }
     * 
     */
    public TrafficlightsSetPhaseResponse createTrafficlightsSetPhaseResponse() {
        return new TrafficlightsSetPhaseResponse();
    }

    /**
     * Create an instance of {@link GUISetOffset }
     * 
     */
    public GUISetOffset createGUISetOffset() {
        return new GUISetOffset();
    }

    /**
     * Create an instance of {@link TrafficlightsSetPhaseDurationResponse }
     * 
     */
    public TrafficlightsSetPhaseDurationResponse createTrafficlightsSetPhaseDurationResponse() {
        return new TrafficlightsSetPhaseDurationResponse();
    }

    /**
     * Create an instance of {@link SimulationGetDeltaT }
     * 
     */
    public SimulationGetDeltaT createSimulationGetDeltaT() {
        return new SimulationGetDeltaT();
    }

    /**
     * Create an instance of {@link VehicleGetAccel }
     * 
     */
    public VehicleGetAccel createVehicleGetAccel() {
        return new VehicleGetAccel();
    }

    /**
     * Create an instance of {@link TrafficlightsSetProgramResponse }
     * 
     */
    public TrafficlightsSetProgramResponse createTrafficlightsSetProgramResponse() {
        return new TrafficlightsSetProgramResponse();
    }

    /**
     * Create an instance of {@link LaneSetAllowedResponse }
     * 
     */
    public LaneSetAllowedResponse createLaneSetAllowedResponse() {
        return new LaneSetAllowedResponse();
    }

    /**
     * Create an instance of {@link JunctionGetIDCountResponse }
     * 
     */
    public JunctionGetIDCountResponse createJunctionGetIDCountResponse() {
        return new JunctionGetIDCountResponse();
    }

    /**
     * Create an instance of {@link InductionloopGetIDCount }
     * 
     */
    public InductionloopGetIDCount createInductionloopGetIDCount() {
        return new InductionloopGetIDCount();
    }

    /**
     * Create an instance of {@link VehicleGetCOEmission }
     * 
     */
    public VehicleGetCOEmission createVehicleGetCOEmission() {
        return new VehicleGetCOEmission();
    }

    /**
     * Create an instance of {@link VehicleSetWidth }
     * 
     */
    public VehicleSetWidth createVehicleSetWidth() {
        return new VehicleSetWidth();
    }

    /**
     * Create an instance of {@link GUIGetZoomResponse }
     * 
     */
    public GUIGetZoomResponse createGUIGetZoomResponse() {
        return new GUIGetZoomResponse();
    }

    /**
     * Create an instance of {@link SimulationGetDepartedIDList }
     * 
     */
    public SimulationGetDepartedIDList createSimulationGetDepartedIDList() {
        return new SimulationGetDepartedIDList();
    }

    /**
     * Create an instance of {@link VehicleGetSpeedResponse }
     * 
     */
    public VehicleGetSpeedResponse createVehicleGetSpeedResponse() {
        return new VehicleGetSpeedResponse();
    }

    /**
     * Create an instance of {@link VehicleSetMaxSpeedResponse }
     * 
     */
    public VehicleSetMaxSpeedResponse createVehicleSetMaxSpeedResponse() {
        return new VehicleSetMaxSpeedResponse();
    }

    /**
     * Create an instance of {@link GUITrackVehicleResponse }
     * 
     */
    public GUITrackVehicleResponse createGUITrackVehicleResponse() {
        return new GUITrackVehicleResponse();
    }

    /**
     * Create an instance of {@link VehicleGetNoiseEmissionResponse }
     * 
     */
    public VehicleGetNoiseEmissionResponse createVehicleGetNoiseEmissionResponse() {
        return new VehicleGetNoiseEmissionResponse();
    }

    /**
     * Create an instance of {@link SimulationConvert2DResponse }
     * 
     */
    public SimulationConvert2DResponse createSimulationConvert2DResponse() {
        return new SimulationConvert2DResponse();
    }

    /**
     * Create an instance of {@link LaneGetLength }
     * 
     */
    public LaneGetLength createLaneGetLength() {
        return new LaneGetLength();
    }

    /**
     * Create an instance of {@link VehicleGetLaneIndex }
     * 
     */
    public VehicleGetLaneIndex createVehicleGetLaneIndex() {
        return new VehicleGetLaneIndex();
    }

    /**
     * Create an instance of {@link SimulationGetParkingStartingVehiclesNumber }
     * 
     */
    public SimulationGetParkingStartingVehiclesNumber createSimulationGetParkingStartingVehiclesNumber() {
        return new SimulationGetParkingStartingVehiclesNumber();
    }

    /**
     * Create an instance of {@link ArealDetectorGetJamLengthMetersResponse }
     * 
     */
    public ArealDetectorGetJamLengthMetersResponse createArealDetectorGetJamLengthMetersResponse() {
        return new ArealDetectorGetJamLengthMetersResponse();
    }

    /**
     * Create an instance of {@link VehicleGetDistanceResponse }
     * 
     */
    public VehicleGetDistanceResponse createVehicleGetDistanceResponse() {
        return new VehicleGetDistanceResponse();
    }

    /**
     * Create an instance of {@link PoiAddResponse }
     * 
     */
    public PoiAddResponse createPoiAddResponse() {
        return new PoiAddResponse();
    }

    /**
     * Create an instance of {@link LaneGetLastStepVehicleIDs }
     * 
     */
    public LaneGetLastStepVehicleIDs createLaneGetLastStepVehicleIDs() {
        return new LaneGetLastStepVehicleIDs();
    }

    /**
     * Create an instance of {@link VehicletypeSetAccel }
     * 
     */
    public VehicletypeSetAccel createVehicletypeSetAccel() {
        return new VehicletypeSetAccel();
    }

    /**
     * Create an instance of {@link EdgeSetMaxSpeed }
     * 
     */
    public EdgeSetMaxSpeed createEdgeSetMaxSpeed() {
        return new EdgeSetMaxSpeed();
    }

    /**
     * Create an instance of {@link VehicleGetDrivingDistance2DResponse }
     * 
     */
    public VehicleGetDrivingDistance2DResponse createVehicleGetDrivingDistance2DResponse() {
        return new VehicleGetDrivingDistance2DResponse();
    }

    /**
     * Create an instance of {@link InductionloopGetLastStepMeanSpeedResponse }
     * 
     */
    public InductionloopGetLastStepMeanSpeedResponse createInductionloopGetLastStepMeanSpeedResponse() {
        return new InductionloopGetLastStepMeanSpeedResponse();
    }

    /**
     * Create an instance of {@link EdgeGetLastStepVehicleNumber }
     * 
     */
    public EdgeGetLastStepVehicleNumber createEdgeGetLastStepVehicleNumber() {
        return new EdgeGetLastStepVehicleNumber();
    }

    /**
     * Create an instance of {@link GUISetZoomResponse }
     * 
     */
    public GUISetZoomResponse createGUISetZoomResponse() {
        return new GUISetZoomResponse();
    }

    /**
     * Create an instance of {@link RouteGetEdges }
     * 
     */
    public RouteGetEdges createRouteGetEdges() {
        return new RouteGetEdges();
    }

    /**
     * Create an instance of {@link EdgeGetHCEmission }
     * 
     */
    public EdgeGetHCEmission createEdgeGetHCEmission() {
        return new EdgeGetHCEmission();
    }

    /**
     * Create an instance of {@link VehicleSetLaneChangeMode }
     * 
     */
    public VehicleSetLaneChangeMode createVehicleSetLaneChangeMode() {
        return new VehicleSetLaneChangeMode();
    }

    /**
     * Create an instance of {@link VehicletypeSetTauResponse }
     * 
     */
    public VehicletypeSetTauResponse createVehicletypeSetTauResponse() {
        return new VehicletypeSetTauResponse();
    }

    /**
     * Create an instance of {@link SimulationGetStopEndingVehiclesIDListResponse }
     * 
     */
    public SimulationGetStopEndingVehiclesIDListResponse createSimulationGetStopEndingVehiclesIDListResponse() {
        return new SimulationGetStopEndingVehiclesIDListResponse();
    }

    /**
     * Create an instance of {@link SetSumoBinary }
     * 
     */
    public SetSumoBinary createSetSumoBinary() {
        return new SetSumoBinary();
    }

    /**
     * Create an instance of {@link RouteAddResponse }
     * 
     */
    public RouteAddResponse createRouteAddResponse() {
        return new RouteAddResponse();
    }

    /**
     * Create an instance of {@link EdgeGetPMxEmissionResponse }
     * 
     */
    public EdgeGetPMxEmissionResponse createEdgeGetPMxEmissionResponse() {
        return new EdgeGetPMxEmissionResponse();
    }

    /**
     * Create an instance of {@link VehicleGetDecel }
     * 
     */
    public VehicleGetDecel createVehicleGetDecel() {
        return new VehicleGetDecel();
    }

    /**
     * Create an instance of {@link GUIScreenshot }
     * 
     */
    public GUIScreenshot createGUIScreenshot() {
        return new GUIScreenshot();
    }

    /**
     * Create an instance of {@link VehicleSlowDown }
     * 
     */
    public VehicleSlowDown createVehicleSlowDown() {
        return new VehicleSlowDown();
    }

    /**
     * Create an instance of {@link EdgeGetLastStepHaltingNumberResponse }
     * 
     */
    public EdgeGetLastStepHaltingNumberResponse createEdgeGetLastStepHaltingNumberResponse() {
        return new EdgeGetLastStepHaltingNumberResponse();
    }

    /**
     * Create an instance of {@link VehicleSetImperfection }
     * 
     */
    public VehicleSetImperfection createVehicleSetImperfection() {
        return new VehicleSetImperfection();
    }

    /**
     * Create an instance of {@link VehicletypeSetSpeedFactorResponse }
     * 
     */
    public VehicletypeSetSpeedFactorResponse createVehicletypeSetSpeedFactorResponse() {
        return new VehicletypeSetSpeedFactorResponse();
    }

    /**
     * Create an instance of {@link VehicletypeSetSpeedFactor }
     * 
     */
    public VehicletypeSetSpeedFactor createVehicletypeSetSpeedFactor() {
        return new VehicletypeSetSpeedFactor();
    }

    /**
     * Create an instance of {@link VehicletypeSetAccelResponse }
     * 
     */
    public VehicletypeSetAccelResponse createVehicletypeSetAccelResponse() {
        return new VehicletypeSetAccelResponse();
    }

    /**
     * Create an instance of {@link MultientryexitGetLastStepVehicleIDsResponse }
     * 
     */
    public MultientryexitGetLastStepVehicleIDsResponse createMultientryexitGetLastStepVehicleIDsResponse() {
        return new MultientryexitGetLastStepVehicleIDsResponse();
    }

    /**
     * Create an instance of {@link LaneGetFuelConsumptionResponse }
     * 
     */
    public LaneGetFuelConsumptionResponse createLaneGetFuelConsumptionResponse() {
        return new LaneGetFuelConsumptionResponse();
    }

    /**
     * Create an instance of {@link LaneGetDisallowed }
     * 
     */
    public LaneGetDisallowed createLaneGetDisallowed() {
        return new LaneGetDisallowed();
    }

    /**
     * Create an instance of {@link SimulationGetArrivedNumberResponse }
     * 
     */
    public SimulationGetArrivedNumberResponse createSimulationGetArrivedNumberResponse() {
        return new SimulationGetArrivedNumberResponse();
    }

    /**
     * Create an instance of {@link EdgeGetEffortResponse }
     * 
     */
    public EdgeGetEffortResponse createEdgeGetEffortResponse() {
        return new EdgeGetEffortResponse();
    }

    /**
     * Create an instance of {@link ArealDetectorGetIDListResponse }
     * 
     */
    public ArealDetectorGetIDListResponse createArealDetectorGetIDListResponse() {
        return new ArealDetectorGetIDListResponse();
    }

    /**
     * Create an instance of {@link VehicletypeSetColorResponse }
     * 
     */
    public VehicletypeSetColorResponse createVehicletypeSetColorResponse() {
        return new VehicletypeSetColorResponse();
    }

    /**
     * Create an instance of {@link GUISetZoom }
     * 
     */
    public GUISetZoom createGUISetZoom() {
        return new GUISetZoom();
    }

    /**
     * Create an instance of {@link VehicleChangeLaneResponse }
     * 
     */
    public VehicleChangeLaneResponse createVehicleChangeLaneResponse() {
        return new VehicleChangeLaneResponse();
    }

    /**
     * Create an instance of {@link PoiGetType }
     * 
     */
    public PoiGetType createPoiGetType() {
        return new PoiGetType();
    }

    /**
     * Create an instance of {@link VehicletypeGetSpeedFactor }
     * 
     */
    public VehicletypeGetSpeedFactor createVehicletypeGetSpeedFactor() {
        return new VehicletypeGetSpeedFactor();
    }

    /**
     * Create an instance of {@link LaneGetNoiseEmissionResponse }
     * 
     */
    public LaneGetNoiseEmissionResponse createLaneGetNoiseEmissionResponse() {
        return new LaneGetNoiseEmissionResponse();
    }

    /**
     * Create an instance of {@link VehicleSetSpeedResponse }
     * 
     */
    public VehicleSetSpeedResponse createVehicleSetSpeedResponse() {
        return new VehicleSetSpeedResponse();
    }

    /**
     * Create an instance of {@link EdgeGetLastStepHaltingNumber }
     * 
     */
    public EdgeGetLastStepHaltingNumber createEdgeGetLastStepHaltingNumber() {
        return new EdgeGetLastStepHaltingNumber();
    }

    /**
     * Create an instance of {@link VehicleGetSignals }
     * 
     */
    public VehicleGetSignals createVehicleGetSignals() {
        return new VehicleGetSignals();
    }

    /**
     * Create an instance of {@link LaneGetLengthResponse }
     * 
     */
    public LaneGetLengthResponse createLaneGetLengthResponse() {
        return new LaneGetLengthResponse();
    }

    /**
     * Create an instance of {@link EdgeGetCO2Emission }
     * 
     */
    public EdgeGetCO2Emission createEdgeGetCO2Emission() {
        return new EdgeGetCO2Emission();
    }

    /**
     * Create an instance of {@link VehicleRemoveResponse }
     * 
     */
    public VehicleRemoveResponse createVehicleRemoveResponse() {
        return new VehicleRemoveResponse();
    }

    /**
     * Create an instance of {@link GUIGetZoom }
     * 
     */
    public GUIGetZoom createGUIGetZoom() {
        return new GUIGetZoom();
    }

    /**
     * Create an instance of {@link VehicleGetIDCountResponse }
     * 
     */
    public VehicleGetIDCountResponse createVehicleGetIDCountResponse() {
        return new VehicleGetIDCountResponse();
    }

    /**
     * Create an instance of {@link VehicletypeSetDecelResponse }
     * 
     */
    public VehicletypeSetDecelResponse createVehicletypeSetDecelResponse() {
        return new VehicletypeSetDecelResponse();
    }

    /**
     * Create an instance of {@link VehicleSetDecel }
     * 
     */
    public VehicleSetDecel createVehicleSetDecel() {
        return new VehicleSetDecel();
    }

    /**
     * Create an instance of {@link LaneGetLastStepLength }
     * 
     */
    public LaneGetLastStepLength createLaneGetLastStepLength() {
        return new LaneGetLastStepLength();
    }

    /**
     * Create an instance of {@link SimulationGetStartingTeleportIDList }
     * 
     */
    public SimulationGetStartingTeleportIDList createSimulationGetStartingTeleportIDList() {
        return new SimulationGetStartingTeleportIDList();
    }

    /**
     * Create an instance of {@link VehicletypeSetMaxSpeed }
     * 
     */
    public VehicletypeSetMaxSpeed createVehicletypeSetMaxSpeed() {
        return new VehicletypeSetMaxSpeed();
    }

    /**
     * Create an instance of {@link VehicletypeGetSpeedDeviation }
     * 
     */
    public VehicletypeGetSpeedDeviation createVehicletypeGetSpeedDeviation() {
        return new VehicletypeGetSpeedDeviation();
    }

    /**
     * Create an instance of {@link PoiSetColor }
     * 
     */
    public PoiSetColor createPoiSetColor() {
        return new PoiSetColor();
    }

    /**
     * Create an instance of {@link VehicletypeSetColor }
     * 
     */
    public VehicletypeSetColor createVehicletypeSetColor() {
        return new VehicletypeSetColor();
    }

    /**
     * Create an instance of {@link VehicleSlowDownResponse }
     * 
     */
    public VehicleSlowDownResponse createVehicleSlowDownResponse() {
        return new VehicleSlowDownResponse();
    }

    /**
     * Create an instance of {@link VehicleGetShapeClassResponse }
     * 
     */
    public VehicleGetShapeClassResponse createVehicleGetShapeClassResponse() {
        return new VehicleGetShapeClassResponse();
    }

    /**
     * Create an instance of {@link LaneGetHCEmissionResponse }
     * 
     */
    public LaneGetHCEmissionResponse createLaneGetHCEmissionResponse() {
        return new LaneGetHCEmissionResponse();
    }

    /**
     * Create an instance of {@link VehicleGetAngleResponse }
     * 
     */
    public VehicleGetAngleResponse createVehicleGetAngleResponse() {
        return new VehicleGetAngleResponse();
    }

    /**
     * Create an instance of {@link VehicletypeGetMaxSpeedResponse }
     * 
     */
    public VehicletypeGetMaxSpeedResponse createVehicletypeGetMaxSpeedResponse() {
        return new VehicletypeGetMaxSpeedResponse();
    }

    /**
     * Create an instance of {@link ArealDetectorGetIDCount }
     * 
     */
    public ArealDetectorGetIDCount createArealDetectorGetIDCount() {
        return new ArealDetectorGetIDCount();
    }

    /**
     * Create an instance of {@link InductionloopGetPosition }
     * 
     */
    public InductionloopGetPosition createInductionloopGetPosition() {
        return new InductionloopGetPosition();
    }

    /**
     * Create an instance of {@link VehicleGetDrivingDistanceResponse }
     * 
     */
    public VehicleGetDrivingDistanceResponse createVehicleGetDrivingDistanceResponse() {
        return new VehicleGetDrivingDistanceResponse();
    }

    /**
     * Create an instance of {@link SimulationGetMinExpectedNumberResponse }
     * 
     */
    public SimulationGetMinExpectedNumberResponse createSimulationGetMinExpectedNumberResponse() {
        return new SimulationGetMinExpectedNumberResponse();
    }

    /**
     * Create an instance of {@link GUISetSchema }
     * 
     */
    public GUISetSchema createGUISetSchema() {
        return new GUISetSchema();
    }

    /**
     * Create an instance of {@link VehicleGetShapeClass }
     * 
     */
    public VehicleGetShapeClass createVehicleGetShapeClass() {
        return new VehicleGetShapeClass();
    }

    /**
     * Create an instance of {@link VehicleGetEffortResponse }
     * 
     */
    public VehicleGetEffortResponse createVehicleGetEffortResponse() {
        return new VehicleGetEffortResponse();
    }

    /**
     * Create an instance of {@link VehicleGetFuelConsumptionResponse }
     * 
     */
    public VehicleGetFuelConsumptionResponse createVehicleGetFuelConsumptionResponse() {
        return new VehicleGetFuelConsumptionResponse();
    }

    /**
     * Create an instance of {@link SimulationGetStopStartingVehiclesNumber }
     * 
     */
    public SimulationGetStopStartingVehiclesNumber createSimulationGetStopStartingVehiclesNumber() {
        return new SimulationGetStopStartingVehiclesNumber();
    }

    /**
     * Create an instance of {@link VehicletypeSetMaxSpeedResponse }
     * 
     */
    public VehicletypeSetMaxSpeedResponse createVehicletypeSetMaxSpeedResponse() {
        return new VehicletypeSetMaxSpeedResponse();
    }

    /**
     * Create an instance of {@link SimulationGetArrivedNumber }
     * 
     */
    public SimulationGetArrivedNumber createSimulationGetArrivedNumber() {
        return new SimulationGetArrivedNumber();
    }

    /**
     * Create an instance of {@link InductionloopGetIDListResponse }
     * 
     */
    public InductionloopGetIDListResponse createInductionloopGetIDListResponse() {
        return new InductionloopGetIDListResponse();
    }

    /**
     * Create an instance of {@link VehicletypeGetIDCount }
     * 
     */
    public VehicletypeGetIDCount createVehicletypeGetIDCount() {
        return new VehicletypeGetIDCount();
    }

    /**
     * Create an instance of {@link VehicleGetWidthResponse }
     * 
     */
    public VehicleGetWidthResponse createVehicleGetWidthResponse() {
        return new VehicleGetWidthResponse();
    }

    /**
     * Create an instance of {@link SimulationGetStartingTeleportNumber }
     * 
     */
    public SimulationGetStartingTeleportNumber createSimulationGetStartingTeleportNumber() {
        return new SimulationGetStartingTeleportNumber();
    }

    /**
     * Create an instance of {@link LaneGetAllowedResponse }
     * 
     */
    public LaneGetAllowedResponse createLaneGetAllowedResponse() {
        return new LaneGetAllowedResponse();
    }

    /**
     * Create an instance of {@link VehicleMoveTo }
     * 
     */
    public VehicleMoveTo createVehicleMoveTo() {
        return new VehicleMoveTo();
    }

    /**
     * Create an instance of {@link EdgeAdaptTraveltimeResponse }
     * 
     */
    public EdgeAdaptTraveltimeResponse createEdgeAdaptTraveltimeResponse() {
        return new EdgeAdaptTraveltimeResponse();
    }

    /**
     * Create an instance of {@link InductionloopGetLastStepOccupancy }
     * 
     */
    public InductionloopGetLastStepOccupancy createInductionloopGetLastStepOccupancy() {
        return new InductionloopGetLastStepOccupancy();
    }

    /**
     * Create an instance of {@link VehicleRerouteEffortResponse }
     * 
     */
    public VehicleRerouteEffortResponse createVehicleRerouteEffortResponse() {
        return new VehicleRerouteEffortResponse();
    }

    /**
     * Create an instance of {@link VehicletypeGetShapeClass }
     * 
     */
    public VehicletypeGetShapeClass createVehicletypeGetShapeClass() {
        return new VehicletypeGetShapeClass();
    }

    /**
     * Create an instance of {@link VehicleGetDrivingDistance }
     * 
     */
    public VehicleGetDrivingDistance createVehicleGetDrivingDistance() {
        return new VehicleGetDrivingDistance();
    }

    /**
     * Create an instance of {@link InductionloopGetIDList }
     * 
     */
    public InductionloopGetIDList createInductionloopGetIDList() {
        return new InductionloopGetIDList();
    }

    /**
     * Create an instance of {@link VehicletypeSetDecel }
     * 
     */
    public VehicletypeSetDecel createVehicletypeSetDecel() {
        return new VehicletypeSetDecel();
    }

    /**
     * Create an instance of {@link VehicleGetWaitingTimeResponse }
     * 
     */
    public VehicleGetWaitingTimeResponse createVehicleGetWaitingTimeResponse() {
        return new VehicleGetWaitingTimeResponse();
    }

    /**
     * Create an instance of {@link TXTOutputResponse }
     * 
     */
    public TXTOutputResponse createTXTOutputResponse() {
        return new TXTOutputResponse();
    }

    /**
     * Create an instance of {@link VehicleSetStop }
     * 
     */
    public VehicleSetStop createVehicleSetStop() {
        return new VehicleSetStop();
    }

    /**
     * Create an instance of {@link VehicleGetSignalsResponse }
     * 
     */
    public VehicleGetSignalsResponse createVehicleGetSignalsResponse() {
        return new VehicleGetSignalsResponse();
    }

    /**
     * Create an instance of {@link InductionloopGetLastStepVehicleIDs }
     * 
     */
    public InductionloopGetLastStepVehicleIDs createInductionloopGetLastStepVehicleIDs() {
        return new InductionloopGetLastStepVehicleIDs();
    }

    /**
     * Create an instance of {@link MultientryexitGetLastStepHaltingNumber }
     * 
     */
    public MultientryexitGetLastStepHaltingNumber createMultientryexitGetLastStepHaltingNumber() {
        return new MultientryexitGetLastStepHaltingNumber();
    }

    /**
     * Create an instance of {@link SimulationGetDeltaTResponse }
     * 
     */
    public SimulationGetDeltaTResponse createSimulationGetDeltaTResponse() {
        return new SimulationGetDeltaTResponse();
    }

    /**
     * Create an instance of {@link PolygonSetColor }
     * 
     */
    public PolygonSetColor createPolygonSetColor() {
        return new PolygonSetColor();
    }

    /**
     * Create an instance of {@link LaneGetWaitingTime }
     * 
     */
    public LaneGetWaitingTime createLaneGetWaitingTime() {
        return new LaneGetWaitingTime();
    }

    /**
     * Create an instance of {@link LastActionTime }
     * 
     */
    public LastActionTime createLastActionTime() {
        return new LastActionTime();
    }

    /**
     * Create an instance of {@link EdgeGetIDCountResponse }
     * 
     */
    public EdgeGetIDCountResponse createEdgeGetIDCountResponse() {
        return new EdgeGetIDCountResponse();
    }

    /**
     * Create an instance of {@link VehicleGetAdaptedTraveltimeResponse }
     * 
     */
    public VehicleGetAdaptedTraveltimeResponse createVehicleGetAdaptedTraveltimeResponse() {
        return new VehicleGetAdaptedTraveltimeResponse();
    }

    /**
     * Create an instance of {@link VehicleSetMinGapResponse }
     * 
     */
    public VehicleSetMinGapResponse createVehicleSetMinGapResponse() {
        return new VehicleSetMinGapResponse();
    }

    /**
     * Create an instance of {@link GUITrackVehicle }
     * 
     */
    public GUITrackVehicle createGUITrackVehicle() {
        return new GUITrackVehicle();
    }

    /**
     * Create an instance of {@link VehicleGetLength }
     * 
     */
    public VehicleGetLength createVehicleGetLength() {
        return new VehicleGetLength();
    }

    /**
     * Create an instance of {@link TrafficlightsGetControlledLinksResponse }
     * 
     */
    public TrafficlightsGetControlledLinksResponse createTrafficlightsGetControlledLinksResponse() {
        return new TrafficlightsGetControlledLinksResponse();
    }

    /**
     * Create an instance of {@link LaneGetWaitingTimeResponse }
     * 
     */
    public LaneGetWaitingTimeResponse createLaneGetWaitingTimeResponse() {
        return new LaneGetWaitingTimeResponse();
    }

    /**
     * Create an instance of {@link PoiSetType }
     * 
     */
    public PoiSetType createPoiSetType() {
        return new PoiSetType();
    }

    /**
     * Create an instance of {@link TrafficlightsGetPhaseDurationResponse }
     * 
     */
    public TrafficlightsGetPhaseDurationResponse createTrafficlightsGetPhaseDurationResponse() {
        return new TrafficlightsGetPhaseDurationResponse();
    }

    /**
     * Create an instance of {@link VehicleSetVehicleClassResponse }
     * 
     */
    public VehicleSetVehicleClassResponse createVehicleSetVehicleClassResponse() {
        return new VehicleSetVehicleClassResponse();
    }

    /**
     * Create an instance of {@link VehicleGetWidth }
     * 
     */
    public VehicleGetWidth createVehicleGetWidth() {
        return new VehicleGetWidth();
    }

    /**
     * Create an instance of {@link SimulationGetDistance2DResponse }
     * 
     */
    public SimulationGetDistance2DResponse createSimulationGetDistance2DResponse() {
        return new SimulationGetDistance2DResponse();
    }

    /**
     * Create an instance of {@link VehicletypeGetWidth }
     * 
     */
    public VehicletypeGetWidth createVehicletypeGetWidth() {
        return new VehicletypeGetWidth();
    }

    /**
     * Create an instance of {@link VehicleRerouteTraveltimeResponse }
     * 
     */
    public VehicleRerouteTraveltimeResponse createVehicleRerouteTraveltimeResponse() {
        return new VehicleRerouteTraveltimeResponse();
    }

    /**
     * Create an instance of {@link VehicleSetEffort }
     * 
     */
    public VehicleSetEffort createVehicleSetEffort() {
        return new VehicleSetEffort();
    }

    /**
     * Create an instance of {@link TrafficlightsSetPhase }
     * 
     */
    public TrafficlightsSetPhase createTrafficlightsSetPhase() {
        return new TrafficlightsSetPhase();
    }

    /**
     * Create an instance of {@link InductionloopGetVehicleData }
     * 
     */
    public InductionloopGetVehicleData createInductionloopGetVehicleData() {
        return new InductionloopGetVehicleData();
    }

    /**
     * Create an instance of {@link VehicletypeGetAccel }
     * 
     */
    public VehicletypeGetAccel createVehicletypeGetAccel() {
        return new VehicletypeGetAccel();
    }

    /**
     * Create an instance of {@link InductionloopGetPositionResponse }
     * 
     */
    public InductionloopGetPositionResponse createInductionloopGetPositionResponse() {
        return new InductionloopGetPositionResponse();
    }

    /**
     * Create an instance of {@link TrafficlightsGetCompleteRedYellowGreenDefinition }
     * 
     */
    public TrafficlightsGetCompleteRedYellowGreenDefinition createTrafficlightsGetCompleteRedYellowGreenDefinition() {
        return new TrafficlightsGetCompleteRedYellowGreenDefinition();
    }

    /**
     * Create an instance of {@link VehicletypeSetSpeedDeviationResponse }
     * 
     */
    public VehicletypeSetSpeedDeviationResponse createVehicletypeSetSpeedDeviationResponse() {
        return new VehicletypeSetSpeedDeviationResponse();
    }

    /**
     * Create an instance of {@link VehicleSetAdaptedTraveltime }
     * 
     */
    public VehicleSetAdaptedTraveltime createVehicleSetAdaptedTraveltime() {
        return new VehicleSetAdaptedTraveltime();
    }

    /**
     * Create an instance of {@link VehicleSetShapeClassResponse }
     * 
     */
    public VehicleSetShapeClassResponse createVehicleSetShapeClassResponse() {
        return new VehicleSetShapeClassResponse();
    }

    /**
     * Create an instance of {@link VehicletypeSetWidthResponse }
     * 
     */
    public VehicletypeSetWidthResponse createVehicletypeSetWidthResponse() {
        return new VehicletypeSetWidthResponse();
    }

    /**
     * Create an instance of {@link GUISetSchemaResponse }
     * 
     */
    public GUISetSchemaResponse createGUISetSchemaResponse() {
        return new GUISetSchemaResponse();
    }

    /**
     * Create an instance of {@link SimulationGetDistance2D }
     * 
     */
    public SimulationGetDistance2D createSimulationGetDistance2D() {
        return new SimulationGetDistance2D();
    }

    /**
     * Create an instance of {@link LaneGetLastStepHaltingNumberResponse }
     * 
     */
    public LaneGetLastStepHaltingNumberResponse createLaneGetLastStepHaltingNumberResponse() {
        return new LaneGetLastStepHaltingNumberResponse();
    }

    /**
     * Create an instance of {@link LaneGetFuelConsumption }
     * 
     */
    public LaneGetFuelConsumption createLaneGetFuelConsumption() {
        return new LaneGetFuelConsumption();
    }

    /**
     * Create an instance of {@link SimulationConvert2D }
     * 
     */
    public SimulationConvert2D createSimulationConvert2D() {
        return new SimulationConvert2D();
    }

    /**
     * Create an instance of {@link InductionloopGetLastStepMeanSpeed }
     * 
     */
    public InductionloopGetLastStepMeanSpeed createInductionloopGetLastStepMeanSpeed() {
        return new InductionloopGetLastStepMeanSpeed();
    }

    /**
     * Create an instance of {@link VehicleGetVehicleClass }
     * 
     */
    public VehicleGetVehicleClass createVehicleGetVehicleClass() {
        return new VehicleGetVehicleClass();
    }

    /**
     * Create an instance of {@link SimulationGetDistanceRoadResponse }
     * 
     */
    public SimulationGetDistanceRoadResponse createSimulationGetDistanceRoadResponse() {
        return new SimulationGetDistanceRoadResponse();
    }

    /**
     * Create an instance of {@link VehicletypeGetImperfectionResponse }
     * 
     */
    public VehicletypeGetImperfectionResponse createVehicletypeGetImperfectionResponse() {
        return new VehicletypeGetImperfectionResponse();
    }

    /**
     * Create an instance of {@link InductionloopGetLastStepMeanLength }
     * 
     */
    public InductionloopGetLastStepMeanLength createInductionloopGetLastStepMeanLength() {
        return new InductionloopGetLastStepMeanLength();
    }

    /**
     * Create an instance of {@link PoiSetPositionResponse }
     * 
     */
    public PoiSetPositionResponse createPoiSetPositionResponse() {
        return new PoiSetPositionResponse();
    }

    /**
     * Create an instance of {@link LaneGetLinksResponse }
     * 
     */
    public LaneGetLinksResponse createLaneGetLinksResponse() {
        return new LaneGetLinksResponse();
    }

    /**
     * Create an instance of {@link PolygonAddResponse }
     * 
     */
    public PolygonAddResponse createPolygonAddResponse() {
        return new PolygonAddResponse();
    }

    /**
     * Create an instance of {@link VehicletypeSetSpeedDeviation }
     * 
     */
    public VehicletypeSetSpeedDeviation createVehicletypeSetSpeedDeviation() {
        return new VehicletypeSetSpeedDeviation();
    }

    /**
     * Create an instance of {@link VehicleGetIDCount }
     * 
     */
    public VehicleGetIDCount createVehicleGetIDCount() {
        return new VehicleGetIDCount();
    }

    /**
     * Create an instance of {@link EdgeAdaptTraveltime }
     * 
     */
    public EdgeAdaptTraveltime createEdgeAdaptTraveltime() {
        return new EdgeAdaptTraveltime();
    }

    /**
     * Create an instance of {@link GetStatus }
     * 
     */
    public GetStatus createGetStatus() {
        return new GetStatus();
    }

    /**
     * Create an instance of {@link SimulationConvertGeoResponse }
     * 
     */
    public SimulationConvertGeoResponse createSimulationConvertGeoResponse() {
        return new SimulationConvertGeoResponse();
    }

    /**
     * Create an instance of {@link VehicletypeGetIDList }
     * 
     */
    public VehicletypeGetIDList createVehicletypeGetIDList() {
        return new VehicletypeGetIDList();
    }

    /**
     * Create an instance of {@link LaneGetIDListResponse }
     * 
     */
    public LaneGetIDListResponse createLaneGetIDListResponse() {
        return new LaneGetIDListResponse();
    }

    /**
     * Create an instance of {@link VehicletypeSetLengthResponse }
     * 
     */
    public VehicletypeSetLengthResponse createVehicletypeSetLengthResponse() {
        return new VehicletypeSetLengthResponse();
    }

    /**
     * Create an instance of {@link LaneGetCOEmissionResponse }
     * 
     */
    public LaneGetCOEmissionResponse createLaneGetCOEmissionResponse() {
        return new LaneGetCOEmissionResponse();
    }

    /**
     * Create an instance of {@link VehicletypeSetShapeClassResponse }
     * 
     */
    public VehicletypeSetShapeClassResponse createVehicletypeSetShapeClassResponse() {
        return new VehicletypeSetShapeClassResponse();
    }

    /**
     * Create an instance of {@link EdgeGetNOxEmissionResponse }
     * 
     */
    public EdgeGetNOxEmissionResponse createEdgeGetNOxEmissionResponse() {
        return new EdgeGetNOxEmissionResponse();
    }

    /**
     * Create an instance of {@link LaneGetNoiseEmission }
     * 
     */
    public LaneGetNoiseEmission createLaneGetNoiseEmission() {
        return new LaneGetNoiseEmission();
    }

    /**
     * Create an instance of {@link SimulationGetParkingEndingVehiclesIDListResponse }
     * 
     */
    public SimulationGetParkingEndingVehiclesIDListResponse createSimulationGetParkingEndingVehiclesIDListResponse() {
        return new SimulationGetParkingEndingVehiclesIDListResponse();
    }

    /**
     * Create an instance of {@link VehicleGetPosition }
     * 
     */
    public VehicleGetPosition createVehicleGetPosition() {
        return new VehicleGetPosition();
    }

    /**
     * Create an instance of {@link PolygonGetIDListResponse }
     * 
     */
    public PolygonGetIDListResponse createPolygonGetIDListResponse() {
        return new PolygonGetIDListResponse();
    }

    /**
     * Create an instance of {@link VehicleGetIDListResponse }
     * 
     */
    public VehicleGetIDListResponse createVehicleGetIDListResponse() {
        return new VehicleGetIDListResponse();
    }

    /**
     * Create an instance of {@link VehicletypeGetIDListResponse }
     * 
     */
    public VehicletypeGetIDListResponse createVehicletypeGetIDListResponse() {
        return new VehicletypeGetIDListResponse();
    }

    /**
     * Create an instance of {@link VehicletypeGetSpeedFactorResponse }
     * 
     */
    public VehicletypeGetSpeedFactorResponse createVehicletypeGetSpeedFactorResponse() {
        return new VehicletypeGetSpeedFactorResponse();
    }

    /**
     * Create an instance of {@link VehicleSetLengthResponse }
     * 
     */
    public VehicleSetLengthResponse createVehicleSetLengthResponse() {
        return new VehicleSetLengthResponse();
    }

    /**
     * Create an instance of {@link LaneGetLastStepVehicleNumber }
     * 
     */
    public LaneGetLastStepVehicleNumber createLaneGetLastStepVehicleNumber() {
        return new LaneGetLastStepVehicleNumber();
    }

    /**
     * Create an instance of {@link VehicleGetRoadID }
     * 
     */
    public VehicleGetRoadID createVehicleGetRoadID() {
        return new VehicleGetRoadID();
    }

    /**
     * Create an instance of {@link LaneGetAllowed }
     * 
     */
    public LaneGetAllowed createLaneGetAllowed() {
        return new LaneGetAllowed();
    }

    /**
     * Create an instance of {@link EdgeGetTraveltime }
     * 
     */
    public EdgeGetTraveltime createEdgeGetTraveltime() {
        return new EdgeGetTraveltime();
    }

    /**
     * Create an instance of {@link LaneGetLastStepHaltingNumber }
     * 
     */
    public LaneGetLastStepHaltingNumber createLaneGetLastStepHaltingNumber() {
        return new LaneGetLastStepHaltingNumber();
    }

    /**
     * Create an instance of {@link VehicleGetAngle }
     * 
     */
    public VehicleGetAngle createVehicleGetAngle() {
        return new VehicleGetAngle();
    }

    /**
     * Create an instance of {@link PolygonSetType }
     * 
     */
    public PolygonSetType createPolygonSetType() {
        return new PolygonSetType();
    }

    /**
     * Create an instance of {@link SimulationGetBusStopWaitingResponse }
     * 
     */
    public SimulationGetBusStopWaitingResponse createSimulationGetBusStopWaitingResponse() {
        return new SimulationGetBusStopWaitingResponse();
    }

    /**
     * Create an instance of {@link VehicleGetPositionResponse }
     * 
     */
    public VehicleGetPositionResponse createVehicleGetPositionResponse() {
        return new VehicleGetPositionResponse();
    }

    /**
     * Create an instance of {@link SimulationGetLoadedNumberResponse }
     * 
     */
    public SimulationGetLoadedNumberResponse createSimulationGetLoadedNumberResponse() {
        return new SimulationGetLoadedNumberResponse();
    }

    /**
     * Create an instance of {@link DoTimestep }
     * 
     */
    public DoTimestep createDoTimestep() {
        return new DoTimestep();
    }

    /**
     * Create an instance of {@link LaneGetIDList }
     * 
     */
    public LaneGetIDList createLaneGetIDList() {
        return new LaneGetIDList();
    }

    /**
     * Create an instance of {@link InductionloopGetLastStepVehicleNumberResponse }
     * 
     */
    public InductionloopGetLastStepVehicleNumberResponse createInductionloopGetLastStepVehicleNumberResponse() {
        return new InductionloopGetLastStepVehicleNumberResponse();
    }

    /**
     * Create an instance of {@link TrafficlightsGetRedYellowGreenState }
     * 
     */
    public TrafficlightsGetRedYellowGreenState createTrafficlightsGetRedYellowGreenState() {
        return new TrafficlightsGetRedYellowGreenState();
    }

    /**
     * Create an instance of {@link EdgeGetLastStepMeanSpeedResponse }
     * 
     */
    public EdgeGetLastStepMeanSpeedResponse createEdgeGetLastStepMeanSpeedResponse() {
        return new EdgeGetLastStepMeanSpeedResponse();
    }

    /**
     * Create an instance of {@link StartResponse }
     * 
     */
    public StartResponse createStartResponse() {
        return new StartResponse();
    }

    /**
     * Create an instance of {@link VehicleGetHCEmissionResponse }
     * 
     */
    public VehicleGetHCEmissionResponse createVehicleGetHCEmissionResponse() {
        return new VehicleGetHCEmissionResponse();
    }

    /**
     * Create an instance of {@link EdgeGetWaitingTimeResponse }
     * 
     */
    public EdgeGetWaitingTimeResponse createEdgeGetWaitingTimeResponse() {
        return new EdgeGetWaitingTimeResponse();
    }

    /**
     * Create an instance of {@link VersionResponse }
     * 
     */
    public VersionResponse createVersionResponse() {
        return new VersionResponse();
    }

    /**
     * Create an instance of {@link LaneGetCO2Emission }
     * 
     */
    public LaneGetCO2Emission createLaneGetCO2Emission() {
        return new LaneGetCO2Emission();
    }

    /**
     * Create an instance of {@link EdgeSetEffortResponse }
     * 
     */
    public EdgeSetEffortResponse createEdgeSetEffortResponse() {
        return new EdgeSetEffortResponse();
    }

    /**
     * Create an instance of {@link InductionloopGetLastStepVehicleIDsResponse }
     * 
     */
    public InductionloopGetLastStepVehicleIDsResponse createInductionloopGetLastStepVehicleIDsResponse() {
        return new InductionloopGetLastStepVehicleIDsResponse();
    }

    /**
     * Create an instance of {@link JunctionGetPosition }
     * 
     */
    public JunctionGetPosition createJunctionGetPosition() {
        return new JunctionGetPosition();
    }

    /**
     * Create an instance of {@link TrafficlightsGetPhaseDuration }
     * 
     */
    public TrafficlightsGetPhaseDuration createTrafficlightsGetPhaseDuration() {
        return new TrafficlightsGetPhaseDuration();
    }

    /**
     * Create an instance of {@link VehicleSetAccelResponse }
     * 
     */
    public VehicleSetAccelResponse createVehicleSetAccelResponse() {
        return new VehicleSetAccelResponse();
    }

    /**
     * Create an instance of {@link EdgeGetCOEmission }
     * 
     */
    public EdgeGetCOEmission createEdgeGetCOEmission() {
        return new EdgeGetCOEmission();
    }

    /**
     * Create an instance of {@link EdgeGetNoiseEmissionResponse }
     * 
     */
    public EdgeGetNoiseEmissionResponse createEdgeGetNoiseEmissionResponse() {
        return new EdgeGetNoiseEmissionResponse();
    }

    /**
     * Create an instance of {@link TrafficlightsSetRedYellowGreenState }
     * 
     */
    public TrafficlightsSetRedYellowGreenState createTrafficlightsSetRedYellowGreenState() {
        return new TrafficlightsSetRedYellowGreenState();
    }

    /**
     * Create an instance of {@link PolygonSetTypeResponse }
     * 
     */
    public PolygonSetTypeResponse createPolygonSetTypeResponse() {
        return new PolygonSetTypeResponse();
    }

    /**
     * Create an instance of {@link AddOption }
     * 
     */
    public AddOption createAddOption() {
        return new AddOption();
    }

    /**
     * Create an instance of {@link VehicleGetMaxSpeedResponse }
     * 
     */
    public VehicleGetMaxSpeedResponse createVehicleGetMaxSpeedResponse() {
        return new VehicleGetMaxSpeedResponse();
    }

    /**
     * Create an instance of {@link VehicletypeGetMinGapResponse }
     * 
     */
    public VehicletypeGetMinGapResponse createVehicletypeGetMinGapResponse() {
        return new VehicletypeGetMinGapResponse();
    }

    /**
     * Create an instance of {@link VehicletypeGetTau }
     * 
     */
    public VehicletypeGetTau createVehicletypeGetTau() {
        return new VehicletypeGetTau();
    }

    /**
     * Create an instance of {@link PolygonGetColorResponse }
     * 
     */
    public PolygonGetColorResponse createPolygonGetColorResponse() {
        return new PolygonGetColorResponse();
    }

    /**
     * Create an instance of {@link VehicletypeGetShapeClassResponse }
     * 
     */
    public VehicletypeGetShapeClassResponse createVehicletypeGetShapeClassResponse() {
        return new VehicletypeGetShapeClassResponse();
    }

    /**
     * Create an instance of {@link GetStatusResponse }
     * 
     */
    public GetStatusResponse createGetStatusResponse() {
        return new GetStatusResponse();
    }

    /**
     * Create an instance of {@link VehicleGetNOxEmission }
     * 
     */
    public VehicleGetNOxEmission createVehicleGetNOxEmission() {
        return new VehicleGetNOxEmission();
    }

    /**
     * Create an instance of {@link LaneGetTraveltime }
     * 
     */
    public LaneGetTraveltime createLaneGetTraveltime() {
        return new LaneGetTraveltime();
    }

    /**
     * Create an instance of {@link EdgeGetLastStepVehicleIDs }
     * 
     */
    public EdgeGetLastStepVehicleIDs createEdgeGetLastStepVehicleIDs() {
        return new EdgeGetLastStepVehicleIDs();
    }

    /**
     * Create an instance of {@link PolygonSetColorResponse }
     * 
     */
    public PolygonSetColorResponse createPolygonSetColorResponse() {
        return new PolygonSetColorResponse();
    }

    /**
     * Create an instance of {@link VehicleSetType }
     * 
     */
    public VehicleSetType createVehicleSetType() {
        return new VehicleSetType();
    }

    /**
     * Create an instance of {@link TrafficlightsGetNextSwitchResponse }
     * 
     */
    public TrafficlightsGetNextSwitchResponse createTrafficlightsGetNextSwitchResponse() {
        return new TrafficlightsGetNextSwitchResponse();
    }

    /**
     * Create an instance of {@link VehicleGetLaneID }
     * 
     */
    public VehicleGetLaneID createVehicleGetLaneID() {
        return new VehicleGetLaneID();
    }

    /**
     * Create an instance of {@link VehicletypeGetSpeedDeviationResponse }
     * 
     */
    public VehicletypeGetSpeedDeviationResponse createVehicletypeGetSpeedDeviationResponse() {
        return new VehicletypeGetSpeedDeviationResponse();
    }

    /**
     * Create an instance of {@link VehicleGetAllowedSpeedResponse }
     * 
     */
    public VehicleGetAllowedSpeedResponse createVehicleGetAllowedSpeedResponse() {
        return new VehicleGetAllowedSpeedResponse();
    }

    /**
     * Create an instance of {@link TrafficlightsGetRedYellowGreenStateResponse }
     * 
     */
    public TrafficlightsGetRedYellowGreenStateResponse createTrafficlightsGetRedYellowGreenStateResponse() {
        return new TrafficlightsGetRedYellowGreenStateResponse();
    }

    /**
     * Create an instance of {@link VehicletypeGetDecel }
     * 
     */
    public VehicletypeGetDecel createVehicletypeGetDecel() {
        return new VehicletypeGetDecel();
    }

    /**
     * Create an instance of {@link VehicleSetRouteID }
     * 
     */
    public VehicleSetRouteID createVehicleSetRouteID() {
        return new VehicleSetRouteID();
    }

    /**
     * Create an instance of {@link VehicleGetPersonNumberResponse }
     * 
     */
    public VehicleGetPersonNumberResponse createVehicleGetPersonNumberResponse() {
        return new VehicleGetPersonNumberResponse();
    }

    /**
     * Create an instance of {@link GUISetOffsetResponse }
     * 
     */
    public GUISetOffsetResponse createGUISetOffsetResponse() {
        return new GUISetOffsetResponse();
    }

    /**
     * Create an instance of {@link VehicleGetAccelResponse }
     * 
     */
    public VehicleGetAccelResponse createVehicleGetAccelResponse() {
        return new VehicleGetAccelResponse();
    }

    /**
     * Create an instance of {@link VehicleGetBestLanesResponse }
     * 
     */
    public VehicleGetBestLanesResponse createVehicleGetBestLanesResponse() {
        return new VehicleGetBestLanesResponse();
    }

    /**
     * Create an instance of {@link VehicleGetLaneIDResponse }
     * 
     */
    public VehicleGetLaneIDResponse createVehicleGetLaneIDResponse() {
        return new VehicleGetLaneIDResponse();
    }

    /**
     * Create an instance of {@link VehicleGetMaxSpeed }
     * 
     */
    public VehicleGetMaxSpeed createVehicleGetMaxSpeed() {
        return new VehicleGetMaxSpeed();
    }

    /**
     * Create an instance of {@link VehicleSetStopResponse }
     * 
     */
    public VehicleSetStopResponse createVehicleSetStopResponse() {
        return new VehicleSetStopResponse();
    }

    /**
     * Create an instance of {@link VehicleSetTau }
     * 
     */
    public VehicleSetTau createVehicleSetTau() {
        return new VehicleSetTau();
    }

    /**
     * Create an instance of {@link VehicleGetFuelConsumption }
     * 
     */
    public VehicleGetFuelConsumption createVehicleGetFuelConsumption() {
        return new VehicleGetFuelConsumption();
    }

    /**
     * Create an instance of {@link TrafficlightsGetIDCount }
     * 
     */
    public TrafficlightsGetIDCount createTrafficlightsGetIDCount() {
        return new TrafficlightsGetIDCount();
    }

    /**
     * Create an instance of {@link EdgeGetNOxEmission }
     * 
     */
    public EdgeGetNOxEmission createEdgeGetNOxEmission() {
        return new EdgeGetNOxEmission();
    }

    /**
     * Create an instance of {@link VehicleSetRouteResponse }
     * 
     */
    public VehicleSetRouteResponse createVehicleSetRouteResponse() {
        return new VehicleSetRouteResponse();
    }

    /**
     * Create an instance of {@link ArealDetectorGetJamLengthVehicleResponse }
     * 
     */
    public ArealDetectorGetJamLengthVehicleResponse createArealDetectorGetJamLengthVehicleResponse() {
        return new ArealDetectorGetJamLengthVehicleResponse();
    }

    /**
     * Create an instance of {@link MultientryexitGetLastStepMeanSpeedResponse }
     * 
     */
    public MultientryexitGetLastStepMeanSpeedResponse createMultientryexitGetLastStepMeanSpeedResponse() {
        return new MultientryexitGetLastStepMeanSpeedResponse();
    }

    /**
     * Create an instance of {@link LaneGetLastStepVehicleNumberResponse }
     * 
     */
    public LaneGetLastStepVehicleNumberResponse createLaneGetLastStepVehicleNumberResponse() {
        return new LaneGetLastStepVehicleNumberResponse();
    }

    /**
     * Create an instance of {@link VehicletypeGetEmissionClassResponse }
     * 
     */
    public VehicletypeGetEmissionClassResponse createVehicletypeGetEmissionClassResponse() {
        return new VehicletypeGetEmissionClassResponse();
    }

    /**
     * Create an instance of {@link VehicleSetAdaptedTraveltimeResponse }
     * 
     */
    public VehicleSetAdaptedTraveltimeResponse createVehicleSetAdaptedTraveltimeResponse() {
        return new VehicleSetAdaptedTraveltimeResponse();
    }

    /**
     * Create an instance of {@link PolygonGetShape }
     * 
     */
    public PolygonGetShape createPolygonGetShape() {
        return new PolygonGetShape();
    }

    /**
     * Create an instance of {@link EdgeGetCO2EmissionResponse }
     * 
     */
    public EdgeGetCO2EmissionResponse createEdgeGetCO2EmissionResponse() {
        return new EdgeGetCO2EmissionResponse();
    }

    /**
     * Create an instance of {@link PolygonGetIDList }
     * 
     */
    public PolygonGetIDList createPolygonGetIDList() {
        return new PolygonGetIDList();
    }

    /**
     * Create an instance of {@link PoiRemove }
     * 
     */
    public PoiRemove createPoiRemove() {
        return new PoiRemove();
    }

    /**
     * Create an instance of {@link VehicleSetEmissionClass }
     * 
     */
    public VehicleSetEmissionClass createVehicleSetEmissionClass() {
        return new VehicleSetEmissionClass();
    }

    /**
     * Create an instance of {@link EdgeGetIDListResponse }
     * 
     */
    public EdgeGetIDListResponse createEdgeGetIDListResponse() {
        return new EdgeGetIDListResponse();
    }

    /**
     * Create an instance of {@link SimulationGetArrivedIDListResponse }
     * 
     */
    public SimulationGetArrivedIDListResponse createSimulationGetArrivedIDListResponse() {
        return new SimulationGetArrivedIDListResponse();
    }

    /**
     * Create an instance of {@link ArealDetectorGetIDList }
     * 
     */
    public ArealDetectorGetIDList createArealDetectorGetIDList() {
        return new ArealDetectorGetIDList();
    }

    /**
     * Create an instance of {@link ArealDetectorGetJamLengthMeters }
     * 
     */
    public ArealDetectorGetJamLengthMeters createArealDetectorGetJamLengthMeters() {
        return new ArealDetectorGetJamLengthMeters();
    }

    /**
     * Create an instance of {@link MultientryexitGetIDList }
     * 
     */
    public MultientryexitGetIDList createMultientryexitGetIDList() {
        return new MultientryexitGetIDList();
    }

    /**
     * Create an instance of {@link LaneGetShapeResponse }
     * 
     */
    public LaneGetShapeResponse createLaneGetShapeResponse() {
        return new LaneGetShapeResponse();
    }

    /**
     * Create an instance of {@link JunctionGetIDCount }
     * 
     */
    public JunctionGetIDCount createJunctionGetIDCount() {
        return new JunctionGetIDCount();
    }

    /**
     * Create an instance of {@link LaneGetLastStepMeanSpeedResponse }
     * 
     */
    public LaneGetLastStepMeanSpeedResponse createLaneGetLastStepMeanSpeedResponse() {
        return new LaneGetLastStepMeanSpeedResponse();
    }

    /**
     * Create an instance of {@link TrafficlightsGetCompleteRedYellowGreenDefinitionResponse }
     * 
     */
    public TrafficlightsGetCompleteRedYellowGreenDefinitionResponse createTrafficlightsGetCompleteRedYellowGreenDefinitionResponse() {
        return new TrafficlightsGetCompleteRedYellowGreenDefinitionResponse();
    }

    /**
     * Create an instance of {@link TrafficlightsGetControlledLanes }
     * 
     */
    public TrafficlightsGetControlledLanes createTrafficlightsGetControlledLanes() {
        return new TrafficlightsGetControlledLanes();
    }

    /**
     * Create an instance of {@link VehicleGetVehicleClassResponse }
     * 
     */
    public VehicleGetVehicleClassResponse createVehicleGetVehicleClassResponse() {
        return new VehicleGetVehicleClassResponse();
    }

    /**
     * Create an instance of {@link VehicleGetCO2Emission }
     * 
     */
    public VehicleGetCO2Emission createVehicleGetCO2Emission() {
        return new VehicleGetCO2Emission();
    }

    /**
     * Create an instance of {@link VehicletypeGetIDCountResponse }
     * 
     */
    public VehicletypeGetIDCountResponse createVehicletypeGetIDCountResponse() {
        return new VehicletypeGetIDCountResponse();
    }

    /**
     * Create an instance of {@link VehicleGetSpeedDeviation }
     * 
     */
    public VehicleGetSpeedDeviation createVehicleGetSpeedDeviation() {
        return new VehicleGetSpeedDeviation();
    }

    /**
     * Create an instance of {@link VehicletypeSetWidth }
     * 
     */
    public VehicletypeSetWidth createVehicletypeSetWidth() {
        return new VehicletypeSetWidth();
    }

    /**
     * Create an instance of {@link VehicleGetPMxEmissionResponse }
     * 
     */
    public VehicleGetPMxEmissionResponse createVehicleGetPMxEmissionResponse() {
        return new VehicleGetPMxEmissionResponse();
    }

    /**
     * Create an instance of {@link LaneGetIDCountResponse }
     * 
     */
    public LaneGetIDCountResponse createLaneGetIDCountResponse() {
        return new LaneGetIDCountResponse();
    }

    /**
     * Create an instance of {@link PolygonGetTypeResponse }
     * 
     */
    public PolygonGetTypeResponse createPolygonGetTypeResponse() {
        return new PolygonGetTypeResponse();
    }

    /**
     * Create an instance of {@link PolygonSetShapeResponse }
     * 
     */
    public PolygonSetShapeResponse createPolygonSetShapeResponse() {
        return new PolygonSetShapeResponse();
    }

    /**
     * Create an instance of {@link PoiGetIDCount }
     * 
     */
    public PoiGetIDCount createPoiGetIDCount() {
        return new PoiGetIDCount();
    }

    /**
     * Create an instance of {@link SimulationGetParkingStartingVehiclesIDListResponse }
     * 
     */
    public SimulationGetParkingStartingVehiclesIDListResponse createSimulationGetParkingStartingVehiclesIDListResponse() {
        return new SimulationGetParkingStartingVehiclesIDListResponse();
    }

    /**
     * Create an instance of {@link LaneGetMaxSpeedResponse }
     * 
     */
    public LaneGetMaxSpeedResponse createLaneGetMaxSpeedResponse() {
        return new LaneGetMaxSpeedResponse();
    }

    /**
     * Create an instance of {@link VehicleGetTypeIDResponse }
     * 
     */
    public VehicleGetTypeIDResponse createVehicleGetTypeIDResponse() {
        return new VehicleGetTypeIDResponse();
    }

    /**
     * Create an instance of {@link VehicleGetEmissionClass }
     * 
     */
    public VehicleGetEmissionClass createVehicleGetEmissionClass() {
        return new VehicleGetEmissionClass();
    }

    /**
     * Create an instance of {@link PoiSetColorResponse }
     * 
     */
    public PoiSetColorResponse createPoiSetColorResponse() {
        return new PoiSetColorResponse();
    }

    /**
     * Create an instance of {@link PolygonGetColor }
     * 
     */
    public PolygonGetColor createPolygonGetColor() {
        return new PolygonGetColor();
    }

    /**
     * Create an instance of {@link LaneSetLengthResponse }
     * 
     */
    public LaneSetLengthResponse createLaneSetLengthResponse() {
        return new LaneSetLengthResponse();
    }

    /**
     * Create an instance of {@link EdgeGetLastStepVehicleIDsResponse }
     * 
     */
    public EdgeGetLastStepVehicleIDsResponse createEdgeGetLastStepVehicleIDsResponse() {
        return new EdgeGetLastStepVehicleIDsResponse();
    }

    /**
     * Create an instance of {@link VehicletypeSetVehicleClass }
     * 
     */
    public VehicletypeSetVehicleClass createVehicletypeSetVehicleClass() {
        return new VehicletypeSetVehicleClass();
    }

    /**
     * Create an instance of {@link TrafficlightsGetPhaseResponse }
     * 
     */
    public TrafficlightsGetPhaseResponse createTrafficlightsGetPhaseResponse() {
        return new TrafficlightsGetPhaseResponse();
    }

    /**
     * Create an instance of {@link EdgeGetLastStepOccupancy }
     * 
     */
    public EdgeGetLastStepOccupancy createEdgeGetLastStepOccupancy() {
        return new EdgeGetLastStepOccupancy();
    }

    /**
     * Create an instance of {@link VehicleGetImperfection }
     * 
     */
    public VehicleGetImperfection createVehicleGetImperfection() {
        return new VehicleGetImperfection();
    }

    /**
     * Create an instance of {@link VehicletypeGetTauResponse }
     * 
     */
    public VehicletypeGetTauResponse createVehicletypeGetTauResponse() {
        return new VehicletypeGetTauResponse();
    }

    /**
     * Create an instance of {@link VehicletypeGetVehicleClassResponse }
     * 
     */
    public VehicletypeGetVehicleClassResponse createVehicletypeGetVehicleClassResponse() {
        return new VehicletypeGetVehicleClassResponse();
    }

    /**
     * Create an instance of {@link JunctionGetIDList }
     * 
     */
    public JunctionGetIDList createJunctionGetIDList() {
        return new JunctionGetIDList();
    }

    /**
     * Create an instance of {@link LaneGetLinks }
     * 
     */
    public LaneGetLinks createLaneGetLinks() {
        return new LaneGetLinks();
    }

    /**
     * Create an instance of {@link VehicleGetSpeedWithoutTraCI }
     * 
     */
    public VehicleGetSpeedWithoutTraCI createVehicleGetSpeedWithoutTraCI() {
        return new VehicleGetSpeedWithoutTraCI();
    }

    /**
     * Create an instance of {@link VehicleIsRouteValidResponse }
     * 
     */
    public VehicleIsRouteValidResponse createVehicleIsRouteValidResponse() {
        return new VehicleIsRouteValidResponse();
    }

    /**
     * Create an instance of {@link PolygonGetIDCountResponse }
     * 
     */
    public PolygonGetIDCountResponse createPolygonGetIDCountResponse() {
        return new PolygonGetIDCountResponse();
    }

    /**
     * Create an instance of {@link VehicleGetMinGapResponse }
     * 
     */
    public VehicleGetMinGapResponse createVehicleGetMinGapResponse() {
        return new VehicleGetMinGapResponse();
    }

    /**
     * Create an instance of {@link VehicletypeGetColor }
     * 
     */
    public VehicletypeGetColor createVehicletypeGetColor() {
        return new VehicletypeGetColor();
    }

    /**
     * Create an instance of {@link VehicleSetSpeedFactorResponse }
     * 
     */
    public VehicleSetSpeedFactorResponse createVehicleSetSpeedFactorResponse() {
        return new VehicleSetSpeedFactorResponse();
    }

    /**
     * Create an instance of {@link InductionloopGetLastStepOccupancyResponse }
     * 
     */
    public InductionloopGetLastStepOccupancyResponse createInductionloopGetLastStepOccupancyResponse() {
        return new InductionloopGetLastStepOccupancyResponse();
    }

    /**
     * Create an instance of {@link VehicleGetColorResponse }
     * 
     */
    public VehicleGetColorResponse createVehicleGetColorResponse() {
        return new VehicleGetColorResponse();
    }

    /**
     * Create an instance of {@link PoiGetIDCountResponse }
     * 
     */
    public PoiGetIDCountResponse createPoiGetIDCountResponse() {
        return new PoiGetIDCountResponse();
    }

    /**
     * Create an instance of {@link SimulationGetDistanceRoad }
     * 
     */
    public SimulationGetDistanceRoad createSimulationGetDistanceRoad() {
        return new SimulationGetDistanceRoad();
    }

    /**
     * Create an instance of {@link TrafficlightsSetCompleteRedYellowGreenDefinition }
     * 
     */
    public TrafficlightsSetCompleteRedYellowGreenDefinition createTrafficlightsSetCompleteRedYellowGreenDefinition() {
        return new TrafficlightsSetCompleteRedYellowGreenDefinition();
    }

    /**
     * Create an instance of {@link LaneGetWidthResponse }
     * 
     */
    public LaneGetWidthResponse createLaneGetWidthResponse() {
        return new LaneGetWidthResponse();
    }

    /**
     * Create an instance of {@link VehicletypeSetEmissionClassResponse }
     * 
     */
    public VehicletypeSetEmissionClassResponse createVehicletypeSetEmissionClassResponse() {
        return new VehicletypeSetEmissionClassResponse();
    }

    /**
     * Create an instance of {@link PoiGetColor }
     * 
     */
    public PoiGetColor createPoiGetColor() {
        return new PoiGetColor();
    }

    /**
     * Create an instance of {@link LaneGetCOEmission }
     * 
     */
    public LaneGetCOEmission createLaneGetCOEmission() {
        return new LaneGetCOEmission();
    }

    /**
     * Create an instance of {@link MultientryexitGetIDCountResponse }
     * 
     */
    public MultientryexitGetIDCountResponse createMultientryexitGetIDCountResponse() {
        return new MultientryexitGetIDCountResponse();
    }

    /**
     * Create an instance of {@link VehicletypeSetMinGap }
     * 
     */
    public VehicletypeSetMinGap createVehicletypeSetMinGap() {
        return new VehicletypeSetMinGap();
    }

    /**
     * Create an instance of {@link EdgeGetHCEmissionResponse }
     * 
     */
    public EdgeGetHCEmissionResponse createEdgeGetHCEmissionResponse() {
        return new EdgeGetHCEmissionResponse();
    }

    /**
     * Create an instance of {@link VehicleSetSpeed }
     * 
     */
    public VehicleSetSpeed createVehicleSetSpeed() {
        return new VehicleSetSpeed();
    }

    /**
     * Create an instance of {@link VehicleGetSpeedWithoutTraCIResponse }
     * 
     */
    public VehicleGetSpeedWithoutTraCIResponse createVehicleGetSpeedWithoutTraCIResponse() {
        return new VehicleGetSpeedWithoutTraCIResponse();
    }

    /**
     * Create an instance of {@link GUIGetBoundaryResponse }
     * 
     */
    public GUIGetBoundaryResponse createGUIGetBoundaryResponse() {
        return new GUIGetBoundaryResponse();
    }

    /**
     * Create an instance of {@link SimulationGetParkingStartingVehiclesNumberResponse }
     * 
     */
    public SimulationGetParkingStartingVehiclesNumberResponse createSimulationGetParkingStartingVehiclesNumberResponse() {
        return new SimulationGetParkingStartingVehiclesNumberResponse();
    }

    /**
     * Create an instance of {@link EdgeGetAdaptedTraveltimeResponse }
     * 
     */
    public EdgeGetAdaptedTraveltimeResponse createEdgeGetAdaptedTraveltimeResponse() {
        return new EdgeGetAdaptedTraveltimeResponse();
    }

    /**
     * Create an instance of {@link RouteGetIDListResponse }
     * 
     */
    public RouteGetIDListResponse createRouteGetIDListResponse() {
        return new RouteGetIDListResponse();
    }

    /**
     * Create an instance of {@link VehicleChangeLane }
     * 
     */
    public VehicleChangeLane createVehicleChangeLane() {
        return new VehicleChangeLane();
    }

    /**
     * Create an instance of {@link PoiGetPositionResponse }
     * 
     */
    public PoiGetPositionResponse createPoiGetPositionResponse() {
        return new PoiGetPositionResponse();
    }

    /**
     * Create an instance of {@link GUIGetIDListResponse }
     * 
     */
    public GUIGetIDListResponse createGUIGetIDListResponse() {
        return new GUIGetIDListResponse();
    }

    /**
     * Create an instance of {@link Start }
     * 
     */
    public Start createStart() {
        return new Start();
    }

    /**
     * Create an instance of {@link VehicleIsRouteValid }
     * 
     */
    public VehicleIsRouteValid createVehicleIsRouteValid() {
        return new VehicleIsRouteValid();
    }

    /**
     * Create an instance of {@link JunctionGetShape }
     * 
     */
    public JunctionGetShape createJunctionGetShape() {
        return new JunctionGetShape();
    }

    /**
     * Create an instance of {@link TrafficlightsSetCompleteRedYellowGreenDefinitionResponse }
     * 
     */
    public TrafficlightsSetCompleteRedYellowGreenDefinitionResponse createTrafficlightsSetCompleteRedYellowGreenDefinitionResponse() {
        return new TrafficlightsSetCompleteRedYellowGreenDefinitionResponse();
    }

    /**
     * Create an instance of {@link LaneGetNOxEmissionResponse }
     * 
     */
    public LaneGetNOxEmissionResponse createLaneGetNOxEmissionResponse() {
        return new LaneGetNOxEmissionResponse();
    }

    /**
     * Create an instance of {@link InductionloopGetIDCountResponse }
     * 
     */
    public InductionloopGetIDCountResponse createInductionloopGetIDCountResponse() {
        return new InductionloopGetIDCountResponse();
    }

    /**
     * Create an instance of {@link VehicleGetNOxEmissionResponse }
     * 
     */
    public VehicleGetNOxEmissionResponse createVehicleGetNOxEmissionResponse() {
        return new VehicleGetNOxEmissionResponse();
    }

    /**
     * Create an instance of {@link SimulationConvertRoadResponse }
     * 
     */
    public SimulationConvertRoadResponse createSimulationConvertRoadResponse() {
        return new SimulationConvertRoadResponse();
    }

    /**
     * Create an instance of {@link PolygonGetIDCount }
     * 
     */
    public PolygonGetIDCount createPolygonGetIDCount() {
        return new PolygonGetIDCount();
    }

    /**
     * Create an instance of {@link VehicletypeSetMinGapResponse }
     * 
     */
    public VehicletypeSetMinGapResponse createVehicletypeSetMinGapResponse() {
        return new VehicletypeSetMinGapResponse();
    }

    /**
     * Create an instance of {@link SimulationGetLoadedIDList }
     * 
     */
    public SimulationGetLoadedIDList createSimulationGetLoadedIDList() {
        return new SimulationGetLoadedIDList();
    }

    /**
     * Create an instance of {@link VehicleGetDistance }
     * 
     */
    public VehicleGetDistance createVehicleGetDistance() {
        return new VehicleGetDistance();
    }

    /**
     * Create an instance of {@link GUIGetSchema }
     * 
     */
    public GUIGetSchema createGUIGetSchema() {
        return new GUIGetSchema();
    }

    /**
     * Create an instance of {@link LastActionTimeResponse }
     * 
     */
    public LastActionTimeResponse createLastActionTimeResponse() {
        return new LastActionTimeResponse();
    }

    /**
     * Create an instance of {@link LaneGetLinkNumberResponse }
     * 
     */
    public LaneGetLinkNumberResponse createLaneGetLinkNumberResponse() {
        return new LaneGetLinkNumberResponse();
    }

    /**
     * Create an instance of {@link VehicleRerouteTraveltime }
     * 
     */
    public VehicleRerouteTraveltime createVehicleRerouteTraveltime() {
        return new VehicleRerouteTraveltime();
    }

    /**
     * Create an instance of {@link GUIGetBoundary }
     * 
     */
    public GUIGetBoundary createGUIGetBoundary() {
        return new GUIGetBoundary();
    }

    /**
     * Create an instance of {@link TrafficlightsGetControlledLinks }
     * 
     */
    public TrafficlightsGetControlledLinks createTrafficlightsGetControlledLinks() {
        return new TrafficlightsGetControlledLinks();
    }

    /**
     * Create an instance of {@link Version }
     * 
     */
    public Version createVersion() {
        return new Version();
    }

    /**
     * Create an instance of {@link LaneGetLastStepMeanSpeed }
     * 
     */
    public LaneGetLastStepMeanSpeed createLaneGetLastStepMeanSpeed() {
        return new LaneGetLastStepMeanSpeed();
    }

    /**
     * Create an instance of {@link VehicleGetLengthResponse }
     * 
     */
    public VehicleGetLengthResponse createVehicleGetLengthResponse() {
        return new VehicleGetLengthResponse();
    }

    /**
     * Create an instance of {@link VehicletypeSetShapeClass }
     * 
     */
    public VehicletypeSetShapeClass createVehicletypeSetShapeClass() {
        return new VehicletypeSetShapeClass();
    }

    /**
     * Create an instance of {@link SimulationGetMinExpectedNumber }
     * 
     */
    public SimulationGetMinExpectedNumber createSimulationGetMinExpectedNumber() {
        return new SimulationGetMinExpectedNumber();
    }

    /**
     * Create an instance of {@link VehicleGetLaneIndexResponse }
     * 
     */
    public VehicleGetLaneIndexResponse createVehicleGetLaneIndexResponse() {
        return new VehicleGetLaneIndexResponse();
    }

    /**
     * Create an instance of {@link EdgeGetLastStepOccupancyResponse }
     * 
     */
    public EdgeGetLastStepOccupancyResponse createEdgeGetLastStepOccupancyResponse() {
        return new EdgeGetLastStepOccupancyResponse();
    }

    /**
     * Create an instance of {@link PoiGetTypeResponse }
     * 
     */
    public PoiGetTypeResponse createPoiGetTypeResponse() {
        return new PoiGetTypeResponse();
    }

    /**
     * Create an instance of {@link SimulationGetParkingEndingVehiclesNumber }
     * 
     */
    public SimulationGetParkingEndingVehiclesNumber createSimulationGetParkingEndingVehiclesNumber() {
        return new SimulationGetParkingEndingVehiclesNumber();
    }

    /**
     * Create an instance of {@link VehicleSetTypeResponse }
     * 
     */
    public VehicleSetTypeResponse createVehicleSetTypeResponse() {
        return new VehicleSetTypeResponse();
    }

    /**
     * Create an instance of {@link PolygonGetShapeResponse }
     * 
     */
    public PolygonGetShapeResponse createPolygonGetShapeResponse() {
        return new PolygonGetShapeResponse();
    }

    /**
     * Create an instance of {@link VehicleSetAccel }
     * 
     */
    public VehicleSetAccel createVehicleSetAccel() {
        return new VehicleSetAccel();
    }

    /**
     * Create an instance of {@link TrafficlightsGetControlledLanesResponse }
     * 
     */
    public TrafficlightsGetControlledLanesResponse createTrafficlightsGetControlledLanesResponse() {
        return new TrafficlightsGetControlledLanesResponse();
    }

    /**
     * Create an instance of {@link TrafficlightsGetProgramResponse }
     * 
     */
    public TrafficlightsGetProgramResponse createTrafficlightsGetProgramResponse() {
        return new TrafficlightsGetProgramResponse();
    }

    /**
     * Create an instance of {@link InductionloopGetVehicleDataResponse }
     * 
     */
    public InductionloopGetVehicleDataResponse createInductionloopGetVehicleDataResponse() {
        return new InductionloopGetVehicleDataResponse();
    }

    /**
     * Create an instance of {@link SimulationGetEndingTeleportNumberResponse }
     * 
     */
    public SimulationGetEndingTeleportNumberResponse createSimulationGetEndingTeleportNumberResponse() {
        return new SimulationGetEndingTeleportNumberResponse();
    }

    /**
     * Create an instance of {@link VehicleGetCOEmissionResponse }
     * 
     */
    public VehicleGetCOEmissionResponse createVehicleGetCOEmissionResponse() {
        return new VehicleGetCOEmissionResponse();
    }

    /**
     * Create an instance of {@link EdgeGetLastStepVehicleNumberResponse }
     * 
     */
    public EdgeGetLastStepVehicleNumberResponse createEdgeGetLastStepVehicleNumberResponse() {
        return new EdgeGetLastStepVehicleNumberResponse();
    }

    /**
     * Create an instance of {@link VehicleGetLanePosition }
     * 
     */
    public VehicleGetLanePosition createVehicleGetLanePosition() {
        return new VehicleGetLanePosition();
    }

    /**
     * Create an instance of {@link VehicleSetVehicleClass }
     * 
     */
    public VehicleSetVehicleClass createVehicleSetVehicleClass() {
        return new VehicleSetVehicleClass();
    }

    /**
     * Create an instance of {@link VehicleGetTauResponse }
     * 
     */
    public VehicleGetTauResponse createVehicleGetTauResponse() {
        return new VehicleGetTauResponse();
    }

    /**
     * Create an instance of {@link VehicleSetSignals }
     * 
     */
    public VehicleSetSignals createVehicleSetSignals() {
        return new VehicleSetSignals();
    }

    /**
     * Create an instance of {@link TrafficlightsGetPhase }
     * 
     */
    public TrafficlightsGetPhase createTrafficlightsGetPhase() {
        return new TrafficlightsGetPhase();
    }

    /**
     * Create an instance of {@link LaneGetDisallowedResponse }
     * 
     */
    public LaneGetDisallowedResponse createLaneGetDisallowedResponse() {
        return new LaneGetDisallowedResponse();
    }

    /**
     * Create an instance of {@link PolygonAdd }
     * 
     */
    public PolygonAdd createPolygonAdd() {
        return new PolygonAdd();
    }

    /**
     * Create an instance of {@link VehicleSetWidthResponse }
     * 
     */
    public VehicleSetWidthResponse createVehicleSetWidthResponse() {
        return new VehicleSetWidthResponse();
    }

    /**
     * Create an instance of {@link LaneGetLastStepVehicleIDsResponse }
     * 
     */
    public LaneGetLastStepVehicleIDsResponse createLaneGetLastStepVehicleIDsResponse() {
        return new LaneGetLastStepVehicleIDsResponse();
    }

    /**
     * Create an instance of {@link VehicleGetRoute }
     * 
     */
    public VehicleGetRoute createVehicleGetRoute() {
        return new VehicleGetRoute();
    }

    /**
     * Create an instance of {@link VehicleSetLaneChangeModeResponse }
     * 
     */
    public VehicleSetLaneChangeModeResponse createVehicleSetLaneChangeModeResponse() {
        return new VehicleSetLaneChangeModeResponse();
    }

    /**
     * Create an instance of {@link VehicleSetColor }
     * 
     */
    public VehicleSetColor createVehicleSetColor() {
        return new VehicleSetColor();
    }

    /**
     * Create an instance of {@link VehicletypeSetLength }
     * 
     */
    public VehicletypeSetLength createVehicletypeSetLength() {
        return new VehicletypeSetLength();
    }

    /**
     * Create an instance of {@link LaneGetMaxSpeed }
     * 
     */
    public LaneGetMaxSpeed createLaneGetMaxSpeed() {
        return new LaneGetMaxSpeed();
    }

    /**
     * Create an instance of {@link RouteAdd }
     * 
     */
    public RouteAdd createRouteAdd() {
        return new RouteAdd();
    }

    /**
     * Create an instance of {@link VehicleGetNoiseEmission }
     * 
     */
    public VehicleGetNoiseEmission createVehicleGetNoiseEmission() {
        return new VehicleGetNoiseEmission();
    }

    /**
     * Create an instance of {@link ArealDetectorGetJamLengthVehicle }
     * 
     */
    public ArealDetectorGetJamLengthVehicle createArealDetectorGetJamLengthVehicle() {
        return new ArealDetectorGetJamLengthVehicle();
    }

    /**
     * Create an instance of {@link VehicleSetMinGap }
     * 
     */
    public VehicleSetMinGap createVehicleSetMinGap() {
        return new VehicleSetMinGap();
    }

    /**
     * Create an instance of {@link VehicleSetSignalsResponse }
     * 
     */
    public VehicleSetSignalsResponse createVehicleSetSignalsResponse() {
        return new VehicleSetSignalsResponse();
    }

    /**
     * Create an instance of {@link EdgeGetFuelConsumption }
     * 
     */
    public EdgeGetFuelConsumption createEdgeGetFuelConsumption() {
        return new EdgeGetFuelConsumption();
    }

    /**
     * Create an instance of {@link SimulationGetNetBoundary }
     * 
     */
    public SimulationGetNetBoundary createSimulationGetNetBoundary() {
        return new SimulationGetNetBoundary();
    }

    /**
     * Create an instance of {@link SimulationGetParkingEndingVehiclesNumberResponse }
     * 
     */
    public SimulationGetParkingEndingVehiclesNumberResponse createSimulationGetParkingEndingVehiclesNumberResponse() {
        return new SimulationGetParkingEndingVehiclesNumberResponse();
    }

    /**
     * Create an instance of {@link JunctionGetIDListResponse }
     * 
     */
    public JunctionGetIDListResponse createJunctionGetIDListResponse() {
        return new JunctionGetIDListResponse();
    }

    /**
     * Create an instance of {@link VehicleGetEffort }
     * 
     */
    public VehicleGetEffort createVehicleGetEffort() {
        return new VehicleGetEffort();
    }

    /**
     * Create an instance of {@link VehicleGetAdaptedTraveltime }
     * 
     */
    public VehicleGetAdaptedTraveltime createVehicleGetAdaptedTraveltime() {
        return new VehicleGetAdaptedTraveltime();
    }

    /**
     * Create an instance of {@link VehicleGetSpeedFactor }
     * 
     */
    public VehicleGetSpeedFactor createVehicleGetSpeedFactor() {
        return new VehicleGetSpeedFactor();
    }

    /**
     * Create an instance of {@link SimulationGetLoadedNumber }
     * 
     */
    public SimulationGetLoadedNumber createSimulationGetLoadedNumber() {
        return new SimulationGetLoadedNumber();
    }

    /**
     * Create an instance of {@link SimulationGetEndingTeleportIDList }
     * 
     */
    public SimulationGetEndingTeleportIDList createSimulationGetEndingTeleportIDList() {
        return new SimulationGetEndingTeleportIDList();
    }

    /**
     * Create an instance of {@link VehicleAdd }
     * 
     */
    public VehicleAdd createVehicleAdd() {
        return new VehicleAdd();
    }

    /**
     * Create an instance of {@link VehicleRemove }
     * 
     */
    public VehicleRemove createVehicleRemove() {
        return new VehicleRemove();
    }

    /**
     * Create an instance of {@link EdgeGetAdaptedTraveltime }
     * 
     */
    public EdgeGetAdaptedTraveltime createEdgeGetAdaptedTraveltime() {
        return new EdgeGetAdaptedTraveltime();
    }

    /**
     * Create an instance of {@link EdgeGetTraveltimeResponse }
     * 
     */
    public EdgeGetTraveltimeResponse createEdgeGetTraveltimeResponse() {
        return new EdgeGetTraveltimeResponse();
    }

    /**
     * Create an instance of {@link LaneGetLinkNumber }
     * 
     */
    public LaneGetLinkNumber createLaneGetLinkNumber() {
        return new LaneGetLinkNumber();
    }

    /**
     * Create an instance of {@link VehicleSetRouteIDResponse }
     * 
     */
    public VehicleSetRouteIDResponse createVehicleSetRouteIDResponse() {
        return new VehicleSetRouteIDResponse();
    }

    /**
     * Create an instance of {@link Stop }
     * 
     */
    public Stop createStop() {
        return new Stop();
    }

    /**
     * Create an instance of {@link TrafficlightsGetIDListResponse }
     * 
     */
    public TrafficlightsGetIDListResponse createTrafficlightsGetIDListResponse() {
        return new TrafficlightsGetIDListResponse();
    }

    /**
     * Create an instance of {@link AddOptionResponse }
     * 
     */
    public AddOptionResponse createAddOptionResponse() {
        return new AddOptionResponse();
    }

    /**
     * Create an instance of {@link GUIGetOffsetResponse }
     * 
     */
    public GUIGetOffsetResponse createGUIGetOffsetResponse() {
        return new GUIGetOffsetResponse();
    }

    /**
     * Create an instance of {@link EdgeGetEffort }
     * 
     */
    public EdgeGetEffort createEdgeGetEffort() {
        return new EdgeGetEffort();
    }

    /**
     * Create an instance of {@link VehicletypeSetImperfection }
     * 
     */
    public VehicletypeSetImperfection createVehicletypeSetImperfection() {
        return new VehicletypeSetImperfection();
    }

    /**
     * Create an instance of {@link VehicleGetSpeedDeviationResponse }
     * 
     */
    public VehicleGetSpeedDeviationResponse createVehicleGetSpeedDeviationResponse() {
        return new VehicleGetSpeedDeviationResponse();
    }

    /**
     * Create an instance of {@link LaneSetMaxSpeedResponse }
     * 
     */
    public LaneSetMaxSpeedResponse createLaneSetMaxSpeedResponse() {
        return new LaneSetMaxSpeedResponse();
    }

    /**
     * Create an instance of {@link GUIGetIDList }
     * 
     */
    public GUIGetIDList createGUIGetIDList() {
        return new GUIGetIDList();
    }

    /**
     * Create an instance of {@link VehicleGetRouteResponse }
     * 
     */
    public VehicleGetRouteResponse createVehicleGetRouteResponse() {
        return new VehicleGetRouteResponse();
    }

    /**
     * Create an instance of {@link TXTOutput }
     * 
     */
    public TXTOutput createTXTOutput() {
        return new TXTOutput();
    }

    /**
     * Create an instance of {@link SimulationGetStartingTeleportNumberResponse }
     * 
     */
    public SimulationGetStartingTeleportNumberResponse createSimulationGetStartingTeleportNumberResponse() {
        return new SimulationGetStartingTeleportNumberResponse();
    }

    /**
     * Create an instance of {@link SimulationGetEndingTeleportNumber }
     * 
     */
    public SimulationGetEndingTeleportNumber createSimulationGetEndingTeleportNumber() {
        return new SimulationGetEndingTeleportNumber();
    }

    /**
     * Create an instance of {@link VehicleMoveToVTDResponse }
     * 
     */
    public VehicleMoveToVTDResponse createVehicleMoveToVTDResponse() {
        return new VehicleMoveToVTDResponse();
    }

    /**
     * Create an instance of {@link VehicleGetAllowedSpeed }
     * 
     */
    public VehicleGetAllowedSpeed createVehicleGetAllowedSpeed() {
        return new VehicleGetAllowedSpeed();
    }

    /**
     * Create an instance of {@link SimulationConvertGeo }
     * 
     */
    public SimulationConvertGeo createSimulationConvertGeo() {
        return new SimulationConvertGeo();
    }

    /**
     * Create an instance of {@link PolygonSetShape }
     * 
     */
    public PolygonSetShape createPolygonSetShape() {
        return new PolygonSetShape();
    }

    /**
     * Create an instance of {@link LaneGetWidth }
     * 
     */
    public LaneGetWidth createLaneGetWidth() {
        return new LaneGetWidth();
    }

    /**
     * Create an instance of {@link EdgeGetCOEmissionResponse }
     * 
     */
    public EdgeGetCOEmissionResponse createEdgeGetCOEmissionResponse() {
        return new EdgeGetCOEmissionResponse();
    }

    /**
     * Create an instance of {@link RouteGetIDCountResponse }
     * 
     */
    public RouteGetIDCountResponse createRouteGetIDCountResponse() {
        return new RouteGetIDCountResponse();
    }

    /**
     * Create an instance of {@link LaneGetPMxEmission }
     * 
     */
    public LaneGetPMxEmission createLaneGetPMxEmission() {
        return new LaneGetPMxEmission();
    }

    /**
     * Create an instance of {@link LaneGetEdgeID }
     * 
     */
    public LaneGetEdgeID createLaneGetEdgeID() {
        return new LaneGetEdgeID();
    }

    /**
     * Create an instance of {@link LaneSetDisallowed }
     * 
     */
    public LaneSetDisallowed createLaneSetDisallowed() {
        return new LaneSetDisallowed();
    }

    /**
     * Create an instance of {@link LaneGetEdgeIDResponse }
     * 
     */
    public LaneGetEdgeIDResponse createLaneGetEdgeIDResponse() {
        return new LaneGetEdgeIDResponse();
    }

    /**
     * Create an instance of {@link VehicleGetDrivingDistance2D }
     * 
     */
    public VehicleGetDrivingDistance2D createVehicleGetDrivingDistance2D() {
        return new VehicleGetDrivingDistance2D();
    }

    /**
     * Create an instance of {@link VehicleGetRoadIDResponse }
     * 
     */
    public VehicleGetRoadIDResponse createVehicleGetRoadIDResponse() {
        return new VehicleGetRoadIDResponse();
    }

    /**
     * Create an instance of {@link SimulationGetArrivedIDList }
     * 
     */
    public SimulationGetArrivedIDList createSimulationGetArrivedIDList() {
        return new SimulationGetArrivedIDList();
    }

    /**
     * Create an instance of {@link VehicleGetSpeedFactorResponse }
     * 
     */
    public VehicleGetSpeedFactorResponse createVehicleGetSpeedFactorResponse() {
        return new VehicleGetSpeedFactorResponse();
    }

    /**
     * Create an instance of {@link DoTimestepResponse }
     * 
     */
    public DoTimestepResponse createDoTimestepResponse() {
        return new DoTimestepResponse();
    }

    /**
     * Create an instance of {@link SetConfig }
     * 
     */
    public SetConfig createSetConfig() {
        return new SetConfig();
    }

    /**
     * Create an instance of {@link SimulationConvertRoad }
     * 
     */
    public SimulationConvertRoad createSimulationConvertRoad() {
        return new SimulationConvertRoad();
    }

    /**
     * Create an instance of {@link VehicleGetImperfectionResponse }
     * 
     */
    public VehicleGetImperfectionResponse createVehicleGetImperfectionResponse() {
        return new VehicleGetImperfectionResponse();
    }

    /**
     * Create an instance of {@link VehicleSetRoute }
     * 
     */
    public VehicleSetRoute createVehicleSetRoute() {
        return new VehicleSetRoute();
    }

    /**
     * Create an instance of {@link EdgeGetLastStepLength }
     * 
     */
    public EdgeGetLastStepLength createEdgeGetLastStepLength() {
        return new EdgeGetLastStepLength();
    }

    /**
     * Create an instance of {@link SimulationGetDepartedNumberResponse }
     * 
     */
    public SimulationGetDepartedNumberResponse createSimulationGetDepartedNumberResponse() {
        return new SimulationGetDepartedNumberResponse();
    }

    /**
     * Create an instance of {@link VehicleSetSpeedDeviation }
     * 
     */
    public VehicleSetSpeedDeviation createVehicleSetSpeedDeviation() {
        return new VehicleSetSpeedDeviation();
    }

    /**
     * Create an instance of {@link VehicleSetEmissionClassResponse }
     * 
     */
    public VehicleSetEmissionClassResponse createVehicleSetEmissionClassResponse() {
        return new VehicleSetEmissionClassResponse();
    }

    /**
     * Create an instance of {@link PoiRemoveResponse }
     * 
     */
    public PoiRemoveResponse createPoiRemoveResponse() {
        return new PoiRemoveResponse();
    }

    /**
     * Create an instance of {@link PoiGetIDListResponse }
     * 
     */
    public PoiGetIDListResponse createPoiGetIDListResponse() {
        return new PoiGetIDListResponse();
    }

    /**
     * Create an instance of {@link LaneGetIDCount }
     * 
     */
    public LaneGetIDCount createLaneGetIDCount() {
        return new LaneGetIDCount();
    }

    /**
     * Create an instance of {@link VehicleGetIDList }
     * 
     */
    public VehicleGetIDList createVehicleGetIDList() {
        return new VehicleGetIDList();
    }

    /**
     * Create an instance of {@link SumoGeometry }
     * 
     */
    public SumoGeometry createSumoGeometry() {
        return new SumoGeometry();
    }

    /**
     * Create an instance of {@link SumoTLSPhase }
     * 
     */
    public SumoTLSPhase createSumoTLSPhase() {
        return new SumoTLSPhase();
    }

    /**
     * Create an instance of {@link SumoTLSLogic }
     * 
     */
    public SumoTLSLogic createSumoTLSLogic() {
        return new SumoTLSLogic();
    }

    /**
     * Create an instance of {@link SumoColor }
     * 
     */
    public SumoColor createSumoColor() {
        return new SumoColor();
    }

    /**
     * Create an instance of {@link SumoPosition2D }
     * 
     */
    public SumoPosition2D createSumoPosition2D() {
        return new SumoPosition2D();
    }

    /**
     * Create an instance of {@link SumoBoundingBox }
     * 
     */
    public SumoBoundingBox createSumoBoundingBox() {
        return new SumoBoundingBox();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetSpeed }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setSpeed")
    public JAXBElement<VehicleSetSpeed> createVehicleSetSpeed(VehicleSetSpeed value) {
        return new JAXBElement<VehicleSetSpeed>(_VehicleSetSpeed_QNAME, VehicleSetSpeed.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetParkingStartingVehiclesNumberResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getParkingStartingVehiclesNumberResponse")
    public JAXBElement<SimulationGetParkingStartingVehiclesNumberResponse> createSimulationGetParkingStartingVehiclesNumberResponse(SimulationGetParkingStartingVehiclesNumberResponse value) {
        return new JAXBElement<SimulationGetParkingStartingVehiclesNumberResponse>(_SimulationGetParkingStartingVehiclesNumberResponse_QNAME, SimulationGetParkingStartingVehiclesNumberResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link GUIGetBoundaryResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "GUI_getBoundaryResponse")
    public JAXBElement<GUIGetBoundaryResponse> createGUIGetBoundaryResponse(GUIGetBoundaryResponse value) {
        return new JAXBElement<GUIGetBoundaryResponse>(_GUIGetBoundaryResponse_QNAME, GUIGetBoundaryResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetSpeedWithoutTraCIResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getSpeedWithoutTraCIResponse")
    public JAXBElement<VehicleGetSpeedWithoutTraCIResponse> createVehicleGetSpeedWithoutTraCIResponse(VehicleGetSpeedWithoutTraCIResponse value) {
        return new JAXBElement<VehicleGetSpeedWithoutTraCIResponse>(_VehicleGetSpeedWithoutTraCIResponse_QNAME, VehicleGetSpeedWithoutTraCIResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleChangeLane }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_changeLane")
    public JAXBElement<VehicleChangeLane> createVehicleChangeLane(VehicleChangeLane value) {
        return new JAXBElement<VehicleChangeLane>(_VehicleChangeLane_QNAME, VehicleChangeLane.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PoiGetPositionResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Poi_getPositionResponse")
    public JAXBElement<PoiGetPositionResponse> createPoiGetPositionResponse(PoiGetPositionResponse value) {
        return new JAXBElement<PoiGetPositionResponse>(_PoiGetPositionResponse_QNAME, PoiGetPositionResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link RouteGetIDListResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Route_getIDListResponse")
    public JAXBElement<RouteGetIDListResponse> createRouteGetIDListResponse(RouteGetIDListResponse value) {
        return new JAXBElement<RouteGetIDListResponse>(_RouteGetIDListResponse_QNAME, RouteGetIDListResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EdgeGetAdaptedTraveltimeResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Edge_getAdaptedTraveltimeResponse")
    public JAXBElement<EdgeGetAdaptedTraveltimeResponse> createEdgeGetAdaptedTraveltimeResponse(EdgeGetAdaptedTraveltimeResponse value) {
        return new JAXBElement<EdgeGetAdaptedTraveltimeResponse>(_EdgeGetAdaptedTraveltimeResponse_QNAME, EdgeGetAdaptedTraveltimeResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TrafficlightsSetCompleteRedYellowGreenDefinitionResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Trafficlights_setCompleteRedYellowGreenDefinitionResponse")
    public JAXBElement<TrafficlightsSetCompleteRedYellowGreenDefinitionResponse> createTrafficlightsSetCompleteRedYellowGreenDefinitionResponse(TrafficlightsSetCompleteRedYellowGreenDefinitionResponse value) {
        return new JAXBElement<TrafficlightsSetCompleteRedYellowGreenDefinitionResponse>(_TrafficlightsSetCompleteRedYellowGreenDefinitionResponse_QNAME, TrafficlightsSetCompleteRedYellowGreenDefinitionResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link JunctionGetShape }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Junction_getShape")
    public JAXBElement<JunctionGetShape> createJunctionGetShape(JunctionGetShape value) {
        return new JAXBElement<JunctionGetShape>(_JunctionGetShape_QNAME, JunctionGetShape.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleIsRouteValid }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_isRouteValid")
    public JAXBElement<VehicleIsRouteValid> createVehicleIsRouteValid(VehicleIsRouteValid value) {
        return new JAXBElement<VehicleIsRouteValid>(_VehicleIsRouteValid_QNAME, VehicleIsRouteValid.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Start }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "start")
    public JAXBElement<Start> createStart(Start value) {
        return new JAXBElement<Start>(_Start_QNAME, Start.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetNOxEmissionResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getNOxEmissionResponse")
    public JAXBElement<LaneGetNOxEmissionResponse> createLaneGetNOxEmissionResponse(LaneGetNOxEmissionResponse value) {
        return new JAXBElement<LaneGetNOxEmissionResponse>(_LaneGetNOxEmissionResponse_QNAME, LaneGetNOxEmissionResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link GUIGetIDListResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "GUI_getIDListResponse")
    public JAXBElement<GUIGetIDListResponse> createGUIGetIDListResponse(GUIGetIDListResponse value) {
        return new JAXBElement<GUIGetIDListResponse>(_GUIGetIDListResponse_QNAME, GUIGetIDListResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link InductionloopGetIDCountResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Inductionloop_getIDCountResponse")
    public JAXBElement<InductionloopGetIDCountResponse> createInductionloopGetIDCountResponse(InductionloopGetIDCountResponse value) {
        return new JAXBElement<InductionloopGetIDCountResponse>(_InductionloopGetIDCountResponse_QNAME, InductionloopGetIDCountResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetNOxEmissionResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getNOxEmissionResponse")
    public JAXBElement<VehicleGetNOxEmissionResponse> createVehicleGetNOxEmissionResponse(VehicleGetNOxEmissionResponse value) {
        return new JAXBElement<VehicleGetNOxEmissionResponse>(_VehicleGetNOxEmissionResponse_QNAME, VehicleGetNOxEmissionResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationConvertRoadResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_convertRoadResponse")
    public JAXBElement<SimulationConvertRoadResponse> createSimulationConvertRoadResponse(SimulationConvertRoadResponse value) {
        return new JAXBElement<SimulationConvertRoadResponse>(_SimulationConvertRoadResponse_QNAME, SimulationConvertRoadResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetMinGapResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getMinGapResponse")
    public JAXBElement<VehicleGetMinGapResponse> createVehicleGetMinGapResponse(VehicleGetMinGapResponse value) {
        return new JAXBElement<VehicleGetMinGapResponse>(_VehicleGetMinGapResponse_QNAME, VehicleGetMinGapResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PolygonGetIDCountResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Polygon_getIDCountResponse")
    public JAXBElement<PolygonGetIDCountResponse> createPolygonGetIDCountResponse(PolygonGetIDCountResponse value) {
        return new JAXBElement<PolygonGetIDCountResponse>(_PolygonGetIDCountResponse_QNAME, PolygonGetIDCountResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleIsRouteValidResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_isRouteValidResponse")
    public JAXBElement<VehicleIsRouteValidResponse> createVehicleIsRouteValidResponse(VehicleIsRouteValidResponse value) {
        return new JAXBElement<VehicleIsRouteValidResponse>(_VehicleIsRouteValidResponse_QNAME, VehicleIsRouteValidResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeGetColor }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_getColor")
    public JAXBElement<VehicletypeGetColor> createVehicletypeGetColor(VehicletypeGetColor value) {
        return new JAXBElement<VehicletypeGetColor>(_VehicletypeGetColor_QNAME, VehicletypeGetColor.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetSpeedFactorResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setSpeedFactorResponse")
    public JAXBElement<VehicleSetSpeedFactorResponse> createVehicleSetSpeedFactorResponse(VehicleSetSpeedFactorResponse value) {
        return new JAXBElement<VehicleSetSpeedFactorResponse>(_VehicleSetSpeedFactorResponse_QNAME, VehicleSetSpeedFactorResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PoiGetIDCountResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Poi_getIDCountResponse")
    public JAXBElement<PoiGetIDCountResponse> createPoiGetIDCountResponse(PoiGetIDCountResponse value) {
        return new JAXBElement<PoiGetIDCountResponse>(_PoiGetIDCountResponse_QNAME, PoiGetIDCountResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetDistanceRoad }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getDistanceRoad")
    public JAXBElement<SimulationGetDistanceRoad> createSimulationGetDistanceRoad(SimulationGetDistanceRoad value) {
        return new JAXBElement<SimulationGetDistanceRoad>(_SimulationGetDistanceRoad_QNAME, SimulationGetDistanceRoad.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TrafficlightsSetCompleteRedYellowGreenDefinition }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Trafficlights_setCompleteRedYellowGreenDefinition")
    public JAXBElement<TrafficlightsSetCompleteRedYellowGreenDefinition> createTrafficlightsSetCompleteRedYellowGreenDefinition(TrafficlightsSetCompleteRedYellowGreenDefinition value) {
        return new JAXBElement<TrafficlightsSetCompleteRedYellowGreenDefinition>(_TrafficlightsSetCompleteRedYellowGreenDefinition_QNAME, TrafficlightsSetCompleteRedYellowGreenDefinition.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetWidthResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getWidthResponse")
    public JAXBElement<LaneGetWidthResponse> createLaneGetWidthResponse(LaneGetWidthResponse value) {
        return new JAXBElement<LaneGetWidthResponse>(_LaneGetWidthResponse_QNAME, LaneGetWidthResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link InductionloopGetLastStepOccupancyResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Inductionloop_getLastStepOccupancyResponse")
    public JAXBElement<InductionloopGetLastStepOccupancyResponse> createInductionloopGetLastStepOccupancyResponse(InductionloopGetLastStepOccupancyResponse value) {
        return new JAXBElement<InductionloopGetLastStepOccupancyResponse>(_InductionloopGetLastStepOccupancyResponse_QNAME, InductionloopGetLastStepOccupancyResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetColorResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getColorResponse")
    public JAXBElement<VehicleGetColorResponse> createVehicleGetColorResponse(VehicleGetColorResponse value) {
        return new JAXBElement<VehicleGetColorResponse>(_VehicleGetColorResponse_QNAME, VehicleGetColorResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeSetEmissionClassResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_setEmissionClassResponse")
    public JAXBElement<VehicletypeSetEmissionClassResponse> createVehicletypeSetEmissionClassResponse(VehicletypeSetEmissionClassResponse value) {
        return new JAXBElement<VehicletypeSetEmissionClassResponse>(_VehicletypeSetEmissionClassResponse_QNAME, VehicletypeSetEmissionClassResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetCOEmission }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getCOEmission")
    public JAXBElement<LaneGetCOEmission> createLaneGetCOEmission(LaneGetCOEmission value) {
        return new JAXBElement<LaneGetCOEmission>(_LaneGetCOEmission_QNAME, LaneGetCOEmission.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PoiGetColor }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Poi_getColor")
    public JAXBElement<PoiGetColor> createPoiGetColor(PoiGetColor value) {
        return new JAXBElement<PoiGetColor>(_PoiGetColor_QNAME, PoiGetColor.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link MultientryexitGetIDCountResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Multientryexit_getIDCountResponse")
    public JAXBElement<MultientryexitGetIDCountResponse> createMultientryexitGetIDCountResponse(MultientryexitGetIDCountResponse value) {
        return new JAXBElement<MultientryexitGetIDCountResponse>(_MultientryexitGetIDCountResponse_QNAME, MultientryexitGetIDCountResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EdgeGetHCEmissionResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Edge_getHCEmissionResponse")
    public JAXBElement<EdgeGetHCEmissionResponse> createEdgeGetHCEmissionResponse(EdgeGetHCEmissionResponse value) {
        return new JAXBElement<EdgeGetHCEmissionResponse>(_EdgeGetHCEmissionResponse_QNAME, EdgeGetHCEmissionResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeSetMinGap }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_setMinGap")
    public JAXBElement<VehicletypeSetMinGap> createVehicletypeSetMinGap(VehicletypeSetMinGap value) {
        return new JAXBElement<VehicletypeSetMinGap>(_VehicletypeSetMinGap_QNAME, VehicletypeSetMinGap.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetTypeResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setTypeResponse")
    public JAXBElement<VehicleSetTypeResponse> createVehicleSetTypeResponse(VehicleSetTypeResponse value) {
        return new JAXBElement<VehicleSetTypeResponse>(_VehicleSetTypeResponse_QNAME, VehicleSetTypeResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetParkingEndingVehiclesNumber }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getParkingEndingVehiclesNumber")
    public JAXBElement<SimulationGetParkingEndingVehiclesNumber> createSimulationGetParkingEndingVehiclesNumber(SimulationGetParkingEndingVehiclesNumber value) {
        return new JAXBElement<SimulationGetParkingEndingVehiclesNumber>(_SimulationGetParkingEndingVehiclesNumber_QNAME, SimulationGetParkingEndingVehiclesNumber.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PoiGetTypeResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Poi_getTypeResponse")
    public JAXBElement<PoiGetTypeResponse> createPoiGetTypeResponse(PoiGetTypeResponse value) {
        return new JAXBElement<PoiGetTypeResponse>(_PoiGetTypeResponse_QNAME, PoiGetTypeResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TrafficlightsGetProgramResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Trafficlights_getProgramResponse")
    public JAXBElement<TrafficlightsGetProgramResponse> createTrafficlightsGetProgramResponse(TrafficlightsGetProgramResponse value) {
        return new JAXBElement<TrafficlightsGetProgramResponse>(_TrafficlightsGetProgramResponse_QNAME, TrafficlightsGetProgramResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TrafficlightsGetControlledLanesResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Trafficlights_getControlledLanesResponse")
    public JAXBElement<TrafficlightsGetControlledLanesResponse> createTrafficlightsGetControlledLanesResponse(TrafficlightsGetControlledLanesResponse value) {
        return new JAXBElement<TrafficlightsGetControlledLanesResponse>(_TrafficlightsGetControlledLanesResponse_QNAME, TrafficlightsGetControlledLanesResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link InductionloopGetVehicleDataResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Inductionloop_getVehicleDataResponse")
    public JAXBElement<InductionloopGetVehicleDataResponse> createInductionloopGetVehicleDataResponse(InductionloopGetVehicleDataResponse value) {
        return new JAXBElement<InductionloopGetVehicleDataResponse>(_InductionloopGetVehicleDataResponse_QNAME, InductionloopGetVehicleDataResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PolygonGetShapeResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Polygon_getShapeResponse")
    public JAXBElement<PolygonGetShapeResponse> createPolygonGetShapeResponse(PolygonGetShapeResponse value) {
        return new JAXBElement<PolygonGetShapeResponse>(_PolygonGetShapeResponse_QNAME, PolygonGetShapeResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetAccel }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setAccel")
    public JAXBElement<VehicleSetAccel> createVehicleSetAccel(VehicleSetAccel value) {
        return new JAXBElement<VehicleSetAccel>(_VehicleSetAccel_QNAME, VehicleSetAccel.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetLanePosition }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getLanePosition")
    public JAXBElement<VehicleGetLanePosition> createVehicleGetLanePosition(VehicleGetLanePosition value) {
        return new JAXBElement<VehicleGetLanePosition>(_VehicleGetLanePosition_QNAME, VehicleGetLanePosition.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetVehicleClass }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setVehicleClass")
    public JAXBElement<VehicleSetVehicleClass> createVehicleSetVehicleClass(VehicleSetVehicleClass value) {
        return new JAXBElement<VehicleSetVehicleClass>(_VehicleSetVehicleClass_QNAME, VehicleSetVehicleClass.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetCOEmissionResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getCOEmissionResponse")
    public JAXBElement<VehicleGetCOEmissionResponse> createVehicleGetCOEmissionResponse(VehicleGetCOEmissionResponse value) {
        return new JAXBElement<VehicleGetCOEmissionResponse>(_VehicleGetCOEmissionResponse_QNAME, VehicleGetCOEmissionResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetEndingTeleportNumberResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getEndingTeleportNumberResponse")
    public JAXBElement<SimulationGetEndingTeleportNumberResponse> createSimulationGetEndingTeleportNumberResponse(SimulationGetEndingTeleportNumberResponse value) {
        return new JAXBElement<SimulationGetEndingTeleportNumberResponse>(_SimulationGetEndingTeleportNumberResponse_QNAME, SimulationGetEndingTeleportNumberResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EdgeGetLastStepVehicleNumberResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Edge_getLastStepVehicleNumberResponse")
    public JAXBElement<EdgeGetLastStepVehicleNumberResponse> createEdgeGetLastStepVehicleNumberResponse(EdgeGetLastStepVehicleNumberResponse value) {
        return new JAXBElement<EdgeGetLastStepVehicleNumberResponse>(_EdgeGetLastStepVehicleNumberResponse_QNAME, EdgeGetLastStepVehicleNumberResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetWidthResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setWidthResponse")
    public JAXBElement<VehicleSetWidthResponse> createVehicleSetWidthResponse(VehicleSetWidthResponse value) {
        return new JAXBElement<VehicleSetWidthResponse>(_VehicleSetWidthResponse_QNAME, VehicleSetWidthResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetRoute }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getRoute")
    public JAXBElement<VehicleGetRoute> createVehicleGetRoute(VehicleGetRoute value) {
        return new JAXBElement<VehicleGetRoute>(_VehicleGetRoute_QNAME, VehicleGetRoute.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetLastStepVehicleIDsResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getLastStepVehicleIDsResponse")
    public JAXBElement<LaneGetLastStepVehicleIDsResponse> createLaneGetLastStepVehicleIDsResponse(LaneGetLastStepVehicleIDsResponse value) {
        return new JAXBElement<LaneGetLastStepVehicleIDsResponse>(_LaneGetLastStepVehicleIDsResponse_QNAME, LaneGetLastStepVehicleIDsResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetTauResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getTauResponse")
    public JAXBElement<VehicleGetTauResponse> createVehicleGetTauResponse(VehicleGetTauResponse value) {
        return new JAXBElement<VehicleGetTauResponse>(_VehicleGetTauResponse_QNAME, VehicleGetTauResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TrafficlightsGetPhase }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Trafficlights_getPhase")
    public JAXBElement<TrafficlightsGetPhase> createTrafficlightsGetPhase(TrafficlightsGetPhase value) {
        return new JAXBElement<TrafficlightsGetPhase>(_TrafficlightsGetPhase_QNAME, TrafficlightsGetPhase.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetSignals }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setSignals")
    public JAXBElement<VehicleSetSignals> createVehicleSetSignals(VehicleSetSignals value) {
        return new JAXBElement<VehicleSetSignals>(_VehicleSetSignals_QNAME, VehicleSetSignals.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PolygonAdd }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Polygon_add")
    public JAXBElement<PolygonAdd> createPolygonAdd(PolygonAdd value) {
        return new JAXBElement<PolygonAdd>(_PolygonAdd_QNAME, PolygonAdd.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetDisallowedResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getDisallowedResponse")
    public JAXBElement<LaneGetDisallowedResponse> createLaneGetDisallowedResponse(LaneGetDisallowedResponse value) {
        return new JAXBElement<LaneGetDisallowedResponse>(_LaneGetDisallowedResponse_QNAME, LaneGetDisallowedResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetLoadedIDList }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getLoadedIDList")
    public JAXBElement<SimulationGetLoadedIDList> createSimulationGetLoadedIDList(SimulationGetLoadedIDList value) {
        return new JAXBElement<SimulationGetLoadedIDList>(_SimulationGetLoadedIDList_QNAME, SimulationGetLoadedIDList.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeSetMinGapResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_setMinGapResponse")
    public JAXBElement<VehicletypeSetMinGapResponse> createVehicletypeSetMinGapResponse(VehicletypeSetMinGapResponse value) {
        return new JAXBElement<VehicletypeSetMinGapResponse>(_VehicletypeSetMinGapResponse_QNAME, VehicletypeSetMinGapResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetDistance }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getDistance")
    public JAXBElement<VehicleGetDistance> createVehicleGetDistance(VehicleGetDistance value) {
        return new JAXBElement<VehicleGetDistance>(_VehicleGetDistance_QNAME, VehicleGetDistance.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link GUIGetSchema }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "GUI_getSchema")
    public JAXBElement<GUIGetSchema> createGUIGetSchema(GUIGetSchema value) {
        return new JAXBElement<GUIGetSchema>(_GUIGetSchema_QNAME, GUIGetSchema.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PolygonGetIDCount }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Polygon_getIDCount")
    public JAXBElement<PolygonGetIDCount> createPolygonGetIDCount(PolygonGetIDCount value) {
        return new JAXBElement<PolygonGetIDCount>(_PolygonGetIDCount_QNAME, PolygonGetIDCount.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TrafficlightsGetControlledLinks }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Trafficlights_getControlledLinks")
    public JAXBElement<TrafficlightsGetControlledLinks> createTrafficlightsGetControlledLinks(TrafficlightsGetControlledLinks value) {
        return new JAXBElement<TrafficlightsGetControlledLinks>(_TrafficlightsGetControlledLinks_QNAME, TrafficlightsGetControlledLinks.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link GUIGetBoundary }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "GUI_getBoundary")
    public JAXBElement<GUIGetBoundary> createGUIGetBoundary(GUIGetBoundary value) {
        return new JAXBElement<GUIGetBoundary>(_GUIGetBoundary_QNAME, GUIGetBoundary.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleRerouteTraveltime }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_rerouteTraveltime")
    public JAXBElement<VehicleRerouteTraveltime> createVehicleRerouteTraveltime(VehicleRerouteTraveltime value) {
        return new JAXBElement<VehicleRerouteTraveltime>(_VehicleRerouteTraveltime_QNAME, VehicleRerouteTraveltime.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Version }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "version")
    public JAXBElement<Version> createVersion(Version value) {
        return new JAXBElement<Version>(_Version_QNAME, Version.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LastActionTimeResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "LastActionTimeResponse")
    public JAXBElement<LastActionTimeResponse> createLastActionTimeResponse(LastActionTimeResponse value) {
        return new JAXBElement<LastActionTimeResponse>(_LastActionTimeResponse_QNAME, LastActionTimeResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetLinkNumberResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getLinkNumberResponse")
    public JAXBElement<LaneGetLinkNumberResponse> createLaneGetLinkNumberResponse(LaneGetLinkNumberResponse value) {
        return new JAXBElement<LaneGetLinkNumberResponse>(_LaneGetLinkNumberResponse_QNAME, LaneGetLinkNumberResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetLengthResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getLengthResponse")
    public JAXBElement<VehicleGetLengthResponse> createVehicleGetLengthResponse(VehicleGetLengthResponse value) {
        return new JAXBElement<VehicleGetLengthResponse>(_VehicleGetLengthResponse_QNAME, VehicleGetLengthResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeSetShapeClass }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_setShapeClass")
    public JAXBElement<VehicletypeSetShapeClass> createVehicletypeSetShapeClass(VehicletypeSetShapeClass value) {
        return new JAXBElement<VehicletypeSetShapeClass>(_VehicletypeSetShapeClass_QNAME, VehicletypeSetShapeClass.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetLastStepMeanSpeed }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getLastStepMeanSpeed")
    public JAXBElement<LaneGetLastStepMeanSpeed> createLaneGetLastStepMeanSpeed(LaneGetLastStepMeanSpeed value) {
        return new JAXBElement<LaneGetLastStepMeanSpeed>(_LaneGetLastStepMeanSpeed_QNAME, LaneGetLastStepMeanSpeed.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetLaneIndexResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getLaneIndexResponse")
    public JAXBElement<VehicleGetLaneIndexResponse> createVehicleGetLaneIndexResponse(VehicleGetLaneIndexResponse value) {
        return new JAXBElement<VehicleGetLaneIndexResponse>(_VehicleGetLaneIndexResponse_QNAME, VehicleGetLaneIndexResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EdgeGetLastStepOccupancyResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Edge_getLastStepOccupancyResponse")
    public JAXBElement<EdgeGetLastStepOccupancyResponse> createEdgeGetLastStepOccupancyResponse(EdgeGetLastStepOccupancyResponse value) {
        return new JAXBElement<EdgeGetLastStepOccupancyResponse>(_EdgeGetLastStepOccupancyResponse_QNAME, EdgeGetLastStepOccupancyResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetMinExpectedNumber }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getMinExpectedNumber")
    public JAXBElement<SimulationGetMinExpectedNumber> createSimulationGetMinExpectedNumber(SimulationGetMinExpectedNumber value) {
        return new JAXBElement<SimulationGetMinExpectedNumber>(_SimulationGetMinExpectedNumber_QNAME, SimulationGetMinExpectedNumber.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetEffort }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getEffort")
    public JAXBElement<VehicleGetEffort> createVehicleGetEffort(VehicleGetEffort value) {
        return new JAXBElement<VehicleGetEffort>(_VehicleGetEffort_QNAME, VehicleGetEffort.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link JunctionGetIDListResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Junction_getIDListResponse")
    public JAXBElement<JunctionGetIDListResponse> createJunctionGetIDListResponse(JunctionGetIDListResponse value) {
        return new JAXBElement<JunctionGetIDListResponse>(_JunctionGetIDListResponse_QNAME, JunctionGetIDListResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetSpeedFactor }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getSpeedFactor")
    public JAXBElement<VehicleGetSpeedFactor> createVehicleGetSpeedFactor(VehicleGetSpeedFactor value) {
        return new JAXBElement<VehicleGetSpeedFactor>(_VehicleGetSpeedFactor_QNAME, VehicleGetSpeedFactor.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetLoadedNumber }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getLoadedNumber")
    public JAXBElement<SimulationGetLoadedNumber> createSimulationGetLoadedNumber(SimulationGetLoadedNumber value) {
        return new JAXBElement<SimulationGetLoadedNumber>(_SimulationGetLoadedNumber_QNAME, SimulationGetLoadedNumber.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleAdd }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_add")
    public JAXBElement<VehicleAdd> createVehicleAdd(VehicleAdd value) {
        return new JAXBElement<VehicleAdd>(_VehicleAdd_QNAME, VehicleAdd.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetEndingTeleportIDList }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getEndingTeleportIDList")
    public JAXBElement<SimulationGetEndingTeleportIDList> createSimulationGetEndingTeleportIDList(SimulationGetEndingTeleportIDList value) {
        return new JAXBElement<SimulationGetEndingTeleportIDList>(_SimulationGetEndingTeleportIDList_QNAME, SimulationGetEndingTeleportIDList.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetAdaptedTraveltime }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getAdaptedTraveltime")
    public JAXBElement<VehicleGetAdaptedTraveltime> createVehicleGetAdaptedTraveltime(VehicleGetAdaptedTraveltime value) {
        return new JAXBElement<VehicleGetAdaptedTraveltime>(_VehicleGetAdaptedTraveltime_QNAME, VehicleGetAdaptedTraveltime.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EdgeGetAdaptedTraveltime }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Edge_getAdaptedTraveltime")
    public JAXBElement<EdgeGetAdaptedTraveltime> createEdgeGetAdaptedTraveltime(EdgeGetAdaptedTraveltime value) {
        return new JAXBElement<EdgeGetAdaptedTraveltime>(_EdgeGetAdaptedTraveltime_QNAME, EdgeGetAdaptedTraveltime.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleRemove }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_remove")
    public JAXBElement<VehicleRemove> createVehicleRemove(VehicleRemove value) {
        return new JAXBElement<VehicleRemove>(_VehicleRemove_QNAME, VehicleRemove.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetRouteIDResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setRouteIDResponse")
    public JAXBElement<VehicleSetRouteIDResponse> createVehicleSetRouteIDResponse(VehicleSetRouteIDResponse value) {
        return new JAXBElement<VehicleSetRouteIDResponse>(_VehicleSetRouteIDResponse_QNAME, VehicleSetRouteIDResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EdgeGetTraveltimeResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Edge_getTraveltimeResponse")
    public JAXBElement<EdgeGetTraveltimeResponse> createEdgeGetTraveltimeResponse(EdgeGetTraveltimeResponse value) {
        return new JAXBElement<EdgeGetTraveltimeResponse>(_EdgeGetTraveltimeResponse_QNAME, EdgeGetTraveltimeResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetLinkNumber }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getLinkNumber")
    public JAXBElement<LaneGetLinkNumber> createLaneGetLinkNumber(LaneGetLinkNumber value) {
        return new JAXBElement<LaneGetLinkNumber>(_LaneGetLinkNumber_QNAME, LaneGetLinkNumber.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetMaxSpeed }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getMaxSpeed")
    public JAXBElement<LaneGetMaxSpeed> createLaneGetMaxSpeed(LaneGetMaxSpeed value) {
        return new JAXBElement<LaneGetMaxSpeed>(_LaneGetMaxSpeed_QNAME, LaneGetMaxSpeed.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeSetLength }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_setLength")
    public JAXBElement<VehicletypeSetLength> createVehicletypeSetLength(VehicletypeSetLength value) {
        return new JAXBElement<VehicletypeSetLength>(_VehicletypeSetLength_QNAME, VehicletypeSetLength.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link RouteAdd }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Route_add")
    public JAXBElement<RouteAdd> createRouteAdd(RouteAdd value) {
        return new JAXBElement<RouteAdd>(_RouteAdd_QNAME, RouteAdd.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetColor }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setColor")
    public JAXBElement<VehicleSetColor> createVehicleSetColor(VehicleSetColor value) {
        return new JAXBElement<VehicleSetColor>(_VehicleSetColor_QNAME, VehicleSetColor.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetLaneChangeModeResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setLaneChangeModeResponse")
    public JAXBElement<VehicleSetLaneChangeModeResponse> createVehicleSetLaneChangeModeResponse(VehicleSetLaneChangeModeResponse value) {
        return new JAXBElement<VehicleSetLaneChangeModeResponse>(_VehicleSetLaneChangeModeResponse_QNAME, VehicleSetLaneChangeModeResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetNoiseEmission }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getNoiseEmission")
    public JAXBElement<VehicleGetNoiseEmission> createVehicleGetNoiseEmission(VehicleGetNoiseEmission value) {
        return new JAXBElement<VehicleGetNoiseEmission>(_VehicleGetNoiseEmission_QNAME, VehicleGetNoiseEmission.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetSignalsResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setSignalsResponse")
    public JAXBElement<VehicleSetSignalsResponse> createVehicleSetSignalsResponse(VehicleSetSignalsResponse value) {
        return new JAXBElement<VehicleSetSignalsResponse>(_VehicleSetSignalsResponse_QNAME, VehicleSetSignalsResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ArealDetectorGetJamLengthVehicle }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "ArealDetector_getJamLengthVehicle")
    public JAXBElement<ArealDetectorGetJamLengthVehicle> createArealDetectorGetJamLengthVehicle(ArealDetectorGetJamLengthVehicle value) {
        return new JAXBElement<ArealDetectorGetJamLengthVehicle>(_ArealDetectorGetJamLengthVehicle_QNAME, ArealDetectorGetJamLengthVehicle.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetMinGap }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setMinGap")
    public JAXBElement<VehicleSetMinGap> createVehicleSetMinGap(VehicleSetMinGap value) {
        return new JAXBElement<VehicleSetMinGap>(_VehicleSetMinGap_QNAME, VehicleSetMinGap.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetParkingEndingVehiclesNumberResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getParkingEndingVehiclesNumberResponse")
    public JAXBElement<SimulationGetParkingEndingVehiclesNumberResponse> createSimulationGetParkingEndingVehiclesNumberResponse(SimulationGetParkingEndingVehiclesNumberResponse value) {
        return new JAXBElement<SimulationGetParkingEndingVehiclesNumberResponse>(_SimulationGetParkingEndingVehiclesNumberResponse_QNAME, SimulationGetParkingEndingVehiclesNumberResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EdgeGetFuelConsumption }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Edge_getFuelConsumption")
    public JAXBElement<EdgeGetFuelConsumption> createEdgeGetFuelConsumption(EdgeGetFuelConsumption value) {
        return new JAXBElement<EdgeGetFuelConsumption>(_EdgeGetFuelConsumption_QNAME, EdgeGetFuelConsumption.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetNetBoundary }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getNetBoundary")
    public JAXBElement<SimulationGetNetBoundary> createSimulationGetNetBoundary(SimulationGetNetBoundary value) {
        return new JAXBElement<SimulationGetNetBoundary>(_SimulationGetNetBoundary_QNAME, SimulationGetNetBoundary.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetArrivedIDList }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getArrivedIDList")
    public JAXBElement<SimulationGetArrivedIDList> createSimulationGetArrivedIDList(SimulationGetArrivedIDList value) {
        return new JAXBElement<SimulationGetArrivedIDList>(_SimulationGetArrivedIDList_QNAME, SimulationGetArrivedIDList.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetSpeedFactorResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getSpeedFactorResponse")
    public JAXBElement<VehicleGetSpeedFactorResponse> createVehicleGetSpeedFactorResponse(VehicleGetSpeedFactorResponse value) {
        return new JAXBElement<VehicleGetSpeedFactorResponse>(_VehicleGetSpeedFactorResponse_QNAME, VehicleGetSpeedFactorResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetRoadIDResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getRoadIDResponse")
    public JAXBElement<VehicleGetRoadIDResponse> createVehicleGetRoadIDResponse(VehicleGetRoadIDResponse value) {
        return new JAXBElement<VehicleGetRoadIDResponse>(_VehicleGetRoadIDResponse_QNAME, VehicleGetRoadIDResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetDrivingDistance2D }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getDrivingDistance2D")
    public JAXBElement<VehicleGetDrivingDistance2D> createVehicleGetDrivingDistance2D(VehicleGetDrivingDistance2D value) {
        return new JAXBElement<VehicleGetDrivingDistance2D>(_VehicleGetDrivingDistance2D_QNAME, VehicleGetDrivingDistance2D.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SetConfig }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "setConfig")
    public JAXBElement<SetConfig> createSetConfig(SetConfig value) {
        return new JAXBElement<SetConfig>(_SetConfig_QNAME, SetConfig.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationConvertRoad }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_convertRoad")
    public JAXBElement<SimulationConvertRoad> createSimulationConvertRoad(SimulationConvertRoad value) {
        return new JAXBElement<SimulationConvertRoad>(_SimulationConvertRoad_QNAME, SimulationConvertRoad.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetImperfectionResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getImperfectionResponse")
    public JAXBElement<VehicleGetImperfectionResponse> createVehicleGetImperfectionResponse(VehicleGetImperfectionResponse value) {
        return new JAXBElement<VehicleGetImperfectionResponse>(_VehicleGetImperfectionResponse_QNAME, VehicleGetImperfectionResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link DoTimestepResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "doTimestepResponse")
    public JAXBElement<DoTimestepResponse> createDoTimestepResponse(DoTimestepResponse value) {
        return new JAXBElement<DoTimestepResponse>(_DoTimestepResponse_QNAME, DoTimestepResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetRoute }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setRoute")
    public JAXBElement<VehicleSetRoute> createVehicleSetRoute(VehicleSetRoute value) {
        return new JAXBElement<VehicleSetRoute>(_VehicleSetRoute_QNAME, VehicleSetRoute.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EdgeGetLastStepLength }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Edge_getLastStepLength")
    public JAXBElement<EdgeGetLastStepLength> createEdgeGetLastStepLength(EdgeGetLastStepLength value) {
        return new JAXBElement<EdgeGetLastStepLength>(_EdgeGetLastStepLength_QNAME, EdgeGetLastStepLength.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PoiGetIDListResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Poi_getIDListResponse")
    public JAXBElement<PoiGetIDListResponse> createPoiGetIDListResponse(PoiGetIDListResponse value) {
        return new JAXBElement<PoiGetIDListResponse>(_PoiGetIDListResponse_QNAME, PoiGetIDListResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PoiRemoveResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Poi_removeResponse")
    public JAXBElement<PoiRemoveResponse> createPoiRemoveResponse(PoiRemoveResponse value) {
        return new JAXBElement<PoiRemoveResponse>(_PoiRemoveResponse_QNAME, PoiRemoveResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetIDCount }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getIDCount")
    public JAXBElement<LaneGetIDCount> createLaneGetIDCount(LaneGetIDCount value) {
        return new JAXBElement<LaneGetIDCount>(_LaneGetIDCount_QNAME, LaneGetIDCount.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetIDList }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getIDList")
    public JAXBElement<VehicleGetIDList> createVehicleGetIDList(VehicleGetIDList value) {
        return new JAXBElement<VehicleGetIDList>(_VehicleGetIDList_QNAME, VehicleGetIDList.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetDepartedNumberResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getDepartedNumberResponse")
    public JAXBElement<SimulationGetDepartedNumberResponse> createSimulationGetDepartedNumberResponse(SimulationGetDepartedNumberResponse value) {
        return new JAXBElement<SimulationGetDepartedNumberResponse>(_SimulationGetDepartedNumberResponse_QNAME, SimulationGetDepartedNumberResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetSpeedDeviation }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setSpeedDeviation")
    public JAXBElement<VehicleSetSpeedDeviation> createVehicleSetSpeedDeviation(VehicleSetSpeedDeviation value) {
        return new JAXBElement<VehicleSetSpeedDeviation>(_VehicleSetSpeedDeviation_QNAME, VehicleSetSpeedDeviation.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetEmissionClassResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setEmissionClassResponse")
    public JAXBElement<VehicleSetEmissionClassResponse> createVehicleSetEmissionClassResponse(VehicleSetEmissionClassResponse value) {
        return new JAXBElement<VehicleSetEmissionClassResponse>(_VehicleSetEmissionClassResponse_QNAME, VehicleSetEmissionClassResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EdgeGetEffort }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Edge_getEffort")
    public JAXBElement<EdgeGetEffort> createEdgeGetEffort(EdgeGetEffort value) {
        return new JAXBElement<EdgeGetEffort>(_EdgeGetEffort_QNAME, EdgeGetEffort.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetSpeedDeviationResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getSpeedDeviationResponse")
    public JAXBElement<VehicleGetSpeedDeviationResponse> createVehicleGetSpeedDeviationResponse(VehicleGetSpeedDeviationResponse value) {
        return new JAXBElement<VehicleGetSpeedDeviationResponse>(_VehicleGetSpeedDeviationResponse_QNAME, VehicleGetSpeedDeviationResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeSetImperfection }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_setImperfection")
    public JAXBElement<VehicletypeSetImperfection> createVehicletypeSetImperfection(VehicletypeSetImperfection value) {
        return new JAXBElement<VehicletypeSetImperfection>(_VehicletypeSetImperfection_QNAME, VehicletypeSetImperfection.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneSetMaxSpeedResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_setMaxSpeedResponse")
    public JAXBElement<LaneSetMaxSpeedResponse> createLaneSetMaxSpeedResponse(LaneSetMaxSpeedResponse value) {
        return new JAXBElement<LaneSetMaxSpeedResponse>(_LaneSetMaxSpeedResponse_QNAME, LaneSetMaxSpeedResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Stop }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "stop")
    public JAXBElement<Stop> createStop(Stop value) {
        return new JAXBElement<Stop>(_Stop_QNAME, Stop.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TrafficlightsGetIDListResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Trafficlights_getIDListResponse")
    public JAXBElement<TrafficlightsGetIDListResponse> createTrafficlightsGetIDListResponse(TrafficlightsGetIDListResponse value) {
        return new JAXBElement<TrafficlightsGetIDListResponse>(_TrafficlightsGetIDListResponse_QNAME, TrafficlightsGetIDListResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link GUIGetOffsetResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "GUI_getOffsetResponse")
    public JAXBElement<GUIGetOffsetResponse> createGUIGetOffsetResponse(GUIGetOffsetResponse value) {
        return new JAXBElement<GUIGetOffsetResponse>(_GUIGetOffsetResponse_QNAME, GUIGetOffsetResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link AddOptionResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "addOptionResponse")
    public JAXBElement<AddOptionResponse> createAddOptionResponse(AddOptionResponse value) {
        return new JAXBElement<AddOptionResponse>(_AddOptionResponse_QNAME, AddOptionResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TXTOutput }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "TXT_output")
    public JAXBElement<TXTOutput> createTXTOutput(TXTOutput value) {
        return new JAXBElement<TXTOutput>(_TXTOutput_QNAME, TXTOutput.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetStartingTeleportNumberResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getStartingTeleportNumberResponse")
    public JAXBElement<SimulationGetStartingTeleportNumberResponse> createSimulationGetStartingTeleportNumberResponse(SimulationGetStartingTeleportNumberResponse value) {
        return new JAXBElement<SimulationGetStartingTeleportNumberResponse>(_SimulationGetStartingTeleportNumberResponse_QNAME, SimulationGetStartingTeleportNumberResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link GUIGetIDList }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "GUI_getIDList")
    public JAXBElement<GUIGetIDList> createGUIGetIDList(GUIGetIDList value) {
        return new JAXBElement<GUIGetIDList>(_GUIGetIDList_QNAME, GUIGetIDList.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetRouteResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getRouteResponse")
    public JAXBElement<VehicleGetRouteResponse> createVehicleGetRouteResponse(VehicleGetRouteResponse value) {
        return new JAXBElement<VehicleGetRouteResponse>(_VehicleGetRouteResponse_QNAME, VehicleGetRouteResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationConvertGeo }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_convertGeo")
    public JAXBElement<SimulationConvertGeo> createSimulationConvertGeo(SimulationConvertGeo value) {
        return new JAXBElement<SimulationConvertGeo>(_SimulationConvertGeo_QNAME, SimulationConvertGeo.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PolygonSetShape }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Polygon_setShape")
    public JAXBElement<PolygonSetShape> createPolygonSetShape(PolygonSetShape value) {
        return new JAXBElement<PolygonSetShape>(_PolygonSetShape_QNAME, PolygonSetShape.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetEndingTeleportNumber }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getEndingTeleportNumber")
    public JAXBElement<SimulationGetEndingTeleportNumber> createSimulationGetEndingTeleportNumber(SimulationGetEndingTeleportNumber value) {
        return new JAXBElement<SimulationGetEndingTeleportNumber>(_SimulationGetEndingTeleportNumber_QNAME, SimulationGetEndingTeleportNumber.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetAllowedSpeed }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getAllowedSpeed")
    public JAXBElement<VehicleGetAllowedSpeed> createVehicleGetAllowedSpeed(VehicleGetAllowedSpeed value) {
        return new JAXBElement<VehicleGetAllowedSpeed>(_VehicleGetAllowedSpeed_QNAME, VehicleGetAllowedSpeed.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleMoveToVTDResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_moveToVTDResponse")
    public JAXBElement<VehicleMoveToVTDResponse> createVehicleMoveToVTDResponse(VehicleMoveToVTDResponse value) {
        return new JAXBElement<VehicleMoveToVTDResponse>(_VehicleMoveToVTDResponse_QNAME, VehicleMoveToVTDResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetEdgeID }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getEdgeID")
    public JAXBElement<LaneGetEdgeID> createLaneGetEdgeID(LaneGetEdgeID value) {
        return new JAXBElement<LaneGetEdgeID>(_LaneGetEdgeID_QNAME, LaneGetEdgeID.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetPMxEmission }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getPMxEmission")
    public JAXBElement<LaneGetPMxEmission> createLaneGetPMxEmission(LaneGetPMxEmission value) {
        return new JAXBElement<LaneGetPMxEmission>(_LaneGetPMxEmission_QNAME, LaneGetPMxEmission.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetEdgeIDResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getEdgeIDResponse")
    public JAXBElement<LaneGetEdgeIDResponse> createLaneGetEdgeIDResponse(LaneGetEdgeIDResponse value) {
        return new JAXBElement<LaneGetEdgeIDResponse>(_LaneGetEdgeIDResponse_QNAME, LaneGetEdgeIDResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneSetDisallowed }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_setDisallowed")
    public JAXBElement<LaneSetDisallowed> createLaneSetDisallowed(LaneSetDisallowed value) {
        return new JAXBElement<LaneSetDisallowed>(_LaneSetDisallowed_QNAME, LaneSetDisallowed.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link RouteGetIDCountResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Route_getIDCountResponse")
    public JAXBElement<RouteGetIDCountResponse> createRouteGetIDCountResponse(RouteGetIDCountResponse value) {
        return new JAXBElement<RouteGetIDCountResponse>(_RouteGetIDCountResponse_QNAME, RouteGetIDCountResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EdgeGetCOEmissionResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Edge_getCOEmissionResponse")
    public JAXBElement<EdgeGetCOEmissionResponse> createEdgeGetCOEmissionResponse(EdgeGetCOEmissionResponse value) {
        return new JAXBElement<EdgeGetCOEmissionResponse>(_EdgeGetCOEmissionResponse_QNAME, EdgeGetCOEmissionResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetWidth }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getWidth")
    public JAXBElement<LaneGetWidth> createLaneGetWidth(LaneGetWidth value) {
        return new JAXBElement<LaneGetWidth>(_LaneGetWidth_QNAME, LaneGetWidth.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link GetStatus }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "get_Status")
    public JAXBElement<GetStatus> createGetStatus(GetStatus value) {
        return new JAXBElement<GetStatus>(_GetStatus_QNAME, GetStatus.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationConvertGeoResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_convertGeoResponse")
    public JAXBElement<SimulationConvertGeoResponse> createSimulationConvertGeoResponse(SimulationConvertGeoResponse value) {
        return new JAXBElement<SimulationConvertGeoResponse>(_SimulationConvertGeoResponse_QNAME, SimulationConvertGeoResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetIDCount }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getIDCount")
    public JAXBElement<VehicleGetIDCount> createVehicleGetIDCount(VehicleGetIDCount value) {
        return new JAXBElement<VehicleGetIDCount>(_VehicleGetIDCount_QNAME, VehicleGetIDCount.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EdgeAdaptTraveltime }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Edge_adaptTraveltime")
    public JAXBElement<EdgeAdaptTraveltime> createEdgeAdaptTraveltime(EdgeAdaptTraveltime value) {
        return new JAXBElement<EdgeAdaptTraveltime>(_EdgeAdaptTraveltime_QNAME, EdgeAdaptTraveltime.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeSetLengthResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_setLengthResponse")
    public JAXBElement<VehicletypeSetLengthResponse> createVehicletypeSetLengthResponse(VehicletypeSetLengthResponse value) {
        return new JAXBElement<VehicletypeSetLengthResponse>(_VehicletypeSetLengthResponse_QNAME, VehicletypeSetLengthResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetCOEmissionResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getCOEmissionResponse")
    public JAXBElement<LaneGetCOEmissionResponse> createLaneGetCOEmissionResponse(LaneGetCOEmissionResponse value) {
        return new JAXBElement<LaneGetCOEmissionResponse>(_LaneGetCOEmissionResponse_QNAME, LaneGetCOEmissionResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeSetShapeClassResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_setShapeClassResponse")
    public JAXBElement<VehicletypeSetShapeClassResponse> createVehicletypeSetShapeClassResponse(VehicletypeSetShapeClassResponse value) {
        return new JAXBElement<VehicletypeSetShapeClassResponse>(_VehicletypeSetShapeClassResponse_QNAME, VehicletypeSetShapeClassResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EdgeGetNOxEmissionResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Edge_getNOxEmissionResponse")
    public JAXBElement<EdgeGetNOxEmissionResponse> createEdgeGetNOxEmissionResponse(EdgeGetNOxEmissionResponse value) {
        return new JAXBElement<EdgeGetNOxEmissionResponse>(_EdgeGetNOxEmissionResponse_QNAME, EdgeGetNOxEmissionResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetNoiseEmission }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getNoiseEmission")
    public JAXBElement<LaneGetNoiseEmission> createLaneGetNoiseEmission(LaneGetNoiseEmission value) {
        return new JAXBElement<LaneGetNoiseEmission>(_LaneGetNoiseEmission_QNAME, LaneGetNoiseEmission.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeGetIDList }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_getIDList")
    public JAXBElement<VehicletypeGetIDList> createVehicletypeGetIDList(VehicletypeGetIDList value) {
        return new JAXBElement<VehicletypeGetIDList>(_VehicletypeGetIDList_QNAME, VehicletypeGetIDList.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetIDListResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getIDListResponse")
    public JAXBElement<LaneGetIDListResponse> createLaneGetIDListResponse(LaneGetIDListResponse value) {
        return new JAXBElement<LaneGetIDListResponse>(_LaneGetIDListResponse_QNAME, LaneGetIDListResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeGetIDListResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_getIDListResponse")
    public JAXBElement<VehicletypeGetIDListResponse> createVehicletypeGetIDListResponse(VehicletypeGetIDListResponse value) {
        return new JAXBElement<VehicletypeGetIDListResponse>(_VehicletypeGetIDListResponse_QNAME, VehicletypeGetIDListResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeGetSpeedFactorResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_getSpeedFactorResponse")
    public JAXBElement<VehicletypeGetSpeedFactorResponse> createVehicletypeGetSpeedFactorResponse(VehicletypeGetSpeedFactorResponse value) {
        return new JAXBElement<VehicletypeGetSpeedFactorResponse>(_VehicletypeGetSpeedFactorResponse_QNAME, VehicletypeGetSpeedFactorResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetParkingEndingVehiclesIDListResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getParkingEndingVehiclesIDListResponse")
    public JAXBElement<SimulationGetParkingEndingVehiclesIDListResponse> createSimulationGetParkingEndingVehiclesIDListResponse(SimulationGetParkingEndingVehiclesIDListResponse value) {
        return new JAXBElement<SimulationGetParkingEndingVehiclesIDListResponse>(_SimulationGetParkingEndingVehiclesIDListResponse_QNAME, SimulationGetParkingEndingVehiclesIDListResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetPosition }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getPosition")
    public JAXBElement<VehicleGetPosition> createVehicleGetPosition(VehicleGetPosition value) {
        return new JAXBElement<VehicleGetPosition>(_VehicleGetPosition_QNAME, VehicleGetPosition.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PolygonGetIDListResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Polygon_getIDListResponse")
    public JAXBElement<PolygonGetIDListResponse> createPolygonGetIDListResponse(PolygonGetIDListResponse value) {
        return new JAXBElement<PolygonGetIDListResponse>(_PolygonGetIDListResponse_QNAME, PolygonGetIDListResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetIDListResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getIDListResponse")
    public JAXBElement<VehicleGetIDListResponse> createVehicleGetIDListResponse(VehicleGetIDListResponse value) {
        return new JAXBElement<VehicleGetIDListResponse>(_VehicleGetIDListResponse_QNAME, VehicleGetIDListResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetLastStepHaltingNumber }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getLastStepHaltingNumber")
    public JAXBElement<LaneGetLastStepHaltingNumber> createLaneGetLastStepHaltingNumber(LaneGetLastStepHaltingNumber value) {
        return new JAXBElement<LaneGetLastStepHaltingNumber>(_LaneGetLastStepHaltingNumber_QNAME, LaneGetLastStepHaltingNumber.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetLengthResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setLengthResponse")
    public JAXBElement<VehicleSetLengthResponse> createVehicleSetLengthResponse(VehicleSetLengthResponse value) {
        return new JAXBElement<VehicleSetLengthResponse>(_VehicleSetLengthResponse_QNAME, VehicleSetLengthResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetLastStepVehicleNumber }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getLastStepVehicleNumber")
    public JAXBElement<LaneGetLastStepVehicleNumber> createLaneGetLastStepVehicleNumber(LaneGetLastStepVehicleNumber value) {
        return new JAXBElement<LaneGetLastStepVehicleNumber>(_LaneGetLastStepVehicleNumber_QNAME, LaneGetLastStepVehicleNumber.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetRoadID }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getRoadID")
    public JAXBElement<VehicleGetRoadID> createVehicleGetRoadID(VehicleGetRoadID value) {
        return new JAXBElement<VehicleGetRoadID>(_VehicleGetRoadID_QNAME, VehicleGetRoadID.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetAllowed }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getAllowed")
    public JAXBElement<LaneGetAllowed> createLaneGetAllowed(LaneGetAllowed value) {
        return new JAXBElement<LaneGetAllowed>(_LaneGetAllowed_QNAME, LaneGetAllowed.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EdgeGetTraveltime }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Edge_getTraveltime")
    public JAXBElement<EdgeGetTraveltime> createEdgeGetTraveltime(EdgeGetTraveltime value) {
        return new JAXBElement<EdgeGetTraveltime>(_EdgeGetTraveltime_QNAME, EdgeGetTraveltime.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetShapeClassResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setShapeClassResponse")
    public JAXBElement<VehicleSetShapeClassResponse> createVehicleSetShapeClassResponse(VehicleSetShapeClassResponse value) {
        return new JAXBElement<VehicleSetShapeClassResponse>(_VehicleSetShapeClassResponse_QNAME, VehicleSetShapeClassResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeSetWidthResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_setWidthResponse")
    public JAXBElement<VehicletypeSetWidthResponse> createVehicletypeSetWidthResponse(VehicletypeSetWidthResponse value) {
        return new JAXBElement<VehicletypeSetWidthResponse>(_VehicletypeSetWidthResponse_QNAME, VehicletypeSetWidthResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link GUISetSchemaResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "GUI_setSchemaResponse")
    public JAXBElement<GUISetSchemaResponse> createGUISetSchemaResponse(GUISetSchemaResponse value) {
        return new JAXBElement<GUISetSchemaResponse>(_GUISetSchemaResponse_QNAME, GUISetSchemaResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeSetSpeedDeviationResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_setSpeedDeviationResponse")
    public JAXBElement<VehicletypeSetSpeedDeviationResponse> createVehicletypeSetSpeedDeviationResponse(VehicletypeSetSpeedDeviationResponse value) {
        return new JAXBElement<VehicletypeSetSpeedDeviationResponse>(_VehicletypeSetSpeedDeviationResponse_QNAME, VehicletypeSetSpeedDeviationResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetAdaptedTraveltime }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setAdaptedTraveltime")
    public JAXBElement<VehicleSetAdaptedTraveltime> createVehicleSetAdaptedTraveltime(VehicleSetAdaptedTraveltime value) {
        return new JAXBElement<VehicleSetAdaptedTraveltime>(_VehicleSetAdaptedTraveltime_QNAME, VehicleSetAdaptedTraveltime.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetLastStepHaltingNumberResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getLastStepHaltingNumberResponse")
    public JAXBElement<LaneGetLastStepHaltingNumberResponse> createLaneGetLastStepHaltingNumberResponse(LaneGetLastStepHaltingNumberResponse value) {
        return new JAXBElement<LaneGetLastStepHaltingNumberResponse>(_LaneGetLastStepHaltingNumberResponse_QNAME, LaneGetLastStepHaltingNumberResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetFuelConsumption }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getFuelConsumption")
    public JAXBElement<LaneGetFuelConsumption> createLaneGetFuelConsumption(LaneGetFuelConsumption value) {
        return new JAXBElement<LaneGetFuelConsumption>(_LaneGetFuelConsumption_QNAME, LaneGetFuelConsumption.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationConvert2D }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_convert2D")
    public JAXBElement<SimulationConvert2D> createSimulationConvert2D(SimulationConvert2D value) {
        return new JAXBElement<SimulationConvert2D>(_SimulationConvert2D_QNAME, SimulationConvert2D.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetDistance2D }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getDistance2D")
    public JAXBElement<SimulationGetDistance2D> createSimulationGetDistance2D(SimulationGetDistance2D value) {
        return new JAXBElement<SimulationGetDistance2D>(_SimulationGetDistance2D_QNAME, SimulationGetDistance2D.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetVehicleClass }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getVehicleClass")
    public JAXBElement<VehicleGetVehicleClass> createVehicleGetVehicleClass(VehicleGetVehicleClass value) {
        return new JAXBElement<VehicleGetVehicleClass>(_VehicleGetVehicleClass_QNAME, VehicleGetVehicleClass.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetDistanceRoadResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getDistanceRoadResponse")
    public JAXBElement<SimulationGetDistanceRoadResponse> createSimulationGetDistanceRoadResponse(SimulationGetDistanceRoadResponse value) {
        return new JAXBElement<SimulationGetDistanceRoadResponse>(_SimulationGetDistanceRoadResponse_QNAME, SimulationGetDistanceRoadResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link InductionloopGetLastStepMeanSpeed }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Inductionloop_getLastStepMeanSpeed")
    public JAXBElement<InductionloopGetLastStepMeanSpeed> createInductionloopGetLastStepMeanSpeed(InductionloopGetLastStepMeanSpeed value) {
        return new JAXBElement<InductionloopGetLastStepMeanSpeed>(_InductionloopGetLastStepMeanSpeed_QNAME, InductionloopGetLastStepMeanSpeed.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeGetImperfectionResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_getImperfectionResponse")
    public JAXBElement<VehicletypeGetImperfectionResponse> createVehicletypeGetImperfectionResponse(VehicletypeGetImperfectionResponse value) {
        return new JAXBElement<VehicletypeGetImperfectionResponse>(_VehicletypeGetImperfectionResponse_QNAME, VehicletypeGetImperfectionResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link InductionloopGetLastStepMeanLength }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Inductionloop_getLastStepMeanLength")
    public JAXBElement<InductionloopGetLastStepMeanLength> createInductionloopGetLastStepMeanLength(InductionloopGetLastStepMeanLength value) {
        return new JAXBElement<InductionloopGetLastStepMeanLength>(_InductionloopGetLastStepMeanLength_QNAME, InductionloopGetLastStepMeanLength.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PoiSetPositionResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Poi_setPositionResponse")
    public JAXBElement<PoiSetPositionResponse> createPoiSetPositionResponse(PoiSetPositionResponse value) {
        return new JAXBElement<PoiSetPositionResponse>(_PoiSetPositionResponse_QNAME, PoiSetPositionResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetLinksResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getLinksResponse")
    public JAXBElement<LaneGetLinksResponse> createLaneGetLinksResponse(LaneGetLinksResponse value) {
        return new JAXBElement<LaneGetLinksResponse>(_LaneGetLinksResponse_QNAME, LaneGetLinksResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PolygonAddResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Polygon_addResponse")
    public JAXBElement<PolygonAddResponse> createPolygonAddResponse(PolygonAddResponse value) {
        return new JAXBElement<PolygonAddResponse>(_PolygonAddResponse_QNAME, PolygonAddResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeSetSpeedDeviation }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_setSpeedDeviation")
    public JAXBElement<VehicletypeSetSpeedDeviation> createVehicletypeSetSpeedDeviation(VehicletypeSetSpeedDeviation value) {
        return new JAXBElement<VehicletypeSetSpeedDeviation>(_VehicletypeSetSpeedDeviation_QNAME, VehicletypeSetSpeedDeviation.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link AddOption }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "addOption")
    public JAXBElement<AddOption> createAddOption(AddOption value) {
        return new JAXBElement<AddOption>(_AddOption_QNAME, AddOption.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeGetTau }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_getTau")
    public JAXBElement<VehicletypeGetTau> createVehicletypeGetTau(VehicletypeGetTau value) {
        return new JAXBElement<VehicletypeGetTau>(_VehicletypeGetTau_QNAME, VehicletypeGetTau.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetMaxSpeedResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getMaxSpeedResponse")
    public JAXBElement<VehicleGetMaxSpeedResponse> createVehicleGetMaxSpeedResponse(VehicleGetMaxSpeedResponse value) {
        return new JAXBElement<VehicleGetMaxSpeedResponse>(_VehicleGetMaxSpeedResponse_QNAME, VehicleGetMaxSpeedResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeGetMinGapResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_getMinGapResponse")
    public JAXBElement<VehicletypeGetMinGapResponse> createVehicletypeGetMinGapResponse(VehicletypeGetMinGapResponse value) {
        return new JAXBElement<VehicletypeGetMinGapResponse>(_VehicletypeGetMinGapResponse_QNAME, VehicletypeGetMinGapResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PolygonGetColorResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Polygon_getColorResponse")
    public JAXBElement<PolygonGetColorResponse> createPolygonGetColorResponse(PolygonGetColorResponse value) {
        return new JAXBElement<PolygonGetColorResponse>(_PolygonGetColorResponse_QNAME, PolygonGetColorResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeGetShapeClassResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_getShapeClassResponse")
    public JAXBElement<VehicletypeGetShapeClassResponse> createVehicletypeGetShapeClassResponse(VehicletypeGetShapeClassResponse value) {
        return new JAXBElement<VehicletypeGetShapeClassResponse>(_VehicletypeGetShapeClassResponse_QNAME, VehicletypeGetShapeClassResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetType }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setType")
    public JAXBElement<VehicleSetType> createVehicleSetType(VehicleSetType value) {
        return new JAXBElement<VehicleSetType>(_VehicleSetType_QNAME, VehicleSetType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link GetStatusResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "get_StatusResponse")
    public JAXBElement<GetStatusResponse> createGetStatusResponse(GetStatusResponse value) {
        return new JAXBElement<GetStatusResponse>(_GetStatusResponse_QNAME, GetStatusResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetNOxEmission }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getNOxEmission")
    public JAXBElement<VehicleGetNOxEmission> createVehicleGetNOxEmission(VehicleGetNOxEmission value) {
        return new JAXBElement<VehicleGetNOxEmission>(_VehicleGetNOxEmission_QNAME, VehicleGetNOxEmission.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetTraveltime }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getTraveltime")
    public JAXBElement<LaneGetTraveltime> createLaneGetTraveltime(LaneGetTraveltime value) {
        return new JAXBElement<LaneGetTraveltime>(_LaneGetTraveltime_QNAME, LaneGetTraveltime.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EdgeGetLastStepVehicleIDs }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Edge_getLastStepVehicleIDs")
    public JAXBElement<EdgeGetLastStepVehicleIDs> createEdgeGetLastStepVehicleIDs(EdgeGetLastStepVehicleIDs value) {
        return new JAXBElement<EdgeGetLastStepVehicleIDs>(_EdgeGetLastStepVehicleIDs_QNAME, EdgeGetLastStepVehicleIDs.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PolygonSetColorResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Polygon_setColorResponse")
    public JAXBElement<PolygonSetColorResponse> createPolygonSetColorResponse(PolygonSetColorResponse value) {
        return new JAXBElement<PolygonSetColorResponse>(_PolygonSetColorResponse_QNAME, PolygonSetColorResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link DoTimestep }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "doTimestep")
    public JAXBElement<DoTimestep> createDoTimestep(DoTimestep value) {
        return new JAXBElement<DoTimestep>(_DoTimestep_QNAME, DoTimestep.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetIDList }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getIDList")
    public JAXBElement<LaneGetIDList> createLaneGetIDList(LaneGetIDList value) {
        return new JAXBElement<LaneGetIDList>(_LaneGetIDList_QNAME, LaneGetIDList.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link InductionloopGetLastStepVehicleNumberResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Inductionloop_getLastStepVehicleNumberResponse")
    public JAXBElement<InductionloopGetLastStepVehicleNumberResponse> createInductionloopGetLastStepVehicleNumberResponse(InductionloopGetLastStepVehicleNumberResponse value) {
        return new JAXBElement<InductionloopGetLastStepVehicleNumberResponse>(_InductionloopGetLastStepVehicleNumberResponse_QNAME, InductionloopGetLastStepVehicleNumberResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TrafficlightsGetRedYellowGreenState }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Trafficlights_getRedYellowGreenState")
    public JAXBElement<TrafficlightsGetRedYellowGreenState> createTrafficlightsGetRedYellowGreenState(TrafficlightsGetRedYellowGreenState value) {
        return new JAXBElement<TrafficlightsGetRedYellowGreenState>(_TrafficlightsGetRedYellowGreenState_QNAME, TrafficlightsGetRedYellowGreenState.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetAngle }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getAngle")
    public JAXBElement<VehicleGetAngle> createVehicleGetAngle(VehicleGetAngle value) {
        return new JAXBElement<VehicleGetAngle>(_VehicleGetAngle_QNAME, VehicleGetAngle.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PolygonSetType }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Polygon_setType")
    public JAXBElement<PolygonSetType> createPolygonSetType(PolygonSetType value) {
        return new JAXBElement<PolygonSetType>(_PolygonSetType_QNAME, PolygonSetType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetBusStopWaitingResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getBusStopWaitingResponse")
    public JAXBElement<SimulationGetBusStopWaitingResponse> createSimulationGetBusStopWaitingResponse(SimulationGetBusStopWaitingResponse value) {
        return new JAXBElement<SimulationGetBusStopWaitingResponse>(_SimulationGetBusStopWaitingResponse_QNAME, SimulationGetBusStopWaitingResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetPositionResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getPositionResponse")
    public JAXBElement<VehicleGetPositionResponse> createVehicleGetPositionResponse(VehicleGetPositionResponse value) {
        return new JAXBElement<VehicleGetPositionResponse>(_VehicleGetPositionResponse_QNAME, VehicleGetPositionResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetLoadedNumberResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getLoadedNumberResponse")
    public JAXBElement<SimulationGetLoadedNumberResponse> createSimulationGetLoadedNumberResponse(SimulationGetLoadedNumberResponse value) {
        return new JAXBElement<SimulationGetLoadedNumberResponse>(_SimulationGetLoadedNumberResponse_QNAME, SimulationGetLoadedNumberResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetHCEmissionResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getHCEmissionResponse")
    public JAXBElement<VehicleGetHCEmissionResponse> createVehicleGetHCEmissionResponse(VehicleGetHCEmissionResponse value) {
        return new JAXBElement<VehicleGetHCEmissionResponse>(_VehicleGetHCEmissionResponse_QNAME, VehicleGetHCEmissionResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EdgeGetWaitingTimeResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Edge_getWaitingTimeResponse")
    public JAXBElement<EdgeGetWaitingTimeResponse> createEdgeGetWaitingTimeResponse(EdgeGetWaitingTimeResponse value) {
        return new JAXBElement<EdgeGetWaitingTimeResponse>(_EdgeGetWaitingTimeResponse_QNAME, EdgeGetWaitingTimeResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VersionResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "versionResponse")
    public JAXBElement<VersionResponse> createVersionResponse(VersionResponse value) {
        return new JAXBElement<VersionResponse>(_VersionResponse_QNAME, VersionResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetCO2Emission }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getCO2Emission")
    public JAXBElement<LaneGetCO2Emission> createLaneGetCO2Emission(LaneGetCO2Emission value) {
        return new JAXBElement<LaneGetCO2Emission>(_LaneGetCO2Emission_QNAME, LaneGetCO2Emission.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EdgeGetLastStepMeanSpeedResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Edge_getLastStepMeanSpeedResponse")
    public JAXBElement<EdgeGetLastStepMeanSpeedResponse> createEdgeGetLastStepMeanSpeedResponse(EdgeGetLastStepMeanSpeedResponse value) {
        return new JAXBElement<EdgeGetLastStepMeanSpeedResponse>(_EdgeGetLastStepMeanSpeedResponse_QNAME, EdgeGetLastStepMeanSpeedResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link StartResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "startResponse")
    public JAXBElement<StartResponse> createStartResponse(StartResponse value) {
        return new JAXBElement<StartResponse>(_StartResponse_QNAME, StartResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TrafficlightsGetPhaseDuration }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Trafficlights_getPhaseDuration")
    public JAXBElement<TrafficlightsGetPhaseDuration> createTrafficlightsGetPhaseDuration(TrafficlightsGetPhaseDuration value) {
        return new JAXBElement<TrafficlightsGetPhaseDuration>(_TrafficlightsGetPhaseDuration_QNAME, TrafficlightsGetPhaseDuration.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetAccelResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setAccelResponse")
    public JAXBElement<VehicleSetAccelResponse> createVehicleSetAccelResponse(VehicleSetAccelResponse value) {
        return new JAXBElement<VehicleSetAccelResponse>(_VehicleSetAccelResponse_QNAME, VehicleSetAccelResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EdgeSetEffortResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Edge_setEffortResponse")
    public JAXBElement<EdgeSetEffortResponse> createEdgeSetEffortResponse(EdgeSetEffortResponse value) {
        return new JAXBElement<EdgeSetEffortResponse>(_EdgeSetEffortResponse_QNAME, EdgeSetEffortResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link InductionloopGetLastStepVehicleIDsResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Inductionloop_getLastStepVehicleIDsResponse")
    public JAXBElement<InductionloopGetLastStepVehicleIDsResponse> createInductionloopGetLastStepVehicleIDsResponse(InductionloopGetLastStepVehicleIDsResponse value) {
        return new JAXBElement<InductionloopGetLastStepVehicleIDsResponse>(_InductionloopGetLastStepVehicleIDsResponse_QNAME, InductionloopGetLastStepVehicleIDsResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link JunctionGetPosition }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Junction_getPosition")
    public JAXBElement<JunctionGetPosition> createJunctionGetPosition(JunctionGetPosition value) {
        return new JAXBElement<JunctionGetPosition>(_JunctionGetPosition_QNAME, JunctionGetPosition.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TrafficlightsSetRedYellowGreenState }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Trafficlights_setRedYellowGreenState")
    public JAXBElement<TrafficlightsSetRedYellowGreenState> createTrafficlightsSetRedYellowGreenState(TrafficlightsSetRedYellowGreenState value) {
        return new JAXBElement<TrafficlightsSetRedYellowGreenState>(_TrafficlightsSetRedYellowGreenState_QNAME, TrafficlightsSetRedYellowGreenState.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PolygonSetTypeResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Polygon_setTypeResponse")
    public JAXBElement<PolygonSetTypeResponse> createPolygonSetTypeResponse(PolygonSetTypeResponse value) {
        return new JAXBElement<PolygonSetTypeResponse>(_PolygonSetTypeResponse_QNAME, PolygonSetTypeResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EdgeGetCOEmission }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Edge_getCOEmission")
    public JAXBElement<EdgeGetCOEmission> createEdgeGetCOEmission(EdgeGetCOEmission value) {
        return new JAXBElement<EdgeGetCOEmission>(_EdgeGetCOEmission_QNAME, EdgeGetCOEmission.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EdgeGetNoiseEmissionResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Edge_getNoiseEmissionResponse")
    public JAXBElement<EdgeGetNoiseEmissionResponse> createEdgeGetNoiseEmissionResponse(EdgeGetNoiseEmissionResponse value) {
        return new JAXBElement<EdgeGetNoiseEmissionResponse>(_EdgeGetNoiseEmissionResponse_QNAME, EdgeGetNoiseEmissionResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetStopResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setStopResponse")
    public JAXBElement<VehicleSetStopResponse> createVehicleSetStopResponse(VehicleSetStopResponse value) {
        return new JAXBElement<VehicleSetStopResponse>(_VehicleSetStopResponse_QNAME, VehicleSetStopResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetMaxSpeed }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getMaxSpeed")
    public JAXBElement<VehicleGetMaxSpeed> createVehicleGetMaxSpeed(VehicleGetMaxSpeed value) {
        return new JAXBElement<VehicleGetMaxSpeed>(_VehicleGetMaxSpeed_QNAME, VehicleGetMaxSpeed.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetFuelConsumption }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getFuelConsumption")
    public JAXBElement<VehicleGetFuelConsumption> createVehicleGetFuelConsumption(VehicleGetFuelConsumption value) {
        return new JAXBElement<VehicleGetFuelConsumption>(_VehicleGetFuelConsumption_QNAME, VehicleGetFuelConsumption.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TrafficlightsGetIDCount }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Trafficlights_getIDCount")
    public JAXBElement<TrafficlightsGetIDCount> createTrafficlightsGetIDCount(TrafficlightsGetIDCount value) {
        return new JAXBElement<TrafficlightsGetIDCount>(_TrafficlightsGetIDCount_QNAME, TrafficlightsGetIDCount.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetTau }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setTau")
    public JAXBElement<VehicleSetTau> createVehicleSetTau(VehicleSetTau value) {
        return new JAXBElement<VehicleSetTau>(_VehicleSetTau_QNAME, VehicleSetTau.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ArealDetectorGetJamLengthVehicleResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "ArealDetector_getJamLengthVehicleResponse")
    public JAXBElement<ArealDetectorGetJamLengthVehicleResponse> createArealDetectorGetJamLengthVehicleResponse(ArealDetectorGetJamLengthVehicleResponse value) {
        return new JAXBElement<ArealDetectorGetJamLengthVehicleResponse>(_ArealDetectorGetJamLengthVehicleResponse_QNAME, ArealDetectorGetJamLengthVehicleResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link MultientryexitGetLastStepMeanSpeedResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Multientryexit_getLastStepMeanSpeedResponse")
    public JAXBElement<MultientryexitGetLastStepMeanSpeedResponse> createMultientryexitGetLastStepMeanSpeedResponse(MultientryexitGetLastStepMeanSpeedResponse value) {
        return new JAXBElement<MultientryexitGetLastStepMeanSpeedResponse>(_MultientryexitGetLastStepMeanSpeedResponse_QNAME, MultientryexitGetLastStepMeanSpeedResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EdgeGetNOxEmission }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Edge_getNOxEmission")
    public JAXBElement<EdgeGetNOxEmission> createEdgeGetNOxEmission(EdgeGetNOxEmission value) {
        return new JAXBElement<EdgeGetNOxEmission>(_EdgeGetNOxEmission_QNAME, EdgeGetNOxEmission.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetRouteResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setRouteResponse")
    public JAXBElement<VehicleSetRouteResponse> createVehicleSetRouteResponse(VehicleSetRouteResponse value) {
        return new JAXBElement<VehicleSetRouteResponse>(_VehicleSetRouteResponse_QNAME, VehicleSetRouteResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PolygonGetShape }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Polygon_getShape")
    public JAXBElement<PolygonGetShape> createPolygonGetShape(PolygonGetShape value) {
        return new JAXBElement<PolygonGetShape>(_PolygonGetShape_QNAME, PolygonGetShape.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EdgeGetCO2EmissionResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Edge_getCO2EmissionResponse")
    public JAXBElement<EdgeGetCO2EmissionResponse> createEdgeGetCO2EmissionResponse(EdgeGetCO2EmissionResponse value) {
        return new JAXBElement<EdgeGetCO2EmissionResponse>(_EdgeGetCO2EmissionResponse_QNAME, EdgeGetCO2EmissionResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PolygonGetIDList }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Polygon_getIDList")
    public JAXBElement<PolygonGetIDList> createPolygonGetIDList(PolygonGetIDList value) {
        return new JAXBElement<PolygonGetIDList>(_PolygonGetIDList_QNAME, PolygonGetIDList.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PoiRemove }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Poi_remove")
    public JAXBElement<PoiRemove> createPoiRemove(PoiRemove value) {
        return new JAXBElement<PoiRemove>(_PoiRemove_QNAME, PoiRemove.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetEmissionClass }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setEmissionClass")
    public JAXBElement<VehicleSetEmissionClass> createVehicleSetEmissionClass(VehicleSetEmissionClass value) {
        return new JAXBElement<VehicleSetEmissionClass>(_VehicleSetEmissionClass_QNAME, VehicleSetEmissionClass.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetLastStepVehicleNumberResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getLastStepVehicleNumberResponse")
    public JAXBElement<LaneGetLastStepVehicleNumberResponse> createLaneGetLastStepVehicleNumberResponse(LaneGetLastStepVehicleNumberResponse value) {
        return new JAXBElement<LaneGetLastStepVehicleNumberResponse>(_LaneGetLastStepVehicleNumberResponse_QNAME, LaneGetLastStepVehicleNumberResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeGetEmissionClassResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_getEmissionClassResponse")
    public JAXBElement<VehicletypeGetEmissionClassResponse> createVehicletypeGetEmissionClassResponse(VehicletypeGetEmissionClassResponse value) {
        return new JAXBElement<VehicletypeGetEmissionClassResponse>(_VehicletypeGetEmissionClassResponse_QNAME, VehicletypeGetEmissionClassResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetAdaptedTraveltimeResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setAdaptedTraveltimeResponse")
    public JAXBElement<VehicleSetAdaptedTraveltimeResponse> createVehicleSetAdaptedTraveltimeResponse(VehicleSetAdaptedTraveltimeResponse value) {
        return new JAXBElement<VehicleSetAdaptedTraveltimeResponse>(_VehicleSetAdaptedTraveltimeResponse_QNAME, VehicleSetAdaptedTraveltimeResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TrafficlightsGetNextSwitchResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Trafficlights_getNextSwitchResponse")
    public JAXBElement<TrafficlightsGetNextSwitchResponse> createTrafficlightsGetNextSwitchResponse(TrafficlightsGetNextSwitchResponse value) {
        return new JAXBElement<TrafficlightsGetNextSwitchResponse>(_TrafficlightsGetNextSwitchResponse_QNAME, TrafficlightsGetNextSwitchResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeGetSpeedDeviationResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_getSpeedDeviationResponse")
    public JAXBElement<VehicletypeGetSpeedDeviationResponse> createVehicletypeGetSpeedDeviationResponse(VehicletypeGetSpeedDeviationResponse value) {
        return new JAXBElement<VehicletypeGetSpeedDeviationResponse>(_VehicletypeGetSpeedDeviationResponse_QNAME, VehicletypeGetSpeedDeviationResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetLaneID }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getLaneID")
    public JAXBElement<VehicleGetLaneID> createVehicleGetLaneID(VehicleGetLaneID value) {
        return new JAXBElement<VehicleGetLaneID>(_VehicleGetLaneID_QNAME, VehicleGetLaneID.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeGetDecel }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_getDecel")
    public JAXBElement<VehicletypeGetDecel> createVehicletypeGetDecel(VehicletypeGetDecel value) {
        return new JAXBElement<VehicletypeGetDecel>(_VehicletypeGetDecel_QNAME, VehicletypeGetDecel.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetRouteID }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setRouteID")
    public JAXBElement<VehicleSetRouteID> createVehicleSetRouteID(VehicleSetRouteID value) {
        return new JAXBElement<VehicleSetRouteID>(_VehicleSetRouteID_QNAME, VehicleSetRouteID.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetAllowedSpeedResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getAllowedSpeedResponse")
    public JAXBElement<VehicleGetAllowedSpeedResponse> createVehicleGetAllowedSpeedResponse(VehicleGetAllowedSpeedResponse value) {
        return new JAXBElement<VehicleGetAllowedSpeedResponse>(_VehicleGetAllowedSpeedResponse_QNAME, VehicleGetAllowedSpeedResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TrafficlightsGetRedYellowGreenStateResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Trafficlights_getRedYellowGreenStateResponse")
    public JAXBElement<TrafficlightsGetRedYellowGreenStateResponse> createTrafficlightsGetRedYellowGreenStateResponse(TrafficlightsGetRedYellowGreenStateResponse value) {
        return new JAXBElement<TrafficlightsGetRedYellowGreenStateResponse>(_TrafficlightsGetRedYellowGreenStateResponse_QNAME, TrafficlightsGetRedYellowGreenStateResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link GUISetOffsetResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "GUI_setOffsetResponse")
    public JAXBElement<GUISetOffsetResponse> createGUISetOffsetResponse(GUISetOffsetResponse value) {
        return new JAXBElement<GUISetOffsetResponse>(_GUISetOffsetResponse_QNAME, GUISetOffsetResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetAccelResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getAccelResponse")
    public JAXBElement<VehicleGetAccelResponse> createVehicleGetAccelResponse(VehicleGetAccelResponse value) {
        return new JAXBElement<VehicleGetAccelResponse>(_VehicleGetAccelResponse_QNAME, VehicleGetAccelResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetBestLanesResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getBestLanesResponse")
    public JAXBElement<VehicleGetBestLanesResponse> createVehicleGetBestLanesResponse(VehicleGetBestLanesResponse value) {
        return new JAXBElement<VehicleGetBestLanesResponse>(_VehicleGetBestLanesResponse_QNAME, VehicleGetBestLanesResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetLaneIDResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getLaneIDResponse")
    public JAXBElement<VehicleGetLaneIDResponse> createVehicleGetLaneIDResponse(VehicleGetLaneIDResponse value) {
        return new JAXBElement<VehicleGetLaneIDResponse>(_VehicleGetLaneIDResponse_QNAME, VehicleGetLaneIDResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetPersonNumberResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getPersonNumberResponse")
    public JAXBElement<VehicleGetPersonNumberResponse> createVehicleGetPersonNumberResponse(VehicleGetPersonNumberResponse value) {
        return new JAXBElement<VehicleGetPersonNumberResponse>(_VehicleGetPersonNumberResponse_QNAME, VehicleGetPersonNumberResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetPMxEmissionResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getPMxEmissionResponse")
    public JAXBElement<VehicleGetPMxEmissionResponse> createVehicleGetPMxEmissionResponse(VehicleGetPMxEmissionResponse value) {
        return new JAXBElement<VehicleGetPMxEmissionResponse>(_VehicleGetPMxEmissionResponse_QNAME, VehicleGetPMxEmissionResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeSetWidth }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_setWidth")
    public JAXBElement<VehicletypeSetWidth> createVehicletypeSetWidth(VehicletypeSetWidth value) {
        return new JAXBElement<VehicletypeSetWidth>(_VehicletypeSetWidth_QNAME, VehicletypeSetWidth.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PolygonSetShapeResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Polygon_setShapeResponse")
    public JAXBElement<PolygonSetShapeResponse> createPolygonSetShapeResponse(PolygonSetShapeResponse value) {
        return new JAXBElement<PolygonSetShapeResponse>(_PolygonSetShapeResponse_QNAME, PolygonSetShapeResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PolygonGetTypeResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Polygon_getTypeResponse")
    public JAXBElement<PolygonGetTypeResponse> createPolygonGetTypeResponse(PolygonGetTypeResponse value) {
        return new JAXBElement<PolygonGetTypeResponse>(_PolygonGetTypeResponse_QNAME, PolygonGetTypeResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetIDCountResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getIDCountResponse")
    public JAXBElement<LaneGetIDCountResponse> createLaneGetIDCountResponse(LaneGetIDCountResponse value) {
        return new JAXBElement<LaneGetIDCountResponse>(_LaneGetIDCountResponse_QNAME, LaneGetIDCountResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetParkingStartingVehiclesIDListResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getParkingStartingVehiclesIDListResponse")
    public JAXBElement<SimulationGetParkingStartingVehiclesIDListResponse> createSimulationGetParkingStartingVehiclesIDListResponse(SimulationGetParkingStartingVehiclesIDListResponse value) {
        return new JAXBElement<SimulationGetParkingStartingVehiclesIDListResponse>(_SimulationGetParkingStartingVehiclesIDListResponse_QNAME, SimulationGetParkingStartingVehiclesIDListResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PoiGetIDCount }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Poi_getIDCount")
    public JAXBElement<PoiGetIDCount> createPoiGetIDCount(PoiGetIDCount value) {
        return new JAXBElement<PoiGetIDCount>(_PoiGetIDCount_QNAME, PoiGetIDCount.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PolygonGetColor }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Polygon_getColor")
    public JAXBElement<PolygonGetColor> createPolygonGetColor(PolygonGetColor value) {
        return new JAXBElement<PolygonGetColor>(_PolygonGetColor_QNAME, PolygonGetColor.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PoiSetColorResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Poi_setColorResponse")
    public JAXBElement<PoiSetColorResponse> createPoiSetColorResponse(PoiSetColorResponse value) {
        return new JAXBElement<PoiSetColorResponse>(_PoiSetColorResponse_QNAME, PoiSetColorResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneSetLengthResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_setLengthResponse")
    public JAXBElement<LaneSetLengthResponse> createLaneSetLengthResponse(LaneSetLengthResponse value) {
        return new JAXBElement<LaneSetLengthResponse>(_LaneSetLengthResponse_QNAME, LaneSetLengthResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetMaxSpeedResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getMaxSpeedResponse")
    public JAXBElement<LaneGetMaxSpeedResponse> createLaneGetMaxSpeedResponse(LaneGetMaxSpeedResponse value) {
        return new JAXBElement<LaneGetMaxSpeedResponse>(_LaneGetMaxSpeedResponse_QNAME, LaneGetMaxSpeedResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetEmissionClass }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getEmissionClass")
    public JAXBElement<VehicleGetEmissionClass> createVehicleGetEmissionClass(VehicleGetEmissionClass value) {
        return new JAXBElement<VehicleGetEmissionClass>(_VehicleGetEmissionClass_QNAME, VehicleGetEmissionClass.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetTypeIDResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getTypeIDResponse")
    public JAXBElement<VehicleGetTypeIDResponse> createVehicleGetTypeIDResponse(VehicleGetTypeIDResponse value) {
        return new JAXBElement<VehicleGetTypeIDResponse>(_VehicleGetTypeIDResponse_QNAME, VehicleGetTypeIDResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TrafficlightsGetPhaseResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Trafficlights_getPhaseResponse")
    public JAXBElement<TrafficlightsGetPhaseResponse> createTrafficlightsGetPhaseResponse(TrafficlightsGetPhaseResponse value) {
        return new JAXBElement<TrafficlightsGetPhaseResponse>(_TrafficlightsGetPhaseResponse_QNAME, TrafficlightsGetPhaseResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetImperfection }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getImperfection")
    public JAXBElement<VehicleGetImperfection> createVehicleGetImperfection(VehicleGetImperfection value) {
        return new JAXBElement<VehicleGetImperfection>(_VehicleGetImperfection_QNAME, VehicleGetImperfection.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EdgeGetLastStepOccupancy }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Edge_getLastStepOccupancy")
    public JAXBElement<EdgeGetLastStepOccupancy> createEdgeGetLastStepOccupancy(EdgeGetLastStepOccupancy value) {
        return new JAXBElement<EdgeGetLastStepOccupancy>(_EdgeGetLastStepOccupancy_QNAME, EdgeGetLastStepOccupancy.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeGetTauResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_getTauResponse")
    public JAXBElement<VehicletypeGetTauResponse> createVehicletypeGetTauResponse(VehicletypeGetTauResponse value) {
        return new JAXBElement<VehicletypeGetTauResponse>(_VehicletypeGetTauResponse_QNAME, VehicletypeGetTauResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EdgeGetLastStepVehicleIDsResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Edge_getLastStepVehicleIDsResponse")
    public JAXBElement<EdgeGetLastStepVehicleIDsResponse> createEdgeGetLastStepVehicleIDsResponse(EdgeGetLastStepVehicleIDsResponse value) {
        return new JAXBElement<EdgeGetLastStepVehicleIDsResponse>(_EdgeGetLastStepVehicleIDsResponse_QNAME, EdgeGetLastStepVehicleIDsResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeSetVehicleClass }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_setVehicleClass")
    public JAXBElement<VehicletypeSetVehicleClass> createVehicletypeSetVehicleClass(VehicletypeSetVehicleClass value) {
        return new JAXBElement<VehicletypeSetVehicleClass>(_VehicletypeSetVehicleClass_QNAME, VehicletypeSetVehicleClass.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetSpeedWithoutTraCI }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getSpeedWithoutTraCI")
    public JAXBElement<VehicleGetSpeedWithoutTraCI> createVehicleGetSpeedWithoutTraCI(VehicleGetSpeedWithoutTraCI value) {
        return new JAXBElement<VehicleGetSpeedWithoutTraCI>(_VehicleGetSpeedWithoutTraCI_QNAME, VehicleGetSpeedWithoutTraCI.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link JunctionGetIDList }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Junction_getIDList")
    public JAXBElement<JunctionGetIDList> createJunctionGetIDList(JunctionGetIDList value) {
        return new JAXBElement<JunctionGetIDList>(_JunctionGetIDList_QNAME, JunctionGetIDList.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeGetVehicleClassResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_getVehicleClassResponse")
    public JAXBElement<VehicletypeGetVehicleClassResponse> createVehicletypeGetVehicleClassResponse(VehicletypeGetVehicleClassResponse value) {
        return new JAXBElement<VehicletypeGetVehicleClassResponse>(_VehicletypeGetVehicleClassResponse_QNAME, VehicletypeGetVehicleClassResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetLinks }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getLinks")
    public JAXBElement<LaneGetLinks> createLaneGetLinks(LaneGetLinks value) {
        return new JAXBElement<LaneGetLinks>(_LaneGetLinks_QNAME, LaneGetLinks.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetArrivedIDListResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getArrivedIDListResponse")
    public JAXBElement<SimulationGetArrivedIDListResponse> createSimulationGetArrivedIDListResponse(SimulationGetArrivedIDListResponse value) {
        return new JAXBElement<SimulationGetArrivedIDListResponse>(_SimulationGetArrivedIDListResponse_QNAME, SimulationGetArrivedIDListResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EdgeGetIDListResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Edge_getIDListResponse")
    public JAXBElement<EdgeGetIDListResponse> createEdgeGetIDListResponse(EdgeGetIDListResponse value) {
        return new JAXBElement<EdgeGetIDListResponse>(_EdgeGetIDListResponse_QNAME, EdgeGetIDListResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ArealDetectorGetJamLengthMeters }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "ArealDetector_getJamLengthMeters")
    public JAXBElement<ArealDetectorGetJamLengthMeters> createArealDetectorGetJamLengthMeters(ArealDetectorGetJamLengthMeters value) {
        return new JAXBElement<ArealDetectorGetJamLengthMeters>(_ArealDetectorGetJamLengthMeters_QNAME, ArealDetectorGetJamLengthMeters.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ArealDetectorGetIDList }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "ArealDetector_getIDList")
    public JAXBElement<ArealDetectorGetIDList> createArealDetectorGetIDList(ArealDetectorGetIDList value) {
        return new JAXBElement<ArealDetectorGetIDList>(_ArealDetectorGetIDList_QNAME, ArealDetectorGetIDList.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetLastStepMeanSpeedResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getLastStepMeanSpeedResponse")
    public JAXBElement<LaneGetLastStepMeanSpeedResponse> createLaneGetLastStepMeanSpeedResponse(LaneGetLastStepMeanSpeedResponse value) {
        return new JAXBElement<LaneGetLastStepMeanSpeedResponse>(_LaneGetLastStepMeanSpeedResponse_QNAME, LaneGetLastStepMeanSpeedResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TrafficlightsGetCompleteRedYellowGreenDefinitionResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Trafficlights_getCompleteRedYellowGreenDefinitionResponse")
    public JAXBElement<TrafficlightsGetCompleteRedYellowGreenDefinitionResponse> createTrafficlightsGetCompleteRedYellowGreenDefinitionResponse(TrafficlightsGetCompleteRedYellowGreenDefinitionResponse value) {
        return new JAXBElement<TrafficlightsGetCompleteRedYellowGreenDefinitionResponse>(_TrafficlightsGetCompleteRedYellowGreenDefinitionResponse_QNAME, TrafficlightsGetCompleteRedYellowGreenDefinitionResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TrafficlightsGetControlledLanes }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Trafficlights_getControlledLanes")
    public JAXBElement<TrafficlightsGetControlledLanes> createTrafficlightsGetControlledLanes(TrafficlightsGetControlledLanes value) {
        return new JAXBElement<TrafficlightsGetControlledLanes>(_TrafficlightsGetControlledLanes_QNAME, TrafficlightsGetControlledLanes.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link MultientryexitGetIDList }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Multientryexit_getIDList")
    public JAXBElement<MultientryexitGetIDList> createMultientryexitGetIDList(MultientryexitGetIDList value) {
        return new JAXBElement<MultientryexitGetIDList>(_MultientryexitGetIDList_QNAME, MultientryexitGetIDList.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetShapeResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getShapeResponse")
    public JAXBElement<LaneGetShapeResponse> createLaneGetShapeResponse(LaneGetShapeResponse value) {
        return new JAXBElement<LaneGetShapeResponse>(_LaneGetShapeResponse_QNAME, LaneGetShapeResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link JunctionGetIDCount }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Junction_getIDCount")
    public JAXBElement<JunctionGetIDCount> createJunctionGetIDCount(JunctionGetIDCount value) {
        return new JAXBElement<JunctionGetIDCount>(_JunctionGetIDCount_QNAME, JunctionGetIDCount.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetSpeedDeviation }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getSpeedDeviation")
    public JAXBElement<VehicleGetSpeedDeviation> createVehicleGetSpeedDeviation(VehicleGetSpeedDeviation value) {
        return new JAXBElement<VehicleGetSpeedDeviation>(_VehicleGetSpeedDeviation_QNAME, VehicleGetSpeedDeviation.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetVehicleClassResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getVehicleClassResponse")
    public JAXBElement<VehicleGetVehicleClassResponse> createVehicleGetVehicleClassResponse(VehicleGetVehicleClassResponse value) {
        return new JAXBElement<VehicleGetVehicleClassResponse>(_VehicleGetVehicleClassResponse_QNAME, VehicleGetVehicleClassResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetCO2Emission }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getCO2Emission")
    public JAXBElement<VehicleGetCO2Emission> createVehicleGetCO2Emission(VehicleGetCO2Emission value) {
        return new JAXBElement<VehicleGetCO2Emission>(_VehicleGetCO2Emission_QNAME, VehicleGetCO2Emission.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeGetIDCountResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_getIDCountResponse")
    public JAXBElement<VehicletypeGetIDCountResponse> createVehicletypeGetIDCountResponse(VehicletypeGetIDCountResponse value) {
        return new JAXBElement<VehicletypeGetIDCountResponse>(_VehicletypeGetIDCountResponse_QNAME, VehicletypeGetIDCountResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetLaneIndex }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getLaneIndex")
    public JAXBElement<VehicleGetLaneIndex> createVehicleGetLaneIndex(VehicleGetLaneIndex value) {
        return new JAXBElement<VehicleGetLaneIndex>(_VehicleGetLaneIndex_QNAME, VehicleGetLaneIndex.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetLength }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getLength")
    public JAXBElement<LaneGetLength> createLaneGetLength(LaneGetLength value) {
        return new JAXBElement<LaneGetLength>(_LaneGetLength_QNAME, LaneGetLength.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetParkingStartingVehiclesNumber }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getParkingStartingVehiclesNumber")
    public JAXBElement<SimulationGetParkingStartingVehiclesNumber> createSimulationGetParkingStartingVehiclesNumber(SimulationGetParkingStartingVehiclesNumber value) {
        return new JAXBElement<SimulationGetParkingStartingVehiclesNumber>(_SimulationGetParkingStartingVehiclesNumber_QNAME, SimulationGetParkingStartingVehiclesNumber.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationConvert2DResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_convert2DResponse")
    public JAXBElement<SimulationConvert2DResponse> createSimulationConvert2DResponse(SimulationConvert2DResponse value) {
        return new JAXBElement<SimulationConvert2DResponse>(_SimulationConvert2DResponse_QNAME, SimulationConvert2DResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PoiAddResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Poi_addResponse")
    public JAXBElement<PoiAddResponse> createPoiAddResponse(PoiAddResponse value) {
        return new JAXBElement<PoiAddResponse>(_PoiAddResponse_QNAME, PoiAddResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ArealDetectorGetJamLengthMetersResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "ArealDetector_getJamLengthMetersResponse")
    public JAXBElement<ArealDetectorGetJamLengthMetersResponse> createArealDetectorGetJamLengthMetersResponse(ArealDetectorGetJamLengthMetersResponse value) {
        return new JAXBElement<ArealDetectorGetJamLengthMetersResponse>(_ArealDetectorGetJamLengthMetersResponse_QNAME, ArealDetectorGetJamLengthMetersResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetDistanceResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getDistanceResponse")
    public JAXBElement<VehicleGetDistanceResponse> createVehicleGetDistanceResponse(VehicleGetDistanceResponse value) {
        return new JAXBElement<VehicleGetDistanceResponse>(_VehicleGetDistanceResponse_QNAME, VehicleGetDistanceResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EdgeSetMaxSpeed }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Edge_setMaxSpeed")
    public JAXBElement<EdgeSetMaxSpeed> createEdgeSetMaxSpeed(EdgeSetMaxSpeed value) {
        return new JAXBElement<EdgeSetMaxSpeed>(_EdgeSetMaxSpeed_QNAME, EdgeSetMaxSpeed.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeSetAccel }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_setAccel")
    public JAXBElement<VehicletypeSetAccel> createVehicletypeSetAccel(VehicletypeSetAccel value) {
        return new JAXBElement<VehicletypeSetAccel>(_VehicletypeSetAccel_QNAME, VehicletypeSetAccel.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetDrivingDistance2DResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getDrivingDistance2DResponse")
    public JAXBElement<VehicleGetDrivingDistance2DResponse> createVehicleGetDrivingDistance2DResponse(VehicleGetDrivingDistance2DResponse value) {
        return new JAXBElement<VehicleGetDrivingDistance2DResponse>(_VehicleGetDrivingDistance2DResponse_QNAME, VehicleGetDrivingDistance2DResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetLastStepVehicleIDs }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getLastStepVehicleIDs")
    public JAXBElement<LaneGetLastStepVehicleIDs> createLaneGetLastStepVehicleIDs(LaneGetLastStepVehicleIDs value) {
        return new JAXBElement<LaneGetLastStepVehicleIDs>(_LaneGetLastStepVehicleIDs_QNAME, LaneGetLastStepVehicleIDs.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link RouteGetEdges }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Route_getEdges")
    public JAXBElement<RouteGetEdges> createRouteGetEdges(RouteGetEdges value) {
        return new JAXBElement<RouteGetEdges>(_RouteGetEdges_QNAME, RouteGetEdges.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link InductionloopGetLastStepMeanSpeedResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Inductionloop_getLastStepMeanSpeedResponse")
    public JAXBElement<InductionloopGetLastStepMeanSpeedResponse> createInductionloopGetLastStepMeanSpeedResponse(InductionloopGetLastStepMeanSpeedResponse value) {
        return new JAXBElement<InductionloopGetLastStepMeanSpeedResponse>(_InductionloopGetLastStepMeanSpeedResponse_QNAME, InductionloopGetLastStepMeanSpeedResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EdgeGetLastStepVehicleNumber }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Edge_getLastStepVehicleNumber")
    public JAXBElement<EdgeGetLastStepVehicleNumber> createEdgeGetLastStepVehicleNumber(EdgeGetLastStepVehicleNumber value) {
        return new JAXBElement<EdgeGetLastStepVehicleNumber>(_EdgeGetLastStepVehicleNumber_QNAME, EdgeGetLastStepVehicleNumber.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link GUISetZoomResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "GUI_setZoomResponse")
    public JAXBElement<GUISetZoomResponse> createGUISetZoomResponse(GUISetZoomResponse value) {
        return new JAXBElement<GUISetZoomResponse>(_GUISetZoomResponse_QNAME, GUISetZoomResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneSetAllowedResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_setAllowedResponse")
    public JAXBElement<LaneSetAllowedResponse> createLaneSetAllowedResponse(LaneSetAllowedResponse value) {
        return new JAXBElement<LaneSetAllowedResponse>(_LaneSetAllowedResponse_QNAME, LaneSetAllowedResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link JunctionGetIDCountResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Junction_getIDCountResponse")
    public JAXBElement<JunctionGetIDCountResponse> createJunctionGetIDCountResponse(JunctionGetIDCountResponse value) {
        return new JAXBElement<JunctionGetIDCountResponse>(_JunctionGetIDCountResponse_QNAME, JunctionGetIDCountResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TrafficlightsSetProgramResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Trafficlights_setProgramResponse")
    public JAXBElement<TrafficlightsSetProgramResponse> createTrafficlightsSetProgramResponse(TrafficlightsSetProgramResponse value) {
        return new JAXBElement<TrafficlightsSetProgramResponse>(_TrafficlightsSetProgramResponse_QNAME, TrafficlightsSetProgramResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetCOEmission }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getCOEmission")
    public JAXBElement<VehicleGetCOEmission> createVehicleGetCOEmission(VehicleGetCOEmission value) {
        return new JAXBElement<VehicleGetCOEmission>(_VehicleGetCOEmission_QNAME, VehicleGetCOEmission.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link InductionloopGetIDCount }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Inductionloop_getIDCount")
    public JAXBElement<InductionloopGetIDCount> createInductionloopGetIDCount(InductionloopGetIDCount value) {
        return new JAXBElement<InductionloopGetIDCount>(_InductionloopGetIDCount_QNAME, InductionloopGetIDCount.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetSpeedResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getSpeedResponse")
    public JAXBElement<VehicleGetSpeedResponse> createVehicleGetSpeedResponse(VehicleGetSpeedResponse value) {
        return new JAXBElement<VehicleGetSpeedResponse>(_VehicleGetSpeedResponse_QNAME, VehicleGetSpeedResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetDepartedIDList }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getDepartedIDList")
    public JAXBElement<SimulationGetDepartedIDList> createSimulationGetDepartedIDList(SimulationGetDepartedIDList value) {
        return new JAXBElement<SimulationGetDepartedIDList>(_SimulationGetDepartedIDList_QNAME, SimulationGetDepartedIDList.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link GUIGetZoomResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "GUI_getZoomResponse")
    public JAXBElement<GUIGetZoomResponse> createGUIGetZoomResponse(GUIGetZoomResponse value) {
        return new JAXBElement<GUIGetZoomResponse>(_GUIGetZoomResponse_QNAME, GUIGetZoomResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetWidth }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setWidth")
    public JAXBElement<VehicleSetWidth> createVehicleSetWidth(VehicleSetWidth value) {
        return new JAXBElement<VehicleSetWidth>(_VehicleSetWidth_QNAME, VehicleSetWidth.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link GUITrackVehicleResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "GUI_trackVehicleResponse")
    public JAXBElement<GUITrackVehicleResponse> createGUITrackVehicleResponse(GUITrackVehicleResponse value) {
        return new JAXBElement<GUITrackVehicleResponse>(_GUITrackVehicleResponse_QNAME, GUITrackVehicleResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetNoiseEmissionResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getNoiseEmissionResponse")
    public JAXBElement<VehicleGetNoiseEmissionResponse> createVehicleGetNoiseEmissionResponse(VehicleGetNoiseEmissionResponse value) {
        return new JAXBElement<VehicleGetNoiseEmissionResponse>(_VehicleGetNoiseEmissionResponse_QNAME, VehicleGetNoiseEmissionResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetMaxSpeedResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setMaxSpeedResponse")
    public JAXBElement<VehicleSetMaxSpeedResponse> createVehicleSetMaxSpeedResponse(VehicleSetMaxSpeedResponse value) {
        return new JAXBElement<VehicleSetMaxSpeedResponse>(_VehicleSetMaxSpeedResponse_QNAME, VehicleSetMaxSpeedResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeGetSpeedFactor }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_getSpeedFactor")
    public JAXBElement<VehicletypeGetSpeedFactor> createVehicletypeGetSpeedFactor(VehicletypeGetSpeedFactor value) {
        return new JAXBElement<VehicletypeGetSpeedFactor>(_VehicletypeGetSpeedFactor_QNAME, VehicletypeGetSpeedFactor.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetNoiseEmissionResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getNoiseEmissionResponse")
    public JAXBElement<LaneGetNoiseEmissionResponse> createLaneGetNoiseEmissionResponse(LaneGetNoiseEmissionResponse value) {
        return new JAXBElement<LaneGetNoiseEmissionResponse>(_LaneGetNoiseEmissionResponse_QNAME, LaneGetNoiseEmissionResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetSpeedResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setSpeedResponse")
    public JAXBElement<VehicleSetSpeedResponse> createVehicleSetSpeedResponse(VehicleSetSpeedResponse value) {
        return new JAXBElement<VehicleSetSpeedResponse>(_VehicleSetSpeedResponse_QNAME, VehicleSetSpeedResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleChangeLaneResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_changeLaneResponse")
    public JAXBElement<VehicleChangeLaneResponse> createVehicleChangeLaneResponse(VehicleChangeLaneResponse value) {
        return new JAXBElement<VehicleChangeLaneResponse>(_VehicleChangeLaneResponse_QNAME, VehicleChangeLaneResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link GUISetZoom }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "GUI_setZoom")
    public JAXBElement<GUISetZoom> createGUISetZoom(GUISetZoom value) {
        return new JAXBElement<GUISetZoom>(_GUISetZoom_QNAME, GUISetZoom.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PoiGetType }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Poi_getType")
    public JAXBElement<PoiGetType> createPoiGetType(PoiGetType value) {
        return new JAXBElement<PoiGetType>(_PoiGetType_QNAME, PoiGetType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleRemoveResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_removeResponse")
    public JAXBElement<VehicleRemoveResponse> createVehicleRemoveResponse(VehicleRemoveResponse value) {
        return new JAXBElement<VehicleRemoveResponse>(_VehicleRemoveResponse_QNAME, VehicleRemoveResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EdgeGetLastStepHaltingNumber }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Edge_getLastStepHaltingNumber")
    public JAXBElement<EdgeGetLastStepHaltingNumber> createEdgeGetLastStepHaltingNumber(EdgeGetLastStepHaltingNumber value) {
        return new JAXBElement<EdgeGetLastStepHaltingNumber>(_EdgeGetLastStepHaltingNumber_QNAME, EdgeGetLastStepHaltingNumber.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetSignals }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getSignals")
    public JAXBElement<VehicleGetSignals> createVehicleGetSignals(VehicleGetSignals value) {
        return new JAXBElement<VehicleGetSignals>(_VehicleGetSignals_QNAME, VehicleGetSignals.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetLengthResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getLengthResponse")
    public JAXBElement<LaneGetLengthResponse> createLaneGetLengthResponse(LaneGetLengthResponse value) {
        return new JAXBElement<LaneGetLengthResponse>(_LaneGetLengthResponse_QNAME, LaneGetLengthResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EdgeGetCO2Emission }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Edge_getCO2Emission")
    public JAXBElement<EdgeGetCO2Emission> createEdgeGetCO2Emission(EdgeGetCO2Emission value) {
        return new JAXBElement<EdgeGetCO2Emission>(_EdgeGetCO2Emission_QNAME, EdgeGetCO2Emission.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeSetDecelResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_setDecelResponse")
    public JAXBElement<VehicletypeSetDecelResponse> createVehicletypeSetDecelResponse(VehicletypeSetDecelResponse value) {
        return new JAXBElement<VehicletypeSetDecelResponse>(_VehicletypeSetDecelResponse_QNAME, VehicletypeSetDecelResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetDecel }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setDecel")
    public JAXBElement<VehicleSetDecel> createVehicleSetDecel(VehicleSetDecel value) {
        return new JAXBElement<VehicleSetDecel>(_VehicleSetDecel_QNAME, VehicleSetDecel.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetLastStepLength }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getLastStepLength")
    public JAXBElement<LaneGetLastStepLength> createLaneGetLastStepLength(LaneGetLastStepLength value) {
        return new JAXBElement<LaneGetLastStepLength>(_LaneGetLastStepLength_QNAME, LaneGetLastStepLength.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetStartingTeleportIDList }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getStartingTeleportIDList")
    public JAXBElement<SimulationGetStartingTeleportIDList> createSimulationGetStartingTeleportIDList(SimulationGetStartingTeleportIDList value) {
        return new JAXBElement<SimulationGetStartingTeleportIDList>(_SimulationGetStartingTeleportIDList_QNAME, SimulationGetStartingTeleportIDList.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeSetMaxSpeed }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_setMaxSpeed")
    public JAXBElement<VehicletypeSetMaxSpeed> createVehicletypeSetMaxSpeed(VehicletypeSetMaxSpeed value) {
        return new JAXBElement<VehicletypeSetMaxSpeed>(_VehicletypeSetMaxSpeed_QNAME, VehicletypeSetMaxSpeed.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link GUIGetZoom }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "GUI_getZoom")
    public JAXBElement<GUIGetZoom> createGUIGetZoom(GUIGetZoom value) {
        return new JAXBElement<GUIGetZoom>(_GUIGetZoom_QNAME, GUIGetZoom.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetIDCountResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getIDCountResponse")
    public JAXBElement<VehicleGetIDCountResponse> createVehicleGetIDCountResponse(VehicleGetIDCountResponse value) {
        return new JAXBElement<VehicleGetIDCountResponse>(_VehicleGetIDCountResponse_QNAME, VehicleGetIDCountResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PoiSetColor }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Poi_setColor")
    public JAXBElement<PoiSetColor> createPoiSetColor(PoiSetColor value) {
        return new JAXBElement<PoiSetColor>(_PoiSetColor_QNAME, PoiSetColor.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeGetSpeedDeviation }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_getSpeedDeviation")
    public JAXBElement<VehicletypeGetSpeedDeviation> createVehicletypeGetSpeedDeviation(VehicletypeGetSpeedDeviation value) {
        return new JAXBElement<VehicletypeGetSpeedDeviation>(_VehicletypeGetSpeedDeviation_QNAME, VehicletypeGetSpeedDeviation.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeSetTauResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_setTauResponse")
    public JAXBElement<VehicletypeSetTauResponse> createVehicletypeSetTauResponse(VehicletypeSetTauResponse value) {
        return new JAXBElement<VehicletypeSetTauResponse>(_VehicletypeSetTauResponse_QNAME, VehicletypeSetTauResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetStopEndingVehiclesIDListResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getStopEndingVehiclesIDListResponse")
    public JAXBElement<SimulationGetStopEndingVehiclesIDListResponse> createSimulationGetStopEndingVehiclesIDListResponse(SimulationGetStopEndingVehiclesIDListResponse value) {
        return new JAXBElement<SimulationGetStopEndingVehiclesIDListResponse>(_SimulationGetStopEndingVehiclesIDListResponse_QNAME, SimulationGetStopEndingVehiclesIDListResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link RouteAddResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Route_addResponse")
    public JAXBElement<RouteAddResponse> createRouteAddResponse(RouteAddResponse value) {
        return new JAXBElement<RouteAddResponse>(_RouteAddResponse_QNAME, RouteAddResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SetSumoBinary }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "setSumoBinary")
    public JAXBElement<SetSumoBinary> createSetSumoBinary(SetSumoBinary value) {
        return new JAXBElement<SetSumoBinary>(_SetSumoBinary_QNAME, SetSumoBinary.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EdgeGetHCEmission }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Edge_getHCEmission")
    public JAXBElement<EdgeGetHCEmission> createEdgeGetHCEmission(EdgeGetHCEmission value) {
        return new JAXBElement<EdgeGetHCEmission>(_EdgeGetHCEmission_QNAME, EdgeGetHCEmission.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetLaneChangeMode }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setLaneChangeMode")
    public JAXBElement<VehicleSetLaneChangeMode> createVehicleSetLaneChangeMode(VehicleSetLaneChangeMode value) {
        return new JAXBElement<VehicleSetLaneChangeMode>(_VehicleSetLaneChangeMode_QNAME, VehicleSetLaneChangeMode.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EdgeGetLastStepHaltingNumberResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Edge_getLastStepHaltingNumberResponse")
    public JAXBElement<EdgeGetLastStepHaltingNumberResponse> createEdgeGetLastStepHaltingNumberResponse(EdgeGetLastStepHaltingNumberResponse value) {
        return new JAXBElement<EdgeGetLastStepHaltingNumberResponse>(_EdgeGetLastStepHaltingNumberResponse_QNAME, EdgeGetLastStepHaltingNumberResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSlowDown }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_slowDown")
    public JAXBElement<VehicleSlowDown> createVehicleSlowDown(VehicleSlowDown value) {
        return new JAXBElement<VehicleSlowDown>(_VehicleSlowDown_QNAME, VehicleSlowDown.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetDecel }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getDecel")
    public JAXBElement<VehicleGetDecel> createVehicleGetDecel(VehicleGetDecel value) {
        return new JAXBElement<VehicleGetDecel>(_VehicleGetDecel_QNAME, VehicleGetDecel.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EdgeGetPMxEmissionResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Edge_getPMxEmissionResponse")
    public JAXBElement<EdgeGetPMxEmissionResponse> createEdgeGetPMxEmissionResponse(EdgeGetPMxEmissionResponse value) {
        return new JAXBElement<EdgeGetPMxEmissionResponse>(_EdgeGetPMxEmissionResponse_QNAME, EdgeGetPMxEmissionResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link GUIScreenshot }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "GUI_screenshot")
    public JAXBElement<GUIScreenshot> createGUIScreenshot(GUIScreenshot value) {
        return new JAXBElement<GUIScreenshot>(_GUIScreenshot_QNAME, GUIScreenshot.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetFuelConsumptionResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getFuelConsumptionResponse")
    public JAXBElement<LaneGetFuelConsumptionResponse> createLaneGetFuelConsumptionResponse(LaneGetFuelConsumptionResponse value) {
        return new JAXBElement<LaneGetFuelConsumptionResponse>(_LaneGetFuelConsumptionResponse_QNAME, LaneGetFuelConsumptionResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link MultientryexitGetLastStepVehicleIDsResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Multientryexit_getLastStepVehicleIDsResponse")
    public JAXBElement<MultientryexitGetLastStepVehicleIDsResponse> createMultientryexitGetLastStepVehicleIDsResponse(MultientryexitGetLastStepVehicleIDsResponse value) {
        return new JAXBElement<MultientryexitGetLastStepVehicleIDsResponse>(_MultientryexitGetLastStepVehicleIDsResponse_QNAME, MultientryexitGetLastStepVehicleIDsResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetImperfection }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setImperfection")
    public JAXBElement<VehicleSetImperfection> createVehicleSetImperfection(VehicleSetImperfection value) {
        return new JAXBElement<VehicleSetImperfection>(_VehicleSetImperfection_QNAME, VehicleSetImperfection.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeSetSpeedFactor }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_setSpeedFactor")
    public JAXBElement<VehicletypeSetSpeedFactor> createVehicletypeSetSpeedFactor(VehicletypeSetSpeedFactor value) {
        return new JAXBElement<VehicletypeSetSpeedFactor>(_VehicletypeSetSpeedFactor_QNAME, VehicletypeSetSpeedFactor.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeSetSpeedFactorResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_setSpeedFactorResponse")
    public JAXBElement<VehicletypeSetSpeedFactorResponse> createVehicletypeSetSpeedFactorResponse(VehicletypeSetSpeedFactorResponse value) {
        return new JAXBElement<VehicletypeSetSpeedFactorResponse>(_VehicletypeSetSpeedFactorResponse_QNAME, VehicletypeSetSpeedFactorResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeSetAccelResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_setAccelResponse")
    public JAXBElement<VehicletypeSetAccelResponse> createVehicletypeSetAccelResponse(VehicletypeSetAccelResponse value) {
        return new JAXBElement<VehicletypeSetAccelResponse>(_VehicletypeSetAccelResponse_QNAME, VehicletypeSetAccelResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EdgeGetEffortResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Edge_getEffortResponse")
    public JAXBElement<EdgeGetEffortResponse> createEdgeGetEffortResponse(EdgeGetEffortResponse value) {
        return new JAXBElement<EdgeGetEffortResponse>(_EdgeGetEffortResponse_QNAME, EdgeGetEffortResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ArealDetectorGetIDListResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "ArealDetector_getIDListResponse")
    public JAXBElement<ArealDetectorGetIDListResponse> createArealDetectorGetIDListResponse(ArealDetectorGetIDListResponse value) {
        return new JAXBElement<ArealDetectorGetIDListResponse>(_ArealDetectorGetIDListResponse_QNAME, ArealDetectorGetIDListResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeSetColorResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_setColorResponse")
    public JAXBElement<VehicletypeSetColorResponse> createVehicletypeSetColorResponse(VehicletypeSetColorResponse value) {
        return new JAXBElement<VehicletypeSetColorResponse>(_VehicletypeSetColorResponse_QNAME, VehicletypeSetColorResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetArrivedNumberResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getArrivedNumberResponse")
    public JAXBElement<SimulationGetArrivedNumberResponse> createSimulationGetArrivedNumberResponse(SimulationGetArrivedNumberResponse value) {
        return new JAXBElement<SimulationGetArrivedNumberResponse>(_SimulationGetArrivedNumberResponse_QNAME, SimulationGetArrivedNumberResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetDisallowed }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getDisallowed")
    public JAXBElement<LaneGetDisallowed> createLaneGetDisallowed(LaneGetDisallowed value) {
        return new JAXBElement<LaneGetDisallowed>(_LaneGetDisallowed_QNAME, LaneGetDisallowed.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetStartingTeleportNumber }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getStartingTeleportNumber")
    public JAXBElement<SimulationGetStartingTeleportNumber> createSimulationGetStartingTeleportNumber(SimulationGetStartingTeleportNumber value) {
        return new JAXBElement<SimulationGetStartingTeleportNumber>(_SimulationGetStartingTeleportNumber_QNAME, SimulationGetStartingTeleportNumber.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetAllowedResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getAllowedResponse")
    public JAXBElement<LaneGetAllowedResponse> createLaneGetAllowedResponse(LaneGetAllowedResponse value) {
        return new JAXBElement<LaneGetAllowedResponse>(_LaneGetAllowedResponse_QNAME, LaneGetAllowedResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleMoveTo }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_moveTo")
    public JAXBElement<VehicleMoveTo> createVehicleMoveTo(VehicleMoveTo value) {
        return new JAXBElement<VehicleMoveTo>(_VehicleMoveTo_QNAME, VehicleMoveTo.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetWidthResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getWidthResponse")
    public JAXBElement<VehicleGetWidthResponse> createVehicleGetWidthResponse(VehicleGetWidthResponse value) {
        return new JAXBElement<VehicleGetWidthResponse>(_VehicleGetWidthResponse_QNAME, VehicleGetWidthResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EdgeAdaptTraveltimeResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Edge_adaptTraveltimeResponse")
    public JAXBElement<EdgeAdaptTraveltimeResponse> createEdgeAdaptTraveltimeResponse(EdgeAdaptTraveltimeResponse value) {
        return new JAXBElement<EdgeAdaptTraveltimeResponse>(_EdgeAdaptTraveltimeResponse_QNAME, EdgeAdaptTraveltimeResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeGetShapeClass }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_getShapeClass")
    public JAXBElement<VehicletypeGetShapeClass> createVehicletypeGetShapeClass(VehicletypeGetShapeClass value) {
        return new JAXBElement<VehicletypeGetShapeClass>(_VehicletypeGetShapeClass_QNAME, VehicletypeGetShapeClass.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link InductionloopGetLastStepOccupancy }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Inductionloop_getLastStepOccupancy")
    public JAXBElement<InductionloopGetLastStepOccupancy> createInductionloopGetLastStepOccupancy(InductionloopGetLastStepOccupancy value) {
        return new JAXBElement<InductionloopGetLastStepOccupancy>(_InductionloopGetLastStepOccupancy_QNAME, InductionloopGetLastStepOccupancy.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleRerouteEffortResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_rerouteEffortResponse")
    public JAXBElement<VehicleRerouteEffortResponse> createVehicleRerouteEffortResponse(VehicleRerouteEffortResponse value) {
        return new JAXBElement<VehicleRerouteEffortResponse>(_VehicleRerouteEffortResponse_QNAME, VehicleRerouteEffortResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetDrivingDistance }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getDrivingDistance")
    public JAXBElement<VehicleGetDrivingDistance> createVehicleGetDrivingDistance(VehicleGetDrivingDistance value) {
        return new JAXBElement<VehicleGetDrivingDistance>(_VehicleGetDrivingDistance_QNAME, VehicleGetDrivingDistance.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link InductionloopGetIDList }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Inductionloop_getIDList")
    public JAXBElement<InductionloopGetIDList> createInductionloopGetIDList(InductionloopGetIDList value) {
        return new JAXBElement<InductionloopGetIDList>(_InductionloopGetIDList_QNAME, InductionloopGetIDList.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeSetDecel }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_setDecel")
    public JAXBElement<VehicletypeSetDecel> createVehicletypeSetDecel(VehicletypeSetDecel value) {
        return new JAXBElement<VehicletypeSetDecel>(_VehicletypeSetDecel_QNAME, VehicletypeSetDecel.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetWaitingTimeResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getWaitingTimeResponse")
    public JAXBElement<VehicleGetWaitingTimeResponse> createVehicleGetWaitingTimeResponse(VehicleGetWaitingTimeResponse value) {
        return new JAXBElement<VehicleGetWaitingTimeResponse>(_VehicleGetWaitingTimeResponse_QNAME, VehicleGetWaitingTimeResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetShapeClassResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getShapeClassResponse")
    public JAXBElement<VehicleGetShapeClassResponse> createVehicleGetShapeClassResponse(VehicleGetShapeClassResponse value) {
        return new JAXBElement<VehicleGetShapeClassResponse>(_VehicleGetShapeClassResponse_QNAME, VehicleGetShapeClassResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetHCEmissionResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getHCEmissionResponse")
    public JAXBElement<LaneGetHCEmissionResponse> createLaneGetHCEmissionResponse(LaneGetHCEmissionResponse value) {
        return new JAXBElement<LaneGetHCEmissionResponse>(_LaneGetHCEmissionResponse_QNAME, LaneGetHCEmissionResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeSetColor }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_setColor")
    public JAXBElement<VehicletypeSetColor> createVehicletypeSetColor(VehicletypeSetColor value) {
        return new JAXBElement<VehicletypeSetColor>(_VehicletypeSetColor_QNAME, VehicletypeSetColor.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSlowDownResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_slowDownResponse")
    public JAXBElement<VehicleSlowDownResponse> createVehicleSlowDownResponse(VehicleSlowDownResponse value) {
        return new JAXBElement<VehicleSlowDownResponse>(_VehicleSlowDownResponse_QNAME, VehicleSlowDownResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ArealDetectorGetIDCount }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "ArealDetector_getIDCount")
    public JAXBElement<ArealDetectorGetIDCount> createArealDetectorGetIDCount(ArealDetectorGetIDCount value) {
        return new JAXBElement<ArealDetectorGetIDCount>(_ArealDetectorGetIDCount_QNAME, ArealDetectorGetIDCount.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link InductionloopGetPosition }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Inductionloop_getPosition")
    public JAXBElement<InductionloopGetPosition> createInductionloopGetPosition(InductionloopGetPosition value) {
        return new JAXBElement<InductionloopGetPosition>(_InductionloopGetPosition_QNAME, InductionloopGetPosition.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetDrivingDistanceResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getDrivingDistanceResponse")
    public JAXBElement<VehicleGetDrivingDistanceResponse> createVehicleGetDrivingDistanceResponse(VehicleGetDrivingDistanceResponse value) {
        return new JAXBElement<VehicleGetDrivingDistanceResponse>(_VehicleGetDrivingDistanceResponse_QNAME, VehicleGetDrivingDistanceResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetMinExpectedNumberResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getMinExpectedNumberResponse")
    public JAXBElement<SimulationGetMinExpectedNumberResponse> createSimulationGetMinExpectedNumberResponse(SimulationGetMinExpectedNumberResponse value) {
        return new JAXBElement<SimulationGetMinExpectedNumberResponse>(_SimulationGetMinExpectedNumberResponse_QNAME, SimulationGetMinExpectedNumberResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetAngleResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getAngleResponse")
    public JAXBElement<VehicleGetAngleResponse> createVehicleGetAngleResponse(VehicleGetAngleResponse value) {
        return new JAXBElement<VehicleGetAngleResponse>(_VehicleGetAngleResponse_QNAME, VehicleGetAngleResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeGetMaxSpeedResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_getMaxSpeedResponse")
    public JAXBElement<VehicletypeGetMaxSpeedResponse> createVehicletypeGetMaxSpeedResponse(VehicletypeGetMaxSpeedResponse value) {
        return new JAXBElement<VehicletypeGetMaxSpeedResponse>(_VehicletypeGetMaxSpeedResponse_QNAME, VehicletypeGetMaxSpeedResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetShapeClass }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getShapeClass")
    public JAXBElement<VehicleGetShapeClass> createVehicleGetShapeClass(VehicleGetShapeClass value) {
        return new JAXBElement<VehicleGetShapeClass>(_VehicleGetShapeClass_QNAME, VehicleGetShapeClass.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetEffortResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getEffortResponse")
    public JAXBElement<VehicleGetEffortResponse> createVehicleGetEffortResponse(VehicleGetEffortResponse value) {
        return new JAXBElement<VehicleGetEffortResponse>(_VehicleGetEffortResponse_QNAME, VehicleGetEffortResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetFuelConsumptionResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getFuelConsumptionResponse")
    public JAXBElement<VehicleGetFuelConsumptionResponse> createVehicleGetFuelConsumptionResponse(VehicleGetFuelConsumptionResponse value) {
        return new JAXBElement<VehicleGetFuelConsumptionResponse>(_VehicleGetFuelConsumptionResponse_QNAME, VehicleGetFuelConsumptionResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link GUISetSchema }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "GUI_setSchema")
    public JAXBElement<GUISetSchema> createGUISetSchema(GUISetSchema value) {
        return new JAXBElement<GUISetSchema>(_GUISetSchema_QNAME, GUISetSchema.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link InductionloopGetIDListResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Inductionloop_getIDListResponse")
    public JAXBElement<InductionloopGetIDListResponse> createInductionloopGetIDListResponse(InductionloopGetIDListResponse value) {
        return new JAXBElement<InductionloopGetIDListResponse>(_InductionloopGetIDListResponse_QNAME, InductionloopGetIDListResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeGetIDCount }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_getIDCount")
    public JAXBElement<VehicletypeGetIDCount> createVehicletypeGetIDCount(VehicletypeGetIDCount value) {
        return new JAXBElement<VehicletypeGetIDCount>(_VehicletypeGetIDCount_QNAME, VehicletypeGetIDCount.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetStopStartingVehiclesNumber }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getStopStartingVehiclesNumber")
    public JAXBElement<SimulationGetStopStartingVehiclesNumber> createSimulationGetStopStartingVehiclesNumber(SimulationGetStopStartingVehiclesNumber value) {
        return new JAXBElement<SimulationGetStopStartingVehiclesNumber>(_SimulationGetStopStartingVehiclesNumber_QNAME, SimulationGetStopStartingVehiclesNumber.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeSetMaxSpeedResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_setMaxSpeedResponse")
    public JAXBElement<VehicletypeSetMaxSpeedResponse> createVehicletypeSetMaxSpeedResponse(VehicletypeSetMaxSpeedResponse value) {
        return new JAXBElement<VehicletypeSetMaxSpeedResponse>(_VehicletypeSetMaxSpeedResponse_QNAME, VehicletypeSetMaxSpeedResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetArrivedNumber }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getArrivedNumber")
    public JAXBElement<SimulationGetArrivedNumber> createSimulationGetArrivedNumber(SimulationGetArrivedNumber value) {
        return new JAXBElement<SimulationGetArrivedNumber>(_SimulationGetArrivedNumber_QNAME, SimulationGetArrivedNumber.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TrafficlightsGetControlledLinksResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Trafficlights_getControlledLinksResponse")
    public JAXBElement<TrafficlightsGetControlledLinksResponse> createTrafficlightsGetControlledLinksResponse(TrafficlightsGetControlledLinksResponse value) {
        return new JAXBElement<TrafficlightsGetControlledLinksResponse>(_TrafficlightsGetControlledLinksResponse_QNAME, TrafficlightsGetControlledLinksResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetMinGapResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setMinGapResponse")
    public JAXBElement<VehicleSetMinGapResponse> createVehicleSetMinGapResponse(VehicleSetMinGapResponse value) {
        return new JAXBElement<VehicleSetMinGapResponse>(_VehicleSetMinGapResponse_QNAME, VehicleSetMinGapResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link GUITrackVehicle }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "GUI_trackVehicle")
    public JAXBElement<GUITrackVehicle> createGUITrackVehicle(GUITrackVehicle value) {
        return new JAXBElement<GUITrackVehicle>(_GUITrackVehicle_QNAME, GUITrackVehicle.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetLength }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getLength")
    public JAXBElement<VehicleGetLength> createVehicleGetLength(VehicleGetLength value) {
        return new JAXBElement<VehicleGetLength>(_VehicleGetLength_QNAME, VehicleGetLength.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetWidth }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getWidth")
    public JAXBElement<VehicleGetWidth> createVehicleGetWidth(VehicleGetWidth value) {
        return new JAXBElement<VehicleGetWidth>(_VehicleGetWidth_QNAME, VehicleGetWidth.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetDistance2DResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getDistance2DResponse")
    public JAXBElement<SimulationGetDistance2DResponse> createSimulationGetDistance2DResponse(SimulationGetDistance2DResponse value) {
        return new JAXBElement<SimulationGetDistance2DResponse>(_SimulationGetDistance2DResponse_QNAME, SimulationGetDistance2DResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetWaitingTimeResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getWaitingTimeResponse")
    public JAXBElement<LaneGetWaitingTimeResponse> createLaneGetWaitingTimeResponse(LaneGetWaitingTimeResponse value) {
        return new JAXBElement<LaneGetWaitingTimeResponse>(_LaneGetWaitingTimeResponse_QNAME, LaneGetWaitingTimeResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PoiSetType }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Poi_setType")
    public JAXBElement<PoiSetType> createPoiSetType(PoiSetType value) {
        return new JAXBElement<PoiSetType>(_PoiSetType_QNAME, PoiSetType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TrafficlightsGetPhaseDurationResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Trafficlights_getPhaseDurationResponse")
    public JAXBElement<TrafficlightsGetPhaseDurationResponse> createTrafficlightsGetPhaseDurationResponse(TrafficlightsGetPhaseDurationResponse value) {
        return new JAXBElement<TrafficlightsGetPhaseDurationResponse>(_TrafficlightsGetPhaseDurationResponse_QNAME, TrafficlightsGetPhaseDurationResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetVehicleClassResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setVehicleClassResponse")
    public JAXBElement<VehicleSetVehicleClassResponse> createVehicleSetVehicleClassResponse(VehicleSetVehicleClassResponse value) {
        return new JAXBElement<VehicleSetVehicleClassResponse>(_VehicleSetVehicleClassResponse_QNAME, VehicleSetVehicleClassResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetEffort }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setEffort")
    public JAXBElement<VehicleSetEffort> createVehicleSetEffort(VehicleSetEffort value) {
        return new JAXBElement<VehicleSetEffort>(_VehicleSetEffort_QNAME, VehicleSetEffort.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TrafficlightsSetPhase }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Trafficlights_setPhase")
    public JAXBElement<TrafficlightsSetPhase> createTrafficlightsSetPhase(TrafficlightsSetPhase value) {
        return new JAXBElement<TrafficlightsSetPhase>(_TrafficlightsSetPhase_QNAME, TrafficlightsSetPhase.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeGetWidth }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_getWidth")
    public JAXBElement<VehicletypeGetWidth> createVehicletypeGetWidth(VehicletypeGetWidth value) {
        return new JAXBElement<VehicletypeGetWidth>(_VehicletypeGetWidth_QNAME, VehicletypeGetWidth.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleRerouteTraveltimeResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_rerouteTraveltimeResponse")
    public JAXBElement<VehicleRerouteTraveltimeResponse> createVehicleRerouteTraveltimeResponse(VehicleRerouteTraveltimeResponse value) {
        return new JAXBElement<VehicleRerouteTraveltimeResponse>(_VehicleRerouteTraveltimeResponse_QNAME, VehicleRerouteTraveltimeResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link InductionloopGetVehicleData }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Inductionloop_getVehicleData")
    public JAXBElement<InductionloopGetVehicleData> createInductionloopGetVehicleData(InductionloopGetVehicleData value) {
        return new JAXBElement<InductionloopGetVehicleData>(_InductionloopGetVehicleData_QNAME, InductionloopGetVehicleData.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeGetAccel }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_getAccel")
    public JAXBElement<VehicletypeGetAccel> createVehicletypeGetAccel(VehicletypeGetAccel value) {
        return new JAXBElement<VehicletypeGetAccel>(_VehicletypeGetAccel_QNAME, VehicletypeGetAccel.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link InductionloopGetPositionResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Inductionloop_getPositionResponse")
    public JAXBElement<InductionloopGetPositionResponse> createInductionloopGetPositionResponse(InductionloopGetPositionResponse value) {
        return new JAXBElement<InductionloopGetPositionResponse>(_InductionloopGetPositionResponse_QNAME, InductionloopGetPositionResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TrafficlightsGetCompleteRedYellowGreenDefinition }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Trafficlights_getCompleteRedYellowGreenDefinition")
    public JAXBElement<TrafficlightsGetCompleteRedYellowGreenDefinition> createTrafficlightsGetCompleteRedYellowGreenDefinition(TrafficlightsGetCompleteRedYellowGreenDefinition value) {
        return new JAXBElement<TrafficlightsGetCompleteRedYellowGreenDefinition>(_TrafficlightsGetCompleteRedYellowGreenDefinition_QNAME, TrafficlightsGetCompleteRedYellowGreenDefinition.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetStop }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setStop")
    public JAXBElement<VehicleSetStop> createVehicleSetStop(VehicleSetStop value) {
        return new JAXBElement<VehicleSetStop>(_VehicleSetStop_QNAME, VehicleSetStop.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TXTOutputResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "TXT_outputResponse")
    public JAXBElement<TXTOutputResponse> createTXTOutputResponse(TXTOutputResponse value) {
        return new JAXBElement<TXTOutputResponse>(_TXTOutputResponse_QNAME, TXTOutputResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetWaitingTime }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getWaitingTime")
    public JAXBElement<LaneGetWaitingTime> createLaneGetWaitingTime(LaneGetWaitingTime value) {
        return new JAXBElement<LaneGetWaitingTime>(_LaneGetWaitingTime_QNAME, LaneGetWaitingTime.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetSignalsResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getSignalsResponse")
    public JAXBElement<VehicleGetSignalsResponse> createVehicleGetSignalsResponse(VehicleGetSignalsResponse value) {
        return new JAXBElement<VehicleGetSignalsResponse>(_VehicleGetSignalsResponse_QNAME, VehicleGetSignalsResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link InductionloopGetLastStepVehicleIDs }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Inductionloop_getLastStepVehicleIDs")
    public JAXBElement<InductionloopGetLastStepVehicleIDs> createInductionloopGetLastStepVehicleIDs(InductionloopGetLastStepVehicleIDs value) {
        return new JAXBElement<InductionloopGetLastStepVehicleIDs>(_InductionloopGetLastStepVehicleIDs_QNAME, InductionloopGetLastStepVehicleIDs.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link MultientryexitGetLastStepHaltingNumber }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Multientryexit_getLastStepHaltingNumber")
    public JAXBElement<MultientryexitGetLastStepHaltingNumber> createMultientryexitGetLastStepHaltingNumber(MultientryexitGetLastStepHaltingNumber value) {
        return new JAXBElement<MultientryexitGetLastStepHaltingNumber>(_MultientryexitGetLastStepHaltingNumber_QNAME, MultientryexitGetLastStepHaltingNumber.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetDeltaTResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getDeltaTResponse")
    public JAXBElement<SimulationGetDeltaTResponse> createSimulationGetDeltaTResponse(SimulationGetDeltaTResponse value) {
        return new JAXBElement<SimulationGetDeltaTResponse>(_SimulationGetDeltaTResponse_QNAME, SimulationGetDeltaTResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PolygonSetColor }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Polygon_setColor")
    public JAXBElement<PolygonSetColor> createPolygonSetColor(PolygonSetColor value) {
        return new JAXBElement<PolygonSetColor>(_PolygonSetColor_QNAME, PolygonSetColor.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LastActionTime }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "LastActionTime")
    public JAXBElement<LastActionTime> createLastActionTime(LastActionTime value) {
        return new JAXBElement<LastActionTime>(_LastActionTime_QNAME, LastActionTime.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EdgeGetIDCountResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Edge_getIDCountResponse")
    public JAXBElement<EdgeGetIDCountResponse> createEdgeGetIDCountResponse(EdgeGetIDCountResponse value) {
        return new JAXBElement<EdgeGetIDCountResponse>(_EdgeGetIDCountResponse_QNAME, EdgeGetIDCountResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetAdaptedTraveltimeResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getAdaptedTraveltimeResponse")
    public JAXBElement<VehicleGetAdaptedTraveltimeResponse> createVehicleGetAdaptedTraveltimeResponse(VehicleGetAdaptedTraveltimeResponse value) {
        return new JAXBElement<VehicleGetAdaptedTraveltimeResponse>(_VehicleGetAdaptedTraveltimeResponse_QNAME, VehicleGetAdaptedTraveltimeResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TrafficlightsSetProgram }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Trafficlights_setProgram")
    public JAXBElement<TrafficlightsSetProgram> createTrafficlightsSetProgram(TrafficlightsSetProgram value) {
        return new JAXBElement<TrafficlightsSetProgram>(_TrafficlightsSetProgram_QNAME, TrafficlightsSetProgram.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetPMxEmission }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getPMxEmission")
    public JAXBElement<VehicleGetPMxEmission> createVehicleGetPMxEmission(VehicleGetPMxEmission value) {
        return new JAXBElement<VehicleGetPMxEmission>(_VehicleGetPMxEmission_QNAME, VehicleGetPMxEmission.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TrafficlightsGetIDCountResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Trafficlights_getIDCountResponse")
    public JAXBElement<TrafficlightsGetIDCountResponse> createTrafficlightsGetIDCountResponse(TrafficlightsGetIDCountResponse value) {
        return new JAXBElement<TrafficlightsGetIDCountResponse>(_TrafficlightsGetIDCountResponse_QNAME, TrafficlightsGetIDCountResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link StopResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "stopResponse")
    public JAXBElement<StopResponse> createStopResponse(StopResponse value) {
        return new JAXBElement<StopResponse>(_StopResponse_QNAME, StopResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SetConfigResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "setConfigResponse")
    public JAXBElement<SetConfigResponse> createSetConfigResponse(SetConfigResponse value) {
        return new JAXBElement<SetConfigResponse>(_SetConfigResponse_QNAME, SetConfigResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetImperfectionResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setImperfectionResponse")
    public JAXBElement<VehicleSetImperfectionResponse> createVehicleSetImperfectionResponse(VehicleSetImperfectionResponse value) {
        return new JAXBElement<VehicleSetImperfectionResponse>(_VehicleSetImperfectionResponse_QNAME, VehicleSetImperfectionResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleChangeTarget }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_changeTarget")
    public JAXBElement<VehicleChangeTarget> createVehicleChangeTarget(VehicleChangeTarget value) {
        return new JAXBElement<VehicleChangeTarget>(_VehicleChangeTarget_QNAME, VehicleChangeTarget.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetMinGap }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getMinGap")
    public JAXBElement<VehicleGetMinGap> createVehicleGetMinGap(VehicleGetMinGap value) {
        return new JAXBElement<VehicleGetMinGap>(_VehicleGetMinGap_QNAME, VehicleGetMinGap.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeGetEmissionClass }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_getEmissionClass")
    public JAXBElement<VehicletypeGetEmissionClass> createVehicletypeGetEmissionClass(VehicletypeGetEmissionClass value) {
        return new JAXBElement<VehicletypeGetEmissionClass>(_VehicletypeGetEmissionClass_QNAME, VehicletypeGetEmissionClass.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EdgeGetLastStepMeanSpeed }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Edge_getLastStepMeanSpeed")
    public JAXBElement<EdgeGetLastStepMeanSpeed> createEdgeGetLastStepMeanSpeed(EdgeGetLastStepMeanSpeed value) {
        return new JAXBElement<EdgeGetLastStepMeanSpeed>(_EdgeGetLastStepMeanSpeed_QNAME, EdgeGetLastStepMeanSpeed.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link MultientryexitGetLastStepVehicleIDs }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Multientryexit_getLastStepVehicleIDs")
    public JAXBElement<MultientryexitGetLastStepVehicleIDs> createMultientryexitGetLastStepVehicleIDs(MultientryexitGetLastStepVehicleIDs value) {
        return new JAXBElement<MultientryexitGetLastStepVehicleIDs>(_MultientryexitGetLastStepVehicleIDs_QNAME, MultientryexitGetLastStepVehicleIDs.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneSetLength }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_setLength")
    public JAXBElement<LaneSetLength> createLaneSetLength(LaneSetLength value) {
        return new JAXBElement<LaneSetLength>(_LaneSetLength_QNAME, LaneSetLength.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetSpeed }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getSpeed")
    public JAXBElement<VehicleGetSpeed> createVehicleGetSpeed(VehicleGetSpeed value) {
        return new JAXBElement<VehicleGetSpeed>(_VehicleGetSpeed_QNAME, VehicleGetSpeed.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeGetColorResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_getColorResponse")
    public JAXBElement<VehicletypeGetColorResponse> createVehicletypeGetColorResponse(VehicletypeGetColorResponse value) {
        return new JAXBElement<VehicletypeGetColorResponse>(_VehicletypeGetColorResponse_QNAME, VehicletypeGetColorResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link RouteGetIDList }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Route_getIDList")
    public JAXBElement<RouteGetIDList> createRouteGetIDList(RouteGetIDList value) {
        return new JAXBElement<RouteGetIDList>(_RouteGetIDList_QNAME, RouteGetIDList.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EdgeGetPMxEmission }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Edge_getPMxEmission")
    public JAXBElement<EdgeGetPMxEmission> createEdgeGetPMxEmission(EdgeGetPMxEmission value) {
        return new JAXBElement<EdgeGetPMxEmission>(_EdgeGetPMxEmission_QNAME, EdgeGetPMxEmission.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleMoveToVTD }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_moveToVTD")
    public JAXBElement<VehicleMoveToVTD> createVehicleMoveToVTD(VehicleMoveToVTD value) {
        return new JAXBElement<VehicleMoveToVTD>(_VehicleMoveToVTD_QNAME, VehicleMoveToVTD.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetStopEndingVehiclesIDList }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getStopEndingVehiclesIDList")
    public JAXBElement<SimulationGetStopEndingVehiclesIDList> createSimulationGetStopEndingVehiclesIDList(SimulationGetStopEndingVehiclesIDList value) {
        return new JAXBElement<SimulationGetStopEndingVehiclesIDList>(_SimulationGetStopEndingVehiclesIDList_QNAME, SimulationGetStopEndingVehiclesIDList.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetDecelResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getDecelResponse")
    public JAXBElement<VehicleGetDecelResponse> createVehicleGetDecelResponse(VehicleGetDecelResponse value) {
        return new JAXBElement<VehicleGetDecelResponse>(_VehicleGetDecelResponse_QNAME, VehicleGetDecelResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetLanePositionResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getLanePositionResponse")
    public JAXBElement<VehicleGetLanePositionResponse> createVehicleGetLanePositionResponse(VehicleGetLanePositionResponse value) {
        return new JAXBElement<VehicleGetLanePositionResponse>(_VehicleGetLanePositionResponse_QNAME, VehicleGetLanePositionResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetTau }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getTau")
    public JAXBElement<VehicleGetTau> createVehicleGetTau(VehicleGetTau value) {
        return new JAXBElement<VehicleGetTau>(_VehicleGetTau_QNAME, VehicleGetTau.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetCO2EmissionResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getCO2EmissionResponse")
    public JAXBElement<LaneGetCO2EmissionResponse> createLaneGetCO2EmissionResponse(LaneGetCO2EmissionResponse value) {
        return new JAXBElement<LaneGetCO2EmissionResponse>(_LaneGetCO2EmissionResponse_QNAME, LaneGetCO2EmissionResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleMoveToResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_moveToResponse")
    public JAXBElement<VehicleMoveToResponse> createVehicleMoveToResponse(VehicleMoveToResponse value) {
        return new JAXBElement<VehicleMoveToResponse>(_VehicleMoveToResponse_QNAME, VehicleMoveToResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link MultientryexitGetLastStepHaltingNumberResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Multientryexit_getLastStepHaltingNumberResponse")
    public JAXBElement<MultientryexitGetLastStepHaltingNumberResponse> createMultientryexitGetLastStepHaltingNumberResponse(MultientryexitGetLastStepHaltingNumberResponse value) {
        return new JAXBElement<MultientryexitGetLastStepHaltingNumberResponse>(_MultientryexitGetLastStepHaltingNumberResponse_QNAME, MultientryexitGetLastStepHaltingNumberResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeGetImperfection }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_getImperfection")
    public JAXBElement<VehicletypeGetImperfection> createVehicletypeGetImperfection(VehicletypeGetImperfection value) {
        return new JAXBElement<VehicletypeGetImperfection>(_VehicletypeGetImperfection_QNAME, VehicletypeGetImperfection.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetStartingTeleportIDListResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getStartingTeleportIDListResponse")
    public JAXBElement<SimulationGetStartingTeleportIDListResponse> createSimulationGetStartingTeleportIDListResponse(SimulationGetStartingTeleportIDListResponse value) {
        return new JAXBElement<SimulationGetStartingTeleportIDListResponse>(_SimulationGetStartingTeleportIDListResponse_QNAME, SimulationGetStartingTeleportIDListResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetShapeClass }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setShapeClass")
    public JAXBElement<VehicleSetShapeClass> createVehicleSetShapeClass(VehicleSetShapeClass value) {
        return new JAXBElement<VehicleSetShapeClass>(_VehicleSetShapeClass_QNAME, VehicleSetShapeClass.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EdgeGetIDCount }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Edge_getIDCount")
    public JAXBElement<EdgeGetIDCount> createEdgeGetIDCount(EdgeGetIDCount value) {
        return new JAXBElement<EdgeGetIDCount>(_EdgeGetIDCount_QNAME, EdgeGetIDCount.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeGetDecelResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_getDecelResponse")
    public JAXBElement<VehicletypeGetDecelResponse> createVehicletypeGetDecelResponse(VehicletypeGetDecelResponse value) {
        return new JAXBElement<VehicletypeGetDecelResponse>(_VehicletypeGetDecelResponse_QNAME, VehicletypeGetDecelResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeGetWidthResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_getWidthResponse")
    public JAXBElement<VehicletypeGetWidthResponse> createVehicletypeGetWidthResponse(VehicletypeGetWidthResponse value) {
        return new JAXBElement<VehicletypeGetWidthResponse>(_VehicletypeGetWidthResponse_QNAME, VehicletypeGetWidthResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneSetDisallowedResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_setDisallowedResponse")
    public JAXBElement<LaneSetDisallowedResponse> createLaneSetDisallowedResponse(LaneSetDisallowedResponse value) {
        return new JAXBElement<LaneSetDisallowedResponse>(_LaneSetDisallowedResponse_QNAME, LaneSetDisallowedResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetSpeedFactor }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setSpeedFactor")
    public JAXBElement<VehicleSetSpeedFactor> createVehicleSetSpeedFactor(VehicleSetSpeedFactor value) {
        return new JAXBElement<VehicleSetSpeedFactor>(_VehicleSetSpeedFactor_QNAME, VehicleSetSpeedFactor.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetHCEmission }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getHCEmission")
    public JAXBElement<VehicleGetHCEmission> createVehicleGetHCEmission(VehicleGetHCEmission value) {
        return new JAXBElement<VehicleGetHCEmission>(_VehicleGetHCEmission_QNAME, VehicleGetHCEmission.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetPersonNumber }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getPersonNumber")
    public JAXBElement<VehicleGetPersonNumber> createVehicleGetPersonNumber(VehicleGetPersonNumber value) {
        return new JAXBElement<VehicleGetPersonNumber>(_VehicleGetPersonNumber_QNAME, VehicleGetPersonNumber.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PoiAdd }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Poi_add")
    public JAXBElement<PoiAdd> createPoiAdd(PoiAdd value) {
        return new JAXBElement<PoiAdd>(_PoiAdd_QNAME, PoiAdd.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetEffortResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setEffortResponse")
    public JAXBElement<VehicleSetEffortResponse> createVehicleSetEffortResponse(VehicleSetEffortResponse value) {
        return new JAXBElement<VehicleSetEffortResponse>(_VehicleSetEffortResponse_QNAME, VehicleSetEffortResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetStopStartingVehiclesNumberResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getStopStartingVehiclesNumberResponse")
    public JAXBElement<SimulationGetStopStartingVehiclesNumberResponse> createSimulationGetStopStartingVehiclesNumberResponse(SimulationGetStopStartingVehiclesNumberResponse value) {
        return new JAXBElement<SimulationGetStopStartingVehiclesNumberResponse>(_SimulationGetStopStartingVehiclesNumberResponse_QNAME, SimulationGetStopStartingVehiclesNumberResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetCO2EmissionResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getCO2EmissionResponse")
    public JAXBElement<VehicleGetCO2EmissionResponse> createVehicleGetCO2EmissionResponse(VehicleGetCO2EmissionResponse value) {
        return new JAXBElement<VehicleGetCO2EmissionResponse>(_VehicleGetCO2EmissionResponse_QNAME, VehicleGetCO2EmissionResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetNOxEmission }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getNOxEmission")
    public JAXBElement<LaneGetNOxEmission> createLaneGetNOxEmission(LaneGetNOxEmission value) {
        return new JAXBElement<LaneGetNOxEmission>(_LaneGetNOxEmission_QNAME, LaneGetNOxEmission.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeSetVehicleClassResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_setVehicleClassResponse")
    public JAXBElement<VehicletypeSetVehicleClassResponse> createVehicletypeSetVehicleClassResponse(VehicletypeSetVehicleClassResponse value) {
        return new JAXBElement<VehicletypeSetVehicleClassResponse>(_VehicletypeSetVehicleClassResponse_QNAME, VehicletypeSetVehicleClassResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link RouteGetEdgesResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Route_getEdgesResponse")
    public JAXBElement<RouteGetEdgesResponse> createRouteGetEdgesResponse(RouteGetEdgesResponse value) {
        return new JAXBElement<RouteGetEdgesResponse>(_RouteGetEdgesResponse_QNAME, RouteGetEdgesResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetEmissionClassResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getEmissionClassResponse")
    public JAXBElement<VehicleGetEmissionClassResponse> createVehicleGetEmissionClassResponse(VehicleGetEmissionClassResponse value) {
        return new JAXBElement<VehicleGetEmissionClassResponse>(_VehicleGetEmissionClassResponse_QNAME, VehicleGetEmissionClassResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link InductionloopGetLaneIDResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Inductionloop_getLaneIDResponse")
    public JAXBElement<InductionloopGetLaneIDResponse> createInductionloopGetLaneIDResponse(InductionloopGetLaneIDResponse value) {
        return new JAXBElement<InductionloopGetLaneIDResponse>(_InductionloopGetLaneIDResponse_QNAME, InductionloopGetLaneIDResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneSetMaxSpeed }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_setMaxSpeed")
    public JAXBElement<LaneSetMaxSpeed> createLaneSetMaxSpeed(LaneSetMaxSpeed value) {
        return new JAXBElement<LaneSetMaxSpeed>(_LaneSetMaxSpeed_QNAME, LaneSetMaxSpeed.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link GUIGetSchemaResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "GUI_getSchemaResponse")
    public JAXBElement<GUIGetSchemaResponse> createGUIGetSchemaResponse(GUIGetSchemaResponse value) {
        return new JAXBElement<GUIGetSchemaResponse>(_GUIGetSchemaResponse_QNAME, GUIGetSchemaResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PoiGetIDList }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Poi_getIDList")
    public JAXBElement<PoiGetIDList> createPoiGetIDList(PoiGetIDList value) {
        return new JAXBElement<PoiGetIDList>(_PoiGetIDList_QNAME, PoiGetIDList.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TrafficlightsGetIDList }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Trafficlights_getIDList")
    public JAXBElement<TrafficlightsGetIDList> createTrafficlightsGetIDList(TrafficlightsGetIDList value) {
        return new JAXBElement<TrafficlightsGetIDList>(_TrafficlightsGetIDList_QNAME, TrafficlightsGetIDList.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetStopEndingVehiclesNumber }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getStopEndingVehiclesNumber")
    public JAXBElement<SimulationGetStopEndingVehiclesNumber> createSimulationGetStopEndingVehiclesNumber(SimulationGetStopEndingVehiclesNumber value) {
        return new JAXBElement<SimulationGetStopEndingVehiclesNumber>(_SimulationGetStopEndingVehiclesNumber_QNAME, SimulationGetStopEndingVehiclesNumber.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EdgeGetIDList }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Edge_getIDList")
    public JAXBElement<EdgeGetIDList> createEdgeGetIDList(EdgeGetIDList value) {
        return new JAXBElement<EdgeGetIDList>(_EdgeGetIDList_QNAME, EdgeGetIDList.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PolygonRemoveResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Polygon_removeResponse")
    public JAXBElement<PolygonRemoveResponse> createPolygonRemoveResponse(PolygonRemoveResponse value) {
        return new JAXBElement<PolygonRemoveResponse>(_PolygonRemoveResponse_QNAME, PolygonRemoveResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link InductionloopGetLastStepVehicleNumber }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Inductionloop_getLastStepVehicleNumber")
    public JAXBElement<InductionloopGetLastStepVehicleNumber> createInductionloopGetLastStepVehicleNumber(InductionloopGetLastStepVehicleNumber value) {
        return new JAXBElement<InductionloopGetLastStepVehicleNumber>(_InductionloopGetLastStepVehicleNumber_QNAME, InductionloopGetLastStepVehicleNumber.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetColorResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setColorResponse")
    public JAXBElement<VehicleSetColorResponse> createVehicleSetColorResponse(VehicleSetColorResponse value) {
        return new JAXBElement<VehicleSetColorResponse>(_VehicleSetColorResponse_QNAME, VehicleSetColorResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetColor }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getColor")
    public JAXBElement<VehicleGetColor> createVehicleGetColor(VehicleGetColor value) {
        return new JAXBElement<VehicleGetColor>(_VehicleGetColor_QNAME, VehicleGetColor.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleChangeTargetResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_changeTargetResponse")
    public JAXBElement<VehicleChangeTargetResponse> createVehicleChangeTargetResponse(VehicleChangeTargetResponse value) {
        return new JAXBElement<VehicleChangeTargetResponse>(_VehicleChangeTargetResponse_QNAME, VehicleChangeTargetResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleAddResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_addResponse")
    public JAXBElement<VehicleAddResponse> createVehicleAddResponse(VehicleAddResponse value) {
        return new JAXBElement<VehicleAddResponse>(_VehicleAddResponse_QNAME, VehicleAddResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetDepartedIDListResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getDepartedIDListResponse")
    public JAXBElement<SimulationGetDepartedIDListResponse> createSimulationGetDepartedIDListResponse(SimulationGetDepartedIDListResponse value) {
        return new JAXBElement<SimulationGetDepartedIDListResponse>(_SimulationGetDepartedIDListResponse_QNAME, SimulationGetDepartedIDListResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EdgeGetLastStepLengthResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Edge_getLastStepLengthResponse")
    public JAXBElement<EdgeGetLastStepLengthResponse> createEdgeGetLastStepLengthResponse(EdgeGetLastStepLengthResponse value) {
        return new JAXBElement<EdgeGetLastStepLengthResponse>(_EdgeGetLastStepLengthResponse_QNAME, EdgeGetLastStepLengthResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetCurrentTimeResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getCurrentTimeResponse")
    public JAXBElement<SimulationGetCurrentTimeResponse> createSimulationGetCurrentTimeResponse(SimulationGetCurrentTimeResponse value) {
        return new JAXBElement<SimulationGetCurrentTimeResponse>(_SimulationGetCurrentTimeResponse_QNAME, SimulationGetCurrentTimeResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EdgeGetFuelConsumptionResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Edge_getFuelConsumptionResponse")
    public JAXBElement<EdgeGetFuelConsumptionResponse> createEdgeGetFuelConsumptionResponse(EdgeGetFuelConsumptionResponse value) {
        return new JAXBElement<EdgeGetFuelConsumptionResponse>(_EdgeGetFuelConsumptionResponse_QNAME, EdgeGetFuelConsumptionResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetLastStepLengthResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getLastStepLengthResponse")
    public JAXBElement<LaneGetLastStepLengthResponse> createLaneGetLastStepLengthResponse(LaneGetLastStepLengthResponse value) {
        return new JAXBElement<LaneGetLastStepLengthResponse>(_LaneGetLastStepLengthResponse_QNAME, LaneGetLastStepLengthResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PoiGetPosition }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Poi_getPosition")
    public JAXBElement<PoiGetPosition> createPoiGetPosition(PoiGetPosition value) {
        return new JAXBElement<PoiGetPosition>(_PoiGetPosition_QNAME, PoiGetPosition.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PoiSetPosition }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Poi_setPosition")
    public JAXBElement<PoiSetPosition> createPoiSetPosition(PoiSetPosition value) {
        return new JAXBElement<PoiSetPosition>(_PoiSetPosition_QNAME, PoiSetPosition.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetLoadedIDListResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getLoadedIDListResponse")
    public JAXBElement<SimulationGetLoadedIDListResponse> createSimulationGetLoadedIDListResponse(SimulationGetLoadedIDListResponse value) {
        return new JAXBElement<SimulationGetLoadedIDListResponse>(_SimulationGetLoadedIDListResponse_QNAME, SimulationGetLoadedIDListResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetWaitingTime }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getWaitingTime")
    public JAXBElement<VehicleGetWaitingTime> createVehicleGetWaitingTime(VehicleGetWaitingTime value) {
        return new JAXBElement<VehicleGetWaitingTime>(_VehicleGetWaitingTime_QNAME, VehicleGetWaitingTime.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link MultientryexitGetLastStepVehicleNumber }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Multientryexit_getLastStepVehicleNumber")
    public JAXBElement<MultientryexitGetLastStepVehicleNumber> createMultientryexitGetLastStepVehicleNumber(MultientryexitGetLastStepVehicleNumber value) {
        return new JAXBElement<MultientryexitGetLastStepVehicleNumber>(_MultientryexitGetLastStepVehicleNumber_QNAME, MultientryexitGetLastStepVehicleNumber.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetMaxSpeed }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setMaxSpeed")
    public JAXBElement<VehicleSetMaxSpeed> createVehicleSetMaxSpeed(VehicleSetMaxSpeed value) {
        return new JAXBElement<VehicleSetMaxSpeed>(_VehicleSetMaxSpeed_QNAME, VehicleSetMaxSpeed.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetPMxEmissionResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getPMxEmissionResponse")
    public JAXBElement<LaneGetPMxEmissionResponse> createLaneGetPMxEmissionResponse(LaneGetPMxEmissionResponse value) {
        return new JAXBElement<LaneGetPMxEmissionResponse>(_LaneGetPMxEmissionResponse_QNAME, LaneGetPMxEmissionResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetStopStartingVehiclesIDList }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getStopStartingVehiclesIDList")
    public JAXBElement<SimulationGetStopStartingVehiclesIDList> createSimulationGetStopStartingVehiclesIDList(SimulationGetStopStartingVehiclesIDList value) {
        return new JAXBElement<SimulationGetStopStartingVehiclesIDList>(_SimulationGetStopStartingVehiclesIDList_QNAME, SimulationGetStopStartingVehiclesIDList.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetSpeedDeviationResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setSpeedDeviationResponse")
    public JAXBElement<VehicleSetSpeedDeviationResponse> createVehicleSetSpeedDeviationResponse(VehicleSetSpeedDeviationResponse value) {
        return new JAXBElement<VehicleSetSpeedDeviationResponse>(_VehicleSetSpeedDeviationResponse_QNAME, VehicleSetSpeedDeviationResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetStopStartingVehiclesIDListResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getStopStartingVehiclesIDListResponse")
    public JAXBElement<SimulationGetStopStartingVehiclesIDListResponse> createSimulationGetStopStartingVehiclesIDListResponse(SimulationGetStopStartingVehiclesIDListResponse value) {
        return new JAXBElement<SimulationGetStopStartingVehiclesIDListResponse>(_SimulationGetStopStartingVehiclesIDListResponse_QNAME, SimulationGetStopStartingVehiclesIDListResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetRouteID }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getRouteID")
    public JAXBElement<VehicleGetRouteID> createVehicleGetRouteID(VehicleGetRouteID value) {
        return new JAXBElement<VehicleGetRouteID>(_VehicleGetRouteID_QNAME, VehicleGetRouteID.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link GUISetBoundary }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "GUI_setBoundary")
    public JAXBElement<GUISetBoundary> createGUISetBoundary(GUISetBoundary value) {
        return new JAXBElement<GUISetBoundary>(_GUISetBoundary_QNAME, GUISetBoundary.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link InductionloopGetTimeSinceDetection }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Inductionloop_getTimeSinceDetection")
    public JAXBElement<InductionloopGetTimeSinceDetection> createInductionloopGetTimeSinceDetection(InductionloopGetTimeSinceDetection value) {
        return new JAXBElement<InductionloopGetTimeSinceDetection>(_InductionloopGetTimeSinceDetection_QNAME, InductionloopGetTimeSinceDetection.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SetSumoBinaryResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "setSumoBinaryResponse")
    public JAXBElement<SetSumoBinaryResponse> createSetSumoBinaryResponse(SetSumoBinaryResponse value) {
        return new JAXBElement<SetSumoBinaryResponse>(_SetSumoBinaryResponse_QNAME, SetSumoBinaryResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EdgeSetMaxSpeedResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Edge_setMaxSpeedResponse")
    public JAXBElement<EdgeSetMaxSpeedResponse> createEdgeSetMaxSpeedResponse(EdgeSetMaxSpeedResponse value) {
        return new JAXBElement<EdgeSetMaxSpeedResponse>(_EdgeSetMaxSpeedResponse_QNAME, EdgeSetMaxSpeedResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link InductionloopGetLaneID }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Inductionloop_getLaneID")
    public JAXBElement<InductionloopGetLaneID> createInductionloopGetLaneID(InductionloopGetLaneID value) {
        return new JAXBElement<InductionloopGetLaneID>(_InductionloopGetLaneID_QNAME, InductionloopGetLaneID.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TrafficlightsSetRedYellowGreenStateResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Trafficlights_setRedYellowGreenStateResponse")
    public JAXBElement<TrafficlightsSetRedYellowGreenStateResponse> createTrafficlightsSetRedYellowGreenStateResponse(TrafficlightsSetRedYellowGreenStateResponse value) {
        return new JAXBElement<TrafficlightsSetRedYellowGreenStateResponse>(_TrafficlightsSetRedYellowGreenStateResponse_QNAME, TrafficlightsSetRedYellowGreenStateResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link GUIScreenshotResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "GUI_screenshotResponse")
    public JAXBElement<GUIScreenshotResponse> createGUIScreenshotResponse(GUIScreenshotResponse value) {
        return new JAXBElement<GUIScreenshotResponse>(_GUIScreenshotResponse_QNAME, GUIScreenshotResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeSetImperfectionResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_setImperfectionResponse")
    public JAXBElement<VehicletypeSetImperfectionResponse> createVehicletypeSetImperfectionResponse(VehicletypeSetImperfectionResponse value) {
        return new JAXBElement<VehicletypeSetImperfectionResponse>(_VehicletypeSetImperfectionResponse_QNAME, VehicletypeSetImperfectionResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeGetAccelResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_getAccelResponse")
    public JAXBElement<VehicletypeGetAccelResponse> createVehicletypeGetAccelResponse(VehicletypeGetAccelResponse value) {
        return new JAXBElement<VehicletypeGetAccelResponse>(_VehicletypeGetAccelResponse_QNAME, VehicletypeGetAccelResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeGetMaxSpeed }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_getMaxSpeed")
    public JAXBElement<VehicletypeGetMaxSpeed> createVehicletypeGetMaxSpeed(VehicletypeGetMaxSpeed value) {
        return new JAXBElement<VehicletypeGetMaxSpeed>(_VehicletypeGetMaxSpeed_QNAME, VehicletypeGetMaxSpeed.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PoiSetTypeResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Poi_setTypeResponse")
    public JAXBElement<PoiSetTypeResponse> createPoiSetTypeResponse(PoiSetTypeResponse value) {
        return new JAXBElement<PoiSetTypeResponse>(_PoiSetTypeResponse_QNAME, PoiSetTypeResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetTypeID }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getTypeID")
    public JAXBElement<VehicleGetTypeID> createVehicleGetTypeID(VehicleGetTypeID value) {
        return new JAXBElement<VehicleGetTypeID>(_VehicleGetTypeID_QNAME, VehicleGetTypeID.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link JunctionGetPositionResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Junction_getPositionResponse")
    public JAXBElement<JunctionGetPositionResponse> createJunctionGetPositionResponse(JunctionGetPositionResponse value) {
        return new JAXBElement<JunctionGetPositionResponse>(_JunctionGetPositionResponse_QNAME, JunctionGetPositionResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link MultientryexitGetLastStepMeanSpeed }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Multientryexit_getLastStepMeanSpeed")
    public JAXBElement<MultientryexitGetLastStepMeanSpeed> createMultientryexitGetLastStepMeanSpeed(MultientryexitGetLastStepMeanSpeed value) {
        return new JAXBElement<MultientryexitGetLastStepMeanSpeed>(_MultientryexitGetLastStepMeanSpeed_QNAME, MultientryexitGetLastStepMeanSpeed.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetDepartedNumber }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getDepartedNumber")
    public JAXBElement<SimulationGetDepartedNumber> createSimulationGetDepartedNumber(SimulationGetDepartedNumber value) {
        return new JAXBElement<SimulationGetDepartedNumber>(_SimulationGetDepartedNumber_QNAME, SimulationGetDepartedNumber.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetParkingStartingVehiclesIDList }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getParkingStartingVehiclesIDList")
    public JAXBElement<SimulationGetParkingStartingVehiclesIDList> createSimulationGetParkingStartingVehiclesIDList(SimulationGetParkingStartingVehiclesIDList value) {
        return new JAXBElement<SimulationGetParkingStartingVehiclesIDList>(_SimulationGetParkingStartingVehiclesIDList_QNAME, SimulationGetParkingStartingVehiclesIDList.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetTraveltimeResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getTraveltimeResponse")
    public JAXBElement<LaneGetTraveltimeResponse> createLaneGetTraveltimeResponse(LaneGetTraveltimeResponse value) {
        return new JAXBElement<LaneGetTraveltimeResponse>(_LaneGetTraveltimeResponse_QNAME, LaneGetTraveltimeResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PolygonGetType }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Polygon_getType")
    public JAXBElement<PolygonGetType> createPolygonGetType(PolygonGetType value) {
        return new JAXBElement<PolygonGetType>(_PolygonGetType_QNAME, PolygonGetType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeSetTau }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_setTau")
    public JAXBElement<VehicletypeSetTau> createVehicletypeSetTau(VehicletypeSetTau value) {
        return new JAXBElement<VehicletypeSetTau>(_VehicletypeSetTau_QNAME, VehicletypeSetTau.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ArealDetectorGetIDCountResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "ArealDetector_getIDCountResponse")
    public JAXBElement<ArealDetectorGetIDCountResponse> createArealDetectorGetIDCountResponse(ArealDetectorGetIDCountResponse value) {
        return new JAXBElement<ArealDetectorGetIDCountResponse>(_ArealDetectorGetIDCountResponse_QNAME, ArealDetectorGetIDCountResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link GUISetBoundaryResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "GUI_setBoundaryResponse")
    public JAXBElement<GUISetBoundaryResponse> createGUISetBoundaryResponse(GUISetBoundaryResponse value) {
        return new JAXBElement<GUISetBoundaryResponse>(_GUISetBoundaryResponse_QNAME, GUISetBoundaryResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetRouteIDResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getRouteIDResponse")
    public JAXBElement<VehicleGetRouteIDResponse> createVehicleGetRouteIDResponse(VehicleGetRouteIDResponse value) {
        return new JAXBElement<VehicleGetRouteIDResponse>(_VehicleGetRouteIDResponse_QNAME, VehicleGetRouteIDResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetLastStepOccupancy }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getLastStepOccupancy")
    public JAXBElement<LaneGetLastStepOccupancy> createLaneGetLastStepOccupancy(LaneGetLastStepOccupancy value) {
        return new JAXBElement<LaneGetLastStepOccupancy>(_LaneGetLastStepOccupancy_QNAME, LaneGetLastStepOccupancy.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeGetLength }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_getLength")
    public JAXBElement<VehicletypeGetLength> createVehicletypeGetLength(VehicletypeGetLength value) {
        return new JAXBElement<VehicletypeGetLength>(_VehicletypeGetLength_QNAME, VehicletypeGetLength.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link InductionloopGetLastStepMeanLengthResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Inductionloop_getLastStepMeanLengthResponse")
    public JAXBElement<InductionloopGetLastStepMeanLengthResponse> createInductionloopGetLastStepMeanLengthResponse(InductionloopGetLastStepMeanLengthResponse value) {
        return new JAXBElement<InductionloopGetLastStepMeanLengthResponse>(_InductionloopGetLastStepMeanLengthResponse_QNAME, InductionloopGetLastStepMeanLengthResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeGetLengthResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_getLengthResponse")
    public JAXBElement<VehicletypeGetLengthResponse> createVehicletypeGetLengthResponse(VehicletypeGetLengthResponse value) {
        return new JAXBElement<VehicletypeGetLengthResponse>(_VehicletypeGetLengthResponse_QNAME, VehicletypeGetLengthResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetHCEmission }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getHCEmission")
    public JAXBElement<LaneGetHCEmission> createLaneGetHCEmission(LaneGetHCEmission value) {
        return new JAXBElement<LaneGetHCEmission>(_LaneGetHCEmission_QNAME, LaneGetHCEmission.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EdgeGetWaitingTime }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Edge_getWaitingTime")
    public JAXBElement<EdgeGetWaitingTime> createEdgeGetWaitingTime(EdgeGetWaitingTime value) {
        return new JAXBElement<EdgeGetWaitingTime>(_EdgeGetWaitingTime_QNAME, EdgeGetWaitingTime.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link MultientryexitGetLastStepVehicleNumberResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Multientryexit_getLastStepVehicleNumberResponse")
    public JAXBElement<MultientryexitGetLastStepVehicleNumberResponse> createMultientryexitGetLastStepVehicleNumberResponse(MultientryexitGetLastStepVehicleNumberResponse value) {
        return new JAXBElement<MultientryexitGetLastStepVehicleNumberResponse>(_MultientryexitGetLastStepVehicleNumberResponse_QNAME, MultientryexitGetLastStepVehicleNumberResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link JunctionGetShapeResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Junction_getShapeResponse")
    public JAXBElement<JunctionGetShapeResponse> createJunctionGetShapeResponse(JunctionGetShapeResponse value) {
        return new JAXBElement<JunctionGetShapeResponse>(_JunctionGetShapeResponse_QNAME, JunctionGetShapeResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetShape }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getShape")
    public JAXBElement<LaneGetShape> createLaneGetShape(LaneGetShape value) {
        return new JAXBElement<LaneGetShape>(_LaneGetShape_QNAME, LaneGetShape.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link RouteGetIDCount }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Route_getIDCount")
    public JAXBElement<RouteGetIDCount> createRouteGetIDCount(RouteGetIDCount value) {
        return new JAXBElement<RouteGetIDCount>(_RouteGetIDCount_QNAME, RouteGetIDCount.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeSetEmissionClass }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_setEmissionClass")
    public JAXBElement<VehicletypeSetEmissionClass> createVehicletypeSetEmissionClass(VehicletypeSetEmissionClass value) {
        return new JAXBElement<VehicletypeSetEmissionClass>(_VehicletypeSetEmissionClass_QNAME, VehicletypeSetEmissionClass.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TrafficlightsSetPhaseDuration }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Trafficlights_setPhaseDuration")
    public JAXBElement<TrafficlightsSetPhaseDuration> createTrafficlightsSetPhaseDuration(TrafficlightsSetPhaseDuration value) {
        return new JAXBElement<TrafficlightsSetPhaseDuration>(_TrafficlightsSetPhaseDuration_QNAME, TrafficlightsSetPhaseDuration.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TrafficlightsGetNextSwitch }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Trafficlights_getNextSwitch")
    public JAXBElement<TrafficlightsGetNextSwitch> createTrafficlightsGetNextSwitch(TrafficlightsGetNextSwitch value) {
        return new JAXBElement<TrafficlightsGetNextSwitch>(_TrafficlightsGetNextSwitch_QNAME, TrafficlightsGetNextSwitch.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetEndingTeleportIDListResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getEndingTeleportIDListResponse")
    public JAXBElement<SimulationGetEndingTeleportIDListResponse> createSimulationGetEndingTeleportIDListResponse(SimulationGetEndingTeleportIDListResponse value) {
        return new JAXBElement<SimulationGetEndingTeleportIDListResponse>(_SimulationGetEndingTeleportIDListResponse_QNAME, SimulationGetEndingTeleportIDListResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetStopEndingVehiclesNumberResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getStopEndingVehiclesNumberResponse")
    public JAXBElement<SimulationGetStopEndingVehiclesNumberResponse> createSimulationGetStopEndingVehiclesNumberResponse(SimulationGetStopEndingVehiclesNumberResponse value) {
        return new JAXBElement<SimulationGetStopEndingVehiclesNumberResponse>(_SimulationGetStopEndingVehiclesNumberResponse_QNAME, SimulationGetStopEndingVehiclesNumberResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetBusStopWaiting }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getBusStopWaiting")
    public JAXBElement<SimulationGetBusStopWaiting> createSimulationGetBusStopWaiting(SimulationGetBusStopWaiting value) {
        return new JAXBElement<SimulationGetBusStopWaiting>(_SimulationGetBusStopWaiting_QNAME, SimulationGetBusStopWaiting.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TrafficlightsSetPhaseResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Trafficlights_setPhaseResponse")
    public JAXBElement<TrafficlightsSetPhaseResponse> createTrafficlightsSetPhaseResponse(TrafficlightsSetPhaseResponse value) {
        return new JAXBElement<TrafficlightsSetPhaseResponse>(_TrafficlightsSetPhaseResponse_QNAME, TrafficlightsSetPhaseResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EdgeSetEffort }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Edge_setEffort")
    public JAXBElement<EdgeSetEffort> createEdgeSetEffort(EdgeSetEffort value) {
        return new JAXBElement<EdgeSetEffort>(_EdgeSetEffort_QNAME, EdgeSetEffort.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetLength }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setLength")
    public JAXBElement<VehicleSetLength> createVehicleSetLength(VehicleSetLength value) {
        return new JAXBElement<VehicleSetLength>(_VehicleSetLength_QNAME, VehicleSetLength.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetAccel }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getAccel")
    public JAXBElement<VehicleGetAccel> createVehicleGetAccel(VehicleGetAccel value) {
        return new JAXBElement<VehicleGetAccel>(_VehicleGetAccel_QNAME, VehicleGetAccel.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link GUISetOffset }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "GUI_setOffset")
    public JAXBElement<GUISetOffset> createGUISetOffset(GUISetOffset value) {
        return new JAXBElement<GUISetOffset>(_GUISetOffset_QNAME, GUISetOffset.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TrafficlightsSetPhaseDurationResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Trafficlights_setPhaseDurationResponse")
    public JAXBElement<TrafficlightsSetPhaseDurationResponse> createTrafficlightsSetPhaseDurationResponse(TrafficlightsSetPhaseDurationResponse value) {
        return new JAXBElement<TrafficlightsSetPhaseDurationResponse>(_TrafficlightsSetPhaseDurationResponse_QNAME, TrafficlightsSetPhaseDurationResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetDeltaT }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getDeltaT")
    public JAXBElement<SimulationGetDeltaT> createSimulationGetDeltaT(SimulationGetDeltaT value) {
        return new JAXBElement<SimulationGetDeltaT>(_SimulationGetDeltaT_QNAME, SimulationGetDeltaT.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TrafficlightsGetProgram }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Trafficlights_getProgram")
    public JAXBElement<TrafficlightsGetProgram> createTrafficlightsGetProgram(TrafficlightsGetProgram value) {
        return new JAXBElement<TrafficlightsGetProgram>(_TrafficlightsGetProgram_QNAME, TrafficlightsGetProgram.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleRerouteEffort }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_rerouteEffort")
    public JAXBElement<VehicleRerouteEffort> createVehicleRerouteEffort(VehicleRerouteEffort value) {
        return new JAXBElement<VehicleRerouteEffort>(_VehicleRerouteEffort_QNAME, VehicleRerouteEffort.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeGetMinGap }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_getMinGap")
    public JAXBElement<VehicletypeGetMinGap> createVehicletypeGetMinGap(VehicletypeGetMinGap value) {
        return new JAXBElement<VehicletypeGetMinGap>(_VehicletypeGetMinGap_QNAME, VehicletypeGetMinGap.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleGetBestLanes }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_getBestLanes")
    public JAXBElement<VehicleGetBestLanes> createVehicleGetBestLanes(VehicleGetBestLanes value) {
        return new JAXBElement<VehicleGetBestLanes>(_VehicleGetBestLanes_QNAME, VehicleGetBestLanes.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetCurrentTime }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getCurrentTime")
    public JAXBElement<SimulationGetCurrentTime> createSimulationGetCurrentTime(SimulationGetCurrentTime value) {
        return new JAXBElement<SimulationGetCurrentTime>(_SimulationGetCurrentTime_QNAME, SimulationGetCurrentTime.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetDecelResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setDecelResponse")
    public JAXBElement<VehicleSetDecelResponse> createVehicleSetDecelResponse(VehicleSetDecelResponse value) {
        return new JAXBElement<VehicleSetDecelResponse>(_VehicleSetDecelResponse_QNAME, VehicleSetDecelResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link GUIGetOffset }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "GUI_getOffset")
    public JAXBElement<GUIGetOffset> createGUIGetOffset(GUIGetOffset value) {
        return new JAXBElement<GUIGetOffset>(_GUIGetOffset_QNAME, GUIGetOffset.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneGetLastStepOccupancyResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_getLastStepOccupancyResponse")
    public JAXBElement<LaneGetLastStepOccupancyResponse> createLaneGetLastStepOccupancyResponse(LaneGetLastStepOccupancyResponse value) {
        return new JAXBElement<LaneGetLastStepOccupancyResponse>(_LaneGetLastStepOccupancyResponse_QNAME, LaneGetLastStepOccupancyResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link InductionloopGetTimeSinceDetectionResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Inductionloop_getTimeSinceDetectionResponse")
    public JAXBElement<InductionloopGetTimeSinceDetectionResponse> createInductionloopGetTimeSinceDetectionResponse(InductionloopGetTimeSinceDetectionResponse value) {
        return new JAXBElement<InductionloopGetTimeSinceDetectionResponse>(_InductionloopGetTimeSinceDetectionResponse_QNAME, InductionloopGetTimeSinceDetectionResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicleSetTauResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicle_setTauResponse")
    public JAXBElement<VehicleSetTauResponse> createVehicleSetTauResponse(VehicleSetTauResponse value) {
        return new JAXBElement<VehicleSetTauResponse>(_VehicleSetTauResponse_QNAME, VehicleSetTauResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link EdgeGetNoiseEmission }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Edge_getNoiseEmission")
    public JAXBElement<EdgeGetNoiseEmission> createEdgeGetNoiseEmission(EdgeGetNoiseEmission value) {
        return new JAXBElement<EdgeGetNoiseEmission>(_EdgeGetNoiseEmission_QNAME, EdgeGetNoiseEmission.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PoiGetColorResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Poi_getColorResponse")
    public JAXBElement<PoiGetColorResponse> createPoiGetColorResponse(PoiGetColorResponse value) {
        return new JAXBElement<PoiGetColorResponse>(_PoiGetColorResponse_QNAME, PoiGetColorResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link MultientryexitGetIDListResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Multientryexit_getIDListResponse")
    public JAXBElement<MultientryexitGetIDListResponse> createMultientryexitGetIDListResponse(MultientryexitGetIDListResponse value) {
        return new JAXBElement<MultientryexitGetIDListResponse>(_MultientryexitGetIDListResponse_QNAME, MultientryexitGetIDListResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetParkingEndingVehiclesIDList }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getParkingEndingVehiclesIDList")
    public JAXBElement<SimulationGetParkingEndingVehiclesIDList> createSimulationGetParkingEndingVehiclesIDList(SimulationGetParkingEndingVehiclesIDList value) {
        return new JAXBElement<SimulationGetParkingEndingVehiclesIDList>(_SimulationGetParkingEndingVehiclesIDList_QNAME, SimulationGetParkingEndingVehiclesIDList.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link MultientryexitGetIDCount }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Multientryexit_getIDCount")
    public JAXBElement<MultientryexitGetIDCount> createMultientryexitGetIDCount(MultientryexitGetIDCount value) {
        return new JAXBElement<MultientryexitGetIDCount>(_MultientryexitGetIDCount_QNAME, MultientryexitGetIDCount.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link VehicletypeGetVehicleClass }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Vehicletype_getVehicleClass")
    public JAXBElement<VehicletypeGetVehicleClass> createVehicletypeGetVehicleClass(VehicletypeGetVehicleClass value) {
        return new JAXBElement<VehicletypeGetVehicleClass>(_VehicletypeGetVehicleClass_QNAME, VehicletypeGetVehicleClass.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimulationGetNetBoundaryResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Simulation_getNetBoundaryResponse")
    public JAXBElement<SimulationGetNetBoundaryResponse> createSimulationGetNetBoundaryResponse(SimulationGetNetBoundaryResponse value) {
        return new JAXBElement<SimulationGetNetBoundaryResponse>(_SimulationGetNetBoundaryResponse_QNAME, SimulationGetNetBoundaryResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PolygonRemove }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Polygon_remove")
    public JAXBElement<PolygonRemove> createPolygonRemove(PolygonRemove value) {
        return new JAXBElement<PolygonRemove>(_PolygonRemove_QNAME, PolygonRemove.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LaneSetAllowed }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.tudresden.de/", name = "Lane_setAllowed")
    public JAXBElement<LaneSetAllowed> createLaneSetAllowed(LaneSetAllowed value) {
        return new JAXBElement<LaneSetAllowed>(_LaneSetAllowed_QNAME, LaneSetAllowed.class, null, value);
    }

}
